/**************************************************************************
 |                                                                         
 |                    STATA SETUP FILE FOR ICPSR 02258
 |         DRUG ABUSE TREATMENT OUTCOME STUDY (DATOS), 1991-1994:
 |                            [UNITED STATES]
 |               (DATASET 0004:  3-MONTH INTREATMENT DATA)
 |
 |
 |  Please edit this file as instructed below.
 |  To execute, start Stata, change to the directory containing:
 |       - this do file
 |       - the ASCII data file
 |       - the dictionary file
 |
 |  Then execute the do file (e.g., do 02258-0004-statasetup.do)
 |
 **************************************************************************/

set mem 20m  /* Allocating 20 megabyte(s) of RAM for Stata SE to read the
                 data file into memory. */


set more off  /* This prevents the Stata output viewer from pausing the
                 process */

/****************************************************

Section 1: File Specifications
   This section assigns local macros to the necessary files.
   Please edit:
        "data-filename" ==> The name of data file downloaded from ICPSR
        "dictionary-filename" ==> The name of the dictionary file downloaded.
        "stata-datafile" ==> The name you wish to call your Stata data file.

   Note:  We assume that the raw data, dictionary, and setup (this do file) all
          reside in the same directory (or folder).  If that is not the case
          you will need to include paths as well as filenames in the macros.

********************************************************/

local raw_data "data-filename"
local dict "dictionary-filename"
local outfile "stata-datafile"

/********************************************************

Section 2: Infile Command

This section reads the raw data into Stata format.  If Section 1 was defined
properly, there should be no reason to modify this section.  These macros
should inflate automatically.

**********************************************************/

infile using `dict', using (`raw_data') clear


/*********************************************************

Section 3: Value Label Definitions
This section defines labels for the individual values of each variable.
We suggest that users do not modify this section.

**********************************************************/


label data "Drug Abuse Treatment Outcome Study (DATOS), 1991-1994: [United States], Dataset 0004"

#delimit ;
label define MODALITY  1 "RESIDENTIAL" 2 "SHORT-TERM INPATIENT"
                       3 "METHADONE MAINTENANCE" 4 "OUTPATIENT DRUG FREE" ;
label define FORM      1 "NOV91" 2 "OCT92" ;
label define GDC_M     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "JAN.-MARCH" 2 "APR.-JUNE"
                       3 "JULY-SEPT." 4 "OCT.-DEC." ;
label define GDC_Y     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define GT_L_I    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define GA3       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define GA3_A     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "PUERTO RICAN" 2 "MEXICAN"
                       3 "CUBAN" 4 "CARIBBEAN" 5 "CENTRAL AMERICAN"
                       6 "SOUTH AMERICAN" 7 "OTHER/ETHNIC BACKGROUND"
                       15 "MIXED" ;
label define GA3_B     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "ALASKAN NATIVE"
                       2 "AMERICAN INDIAN" 3 "ASIAN/PACIFIC ISLANDER"
                       4 "BLACK/AFRICAN AMERICAN" 5 "WHITE/CAUCASIAN"
                       6 "OTHER" ;
label define GA4       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "ALASKAN NATIVE"
                       2 "AMERICAN INDIAN" 3 "ASIAN/PACIFIC ISLANDER"
                       4 "BLACK/AFRICAN AMERICAN" 5 "WHITE/CAUCASIAN"
                       6 "OTHER" ;
label define GA5       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM"
                       1 "ONE FAMILY HOUSE/DUPLEX/CONDO"
                       2 "A MOBILE HOME/TRAILER"
                       3 "APARTMENT/MULTIPLE FAMILY BUILDING"
                       4 "HOTEL/ROOMING HOUSE/BOARDING HOUSE"
                       5 "HOSPITAL/MEDICAL INSTITUTION"
                       6 "JAIL/PRISON/JUVENILE DETENTION HOME"
                       7 "RESIDENTIAL DRUG TREAT CTR"
                       8 "OTHER GROUP RESIDENCE/HALFWAY HOUSE"
                       9 "IN A HOMELESS SHELTER"
                       10 "ON THE STREET/NO REGULAR PLACE" 11 "OTHER" ;
label define GA6       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define GA7       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "MARRIED" 2 "SEPARATED"
                       3 "DIVORCED" 4 "WIDOWED" 5 "LIVE/W/SOMEONE AS MARRIED"
                       6 "NEVER MARRIED" ;
label define GA8       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM"
                       1 "HAS BEEN VERY MUCH OPPOSED"
                       2 "HAS BEEN SOMEWHAT OPPOSED"
                       3 "HAS NOT CARED ONE WAY/OTHER"
                       4 "APPROVED OF YOUR USE OF DRUGS"
                       5 "HAS NOT AWARE OF YOUR DRUG USE"
                       6 "NOT IN CONTACT WITH PARTNER" ;
label define GA8_A     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "NOT AT ALL" 2 "SOMEWHAT"
                       3 "VERY IMPORTANT" ;
label define GA8_B     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define GA8_C     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define GA8_D     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define GA8_E     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define GA9       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NOT AT ALL" 1 "SOMEWHAT"
                       2 "VERY MUCH" ;
label define GA10      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM"
                       1 "WITH SPOUSE/SEXUAL PARTNER/CHILDREN"
                       2 "WITH SPOUSE/SEXUAL PARTNER ONLY"
                       3 "WITH CHILDREN ONLY" 4 "WITH BOTH PARENTS"
                       5 "WITH MOTHER ONLY" 6 "WITH FATHER ONLY"
                       7 "WITH PARENT(S) AND OWN CHILDREN"
                       8 "WITH OTHER FAMILY/ANY COMB 01-07"
                       9 "WITH FOSTER PARENTS"
                       10 "W/FAMILY/FRIENDS/BOARDERS/ROOMMATES"
                       11 "W/FRIENDS/ROOMMATES ONLY" 12 "ALONE"
                       13 "INSTITUTION/CLOSED FACILITY/HOSP"
                       14 "NO STABLE ARRANGEMENTS" 15 "OTHER" ;
label define GA11      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "VERY DISSATISFIED"
                       2 "SOMEWHAT DISSATISFIED" 3 "SOMEWHAT SATISFIED"
                       4 "VERY SATISFIED" ;
label define GA12      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 6 "6+" ;
label define GA13      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 6 "6+" ;
label define GA13A_02  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 2 "CIRCLED" ;
label define GA13A_03  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 3 "CIRCLED" ;
label define GA13A_04  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 4 "CIRCLED" ;
label define GA13A_05  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 5 "CIRCLED" ;
label define GA13A_06  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 6 "CIRCLED" ;
label define GA14      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 6 "6+" ;
label define GA14A_02  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 2 "CIRCLED" ;
label define GA14A_03  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 3 "CIRCLED" ;
label define GA14A_04  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 4 "CIRCLED" ;
label define GA14A_05  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 5 "CIRCLED" ;
label define GA14A_06  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 6 "CIRCLED" ;
label define GA15_00   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "CIRCLED" ;
label define GA15_01   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "CIRCLED" ;
label define GA15_02   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 2 "CIRCLED" ;
label define GA15_03   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 3 "CIRCLED" ;
label define GA16      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO"
                       3 "SOMEWHAT/MAYBE" ;
label define GA17      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "POOR" 2 "FAIR" 3 "WELL" ;
label define GA18      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NOT AT ALL" 1 "SOMEWHAT"
                       2 "VERY DIFFICULT" ;
label define GA19      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define GA19_A    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define GA19_B    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define GA20      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NOT AT ALL" 1 "SOMEWHAT"
                       2 "VERY IMPORTANT" ;
label define GA21      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NONE" 1 "SOME" 2 "A LOT"
                       93 "IF VOL: NO FAMILY/FRIENDS" ;
label define GA22      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "POOR" 2 "FAIR" 3 "WELL" ;
label define GA23_A    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "NOT AT ALL"
                       2 "LESS ONCE/WEEK" 3 "AT LEAST ONCE/WEEK"
                       4 "ALMOST DAILY" ;
label define GA23_B    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "NOT AT ALL"
                       2 "LESS ONCE/WEEK" 3 "AT LEAST ONCE/WEEK"
                       4 "ALMOST DAILY" ;
label define GA23_C    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "NOT AT ALL"
                       2 "LESS ONCE/WEEK" 3 "AT LEAST ONCE/WEEK"
                       4 "ALMOST DAILY" ;
label define GA24_A    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "NONE" 2 "ONE OR A FEW"
                       3 "MANY" ;
label define GA24_B    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "NONE" 2 "ONE OR A FEW"
                       3 "MANY" ;
label define GA24_C    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "NONE" 2 "ONE OR A FEW"
                       3 "MANY" ;
label define GA24_D    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "NONE" 2 "ONE OR A FEW"
                       3 "MANY" ;
label define GA24_E    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "NONE" 2 "ONE OR A FEW"
                       3 "MANY" ;
label define GA24_F    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "NONE" 2 "ONE OR A FEW"
                       3 "MANY" ;
label define GA25      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "VERY UNHAPPY"
                       2 "SOMEWHAT UNHAPPY" 3 "SOMEWHAT HAPPY" 4 "VERY HAPPY" ;
label define GA26      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "WORSE" 2 "BETTER" ;
label define GA27      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define GA27A     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "NOT AT ALL" 2 "SOMEWHAT"
                       3 "VERY SERIOUS" ;
label define GB1       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 21 "21+" ;
label define GB1_A     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define GB1_B     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define GB1_C     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM"
                       1 "MIDDLE SCHOOL (JUNIOR HIGH)" 2 "HIGH SCHOOL"
                       3 "JUNIOR (2-YR) COLLEGE"
                       4 "4-YR COLLEGE OR UNIVERSITY"
                       5 "TECHNICAL/TRADE/VOCATIONAL SCHOOL"
                       6 "JOB CORPS PROG" 7 "SPECIAL EDUCATION PROG"
                       8 "OTHER" ;
label define GB1_D     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "BETTER THAN AVERAGE"
                       2 "AVERAGE" 3 "NOT SO GOOD" ;
label define GB1_E     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "DID AS WELL AS COULD"
                       2 "COULD HAVE DONE MUCH BETTER" ;
label define GB1_F     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define GB1_G     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define GB2       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define GB2_A     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "DIPLOMA" 2 "GED" ;
label define GB3_0     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "CIRCLED" ;
label define GB3_1     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "CIRCLED" ;
label define GB3_2     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 2 "CIRCLED" ;
label define GB3_3     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 3 "CIRCLED" ;
label define GB3_4     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 4 "CIRCLED" ;
label define GB3_5     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 5 "CIRCLED" ;
label define GB3_6     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 6 "CIRCLED" ;
label define GB4       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define GB4_A     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "EXPIRED" 2 "SUSPENDED"
                       3 "REVOKED" 4 "IF VOL: NEVER HAD ONE" ;
label define GB5       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NONE" 1 "SOME"
                       2 "ALL OF THE TIME" ;
label define GC1       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define GC1_A_01  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "CIRCLED" ;
label define GC1_A_02  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 2 "CIRCLED" ;
label define GC1_A_03  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 3 "CIRCLED" ;
label define GC1_A_04  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 4 "CIRCLED" ;
label define GC1_A_05  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 5 "CIRCLED" ;
label define GC1_A_06  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 6 "CIRCLED" ;
label define GC1_A_07  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 7 "CIRCLED" ;
label define GC1_B     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "OWN NAME"
                       2 "OTHER FAMILY MEMBER" ;
label define GC1_C     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO"
                       3 "PROG CHARGES NO FEES" ;
label define GC1_D     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NONE" 1 "LESS THAN HALF"
                       2 "HALF OR MORE" 3 "ALL" 4 "PROG CHARGES NO FEES" ;
label define GC1_E     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "SELF PAY"
                       2 "FAMILY/RELATIVES" 3 "WORKERS COMPENSATION"
                       4 "OTHER" ;
label define GC2       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "LIVING AT PROG" 1 "WALK"
                       2 "DRIVE" 3 "PUB TRANSPORTATION"
                       4 "RIDE FROM FAMILY/FRIEND" 5 "TAXICAB"
                       6 "PROG PROVIDED TRANSPORTATION" 7 "OTHER" ;
label define GC3       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "EASY" 2 "DIFFICULT" ;
label define GC3_A     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "SOMEWHAT EASY"
                       2 "VERY EASY" ;
label define GC3_B     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "SOMEWHAT DIFFICULT"
                       2 "VERY DIFFICULT" ;
label define GC4_00    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "CIRCLED" ;
label define GC4_01    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "CIRCLED" ;
label define GC4_02    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 2 "CIRCLED" ;
label define GC4_03    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 3 "CIRCLED" ;
label define GC4_04    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 4 "CIRCLED" ;
label define GC4_05    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 5 "CIRCLED" ;
label define GC4_06    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 6 "CIRCLED" ;
label define GC4_07    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 7 "CIRCLED" ;
label define GC4_08    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 8 "CIRCLED" ;
label define GC4_09    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 9 "CIRCLED" ;
label define GC5       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" 3 "UNCERTAIN" ;
label define GC5_A     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define GC6       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define GC6_A     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "REQUIRED, STIPULATED"
                       2 "SUGGESTED, ENCOURAGED" ;
label define GC7       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define GC7_A     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "REGULAR" 2 "RANDOM"
                       3 "BOTH" ;
label define GC7_B_1   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define GC7_B_2   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "PER WEEK" 2 "PER MONTH"
                       3 "TOTAL/ALTOGETHER" ;
label define GD1       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define GD1_A     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define GD1_B_1   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM"
                       1 "LESS THAN ONE WEEK AFTER ADM"
                       2 "AT LEAST ONE WEEK AFTER ADM" ;
label define GD1_B_2   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define GD1_C     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define GD2       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define GD2_A     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define GD2_B     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define GD2_C_1   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM"
                       1 "LESS THAN ONE WEEK AFTER ADM"
                       2 "AT LEAST ONE WEEK AFTER ADM" ;
label define GD2_C_2   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define GD2_D     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define GD3       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define GD3_A     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define GD4       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define GD4_A     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define GD5       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define GD5_A_1   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM"
                       1 "LESS THAN ONE WEEK AFTER ADM"
                       2 "AT LEAST ONE WEEK AFTER ADM" ;
label define GD5_A_2   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define GD5_B     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define GD6       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define GD6_A_1   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM"
                       1 "LESS THAN ONE WEEK AFTER ADM"
                       2 "AT LEAST ONE WEEK AFTER ADM" ;
label define GD6_A_2   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define GD6_B     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define GD7       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define GD7_A_1   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM"
                       1 "LESS THAN ONE WEEK AFTER ADM"
                       2 "AT LEAST ONE WEEK AFTER ADM" ;
label define GD7_A_2   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define GD7_B     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define GD8       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define GD8_A     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define GD9       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define GD10      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define GD10_A    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define GD11      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define GD11_A    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "NOT AT ALL" 2 "SOMEWHAT"
                       3 "VERY SERIOUS" ;
label define GD12      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NOT AT ALL" 1 "SOMEWHAT"
                       2 "VERY TROUBLED" ;
label define GD13      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "STRONGLY DISAGREE"
                       2 "SOMEWHAT DISAGREE" 3 "SOMEWHAT AGREE"
                       4 "STRONGLY AGREE" ;
label define GD14      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "STRONGLY DISAGREE"
                       2 "SOMEWHAT DISAGREE" 3 "SOMEWHAT AGREE"
                       4 "STRONGLY AGREE" ;
label define GD15      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "STRONGLY DISAGREE"
                       2 "SOMEWHAT DISAGREE" 3 "SOMEWHAT AGREE"
                       4 "STRONGLY AGREE" ;
label define GD16      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "STRONGLY DISAGREE"
                       2 "SOMEWHAT DISAGREE" 3 "SOMEWHAT AGREE"
                       4 "STRONGLY AGREE" ;
label define GD17      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "STRONGLY DISAGREE"
                       2 "SOMEWHAT DISAGREE" 3 "SOMEWHAT AGREE"
                       4 "STRONGLY AGREE" ;
label define GD18      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "STRONGLY DISAGREE"
                       2 "SOMEWHAT DISAGREE" 3 "SOMEWHAT AGREE"
                       4 "STRONGLY AGREE" ;
label define GD19      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NOT AT ALL" 1 "SOMEWHAT"
                       2 "VERY IMPORTANT" ;
label define GE1       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define GE2       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define GE3       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define GE4       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define GE5       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define GE6       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define GE7       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NOT AT ALL" 1 "SOMEWHAT"
                       2 "VERY TROUBLED" ;
label define GE8       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NOT AT ALL" 1 "SOMEWHAT"
                       2 "VERY IMPORTANT" ;
label define GE9       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "VERY POOR" 2 "FAIR"
                       3 "VERY GOOD" ;
label define GE10      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NOT AT ALL" 1 "SOMEWHAT"
                       2 "VERY DIFFICULT" ;
label define GE11      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "VERY POOR" 2 "FAIR"
                       3 "VERY GOOD" ;
label define GE12      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define GE12_A    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "1-5 CIGARETTES"
                       2 "6-15 CIGARETTES" 3 "16-25 CIGARETTES"
                       4 "26-35 CIGARETTES" 5 "OVER 35 CIGARETTES" ;
label define GE13      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define GE13_A_1  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "CIRCLED" ;
label define GE13_A_2  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 2 "CIRCLED" ;
label define GE13_A_3  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 3 "CIRCLED" ;
label define GE14      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define GE14_A_1  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM"
                       1 "LESS THAN ONE WEEK AFTER ADM"
                       2 "AT LEAST ONE WEEK AFTER ADM" ;
label define GE14_A_2  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define GE14_B_1  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "MORE THAN ONE WEEK AGO"
                       2 "WITHIN THE LAST WEEK" ;
label define GE14_B_2  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define GE14_C    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "LESS THAN ONCE PER MONTH"
                       2 "1-3 TIMES/MO" 3 "1-2 TIMES/WK" 4 "3-4 TIMES/WK"
                       5 "5-6 TIMES/WK" 6 "DAILY OR ALMOST EVERY DAY"
                       7 "2 OR 3 TIMES A DAY" 8 "4+ TIMES A DAY" ;
label define GE15      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define GE15_A_1  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM"
                       1 "LESS THAN ONE WEEK AFTER ADM"
                       2 "AT LEAST ONE WEEK AFTER ADM" ;
label define GE15_A_2  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define GE15_B_1  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "MORE THAN ONE WEEK AGO"
                       2 "WITHIN THE LAST WEEK" ;
label define GE15_B_2  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define GE15_C    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "BY MOUTH (EAT, CHEW)"
                       2 "BY SMOKING IT" 3 "BY INHALING/SNORTING/SNIFFING IT"
                       4 "BY INJECTING IT INTO A VEIN"
                       5 "BY INJECTING IT SOMEWHERE ELSE" 6 "BY FREEBASING"
                       7 "SOME OTHER WAY" ;
label define GE15_D    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "LESS THAN ONCE PER MONTH"
                       2 "1-3 TIMES A MONTH" 3 "1-2 TIMES A WEEK"
                       4 "3-4 TIMES A WEEK" 5 "5-6 TIMES A WEEK"
                       6 "DAILY OR ALMOST EVERY DAY" 7 "2 OR 3 TIMES A DAY"
                       8 "4+ TIMES A DAY" ;
label define GE15_E    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NOT USED"
                       1 "LESS THAN ONCE PER MONTH" 2 "1-3 TIMES A MONTH"
                       3 "1-2 TIMES A WEEK" 4 "3-4 TIMES A WEEK"
                       5 "5-6 TIMES A WEEK" 6 "DAILY OR ALMOST EVERY DAY"
                       7 "2 OR 3 TIMES A DAY" 8 "4+ TIMES A DAY" ;
label define GE16      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define GE16_A_1  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM"
                       1 "LESS THAN ONE WEEK AFTER ADM"
                       2 "AT LEAST ONE WEEK AFTER ADM" ;
label define GE16_A_2  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define GE16_B_1  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "MORE THAN ONE WEEK AGO"
                       2 "WITHIN THE LAST WEEK" ;
label define GE16_B_2  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define GE16_C    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "BY MOUTH (EAT, CHEW)"
                       2 "BY SMOKING IT" 3 "BY INHALING/SNORTING/SNIFFING IT"
                       4 "BY INJECTING IT INTO A VEIN"
                       5 "BY INJECTING IT SOMEWHERE ELSE" 6 "BY FREEBASING"
                       7 "SOME OTHER WAY" ;
label define GE16_D    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "LESS THAN ONCE PER MONTH"
                       2 "1-3 TIMES A MONTH" 3 "1-2 TIMES A WEEK"
                       4 "3-4 TIMES A WEEK" 5 "5-6 TIMES A WEEK"
                       6 "DAILY OR ALMOST EVERY DAY" 7 "2 OR 3 TIMES A DAY"
                       8 "4+ TIMES A DAY" ;
label define GE16_E    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NOT USED"
                       1 "LESS THAN ONCE PER MONTH" 2 "1-3 TIMES A MONTH"
                       3 "1-2 TIMES A WEEK" 4 "3-4 TIMES A WEEK"
                       5 "5-6 TIMES A WEEK" 6 "DAILY OR ALMOST EVERY DAY"
                       7 "2 OR 3 TIMES A DAY" 8 "4+ TIMES A DAY" ;
label define GE16_F    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "BY MOUTH (EAT, CHEW)"
                       2 "BY SMOKING IT" 3 "BY INHALING/SNORTING/SNIFFING IT"
                       4 "BY INJECTING IT INTO A VEIN"
                       5 "BY INJECTING IT SOMEWHERE ELSE" 6 "BY FREEBASING"
                       7 "SOME OTHER WAY" ;
label define GE17      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define GE17_A    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define GE17_B_1  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NONE" 1 "DARVON"
                       2 "DOLENE" 3 "SK-65" 4 "WYGESIC" 5 "LEVO-DROMORAN"
                       6 "PERCODAN" 7 "DEMEROL" 8 "DILAUDID"
                       9 "TYLENOL WITH CODEINE" 10 "PHENAPHEN WITH CODEINE"
                       11 "TALWIN" 12 "TALWIN NX" 13 "TALACEN"
                       14 "PROPOXYPHENE" 15 "CODEINE" 16 "ANILERIDINE"
                       17 "MORPHINE" 18 "METHADONE" 19 "STADOL" 20 "DARVOCET"
                       21 "LOMOTIL" 22 "PAREGORIC" ;
label define GE17_B_2  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NONE" 1 "DARVON"
                       2 "DOLENE" 3 "SK-65" 4 "WYGESIC" 5 "LEVO-DROMORAN"
                       6 "PERCODAN" 7 "DEMEROL" 8 "DILAUDID"
                       9 "TYLENOL WITH CODEINE" 10 "PHENAPHEN WITH CODEINE"
                       11 "TALWIN" 12 "TALWIN NX" 13 "TALACEN"
                       14 "PROPOXYPHENE" 15 "CODEINE" 16 "ANILERIDINE"
                       17 "MORPHINE" 18 "METHADONE" 19 "STADOL" 20 "DARVOCET"
                       21 "LOMOTIL" 22 "PAREGORIC" ;
label define GE17_B_3  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NONE" 1 "DEXEDRINE"
                       2 "DEXAMYL" 3 "ESKATROL" 4 "BENZEDRINE"
                       5 "BIPHETAMINE" 6 "DESOXYN" 7 "TENUATE" 8 "TEPANIL"
                       9 "DIDREX" 10 "PLEGINE" 11 "PRELUDIN" 12 "IONAMIN"
                       13 "FASTIN" 14 "PONDIMIN" 15 "VORANIL" 16 "SANOREX"
                       17 "MAZANOR" 18 "RITALIN" 19 "CYLERT"
                       20 "DEXTROAMPHETAMINE" 21 "METHEDRINE"
                       22 "METHAMPHETAMINE (SPEED OR CRANK)"
                       23 "OBEDRIN-L.A." ;
label define GE17_C    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define GE18      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define GE18_A_1  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM"
                       1 "LESS THAN ONE WEEK AFTER ADM"
                       2 "AT LEAST ONE WEEK AFTER ADM" ;
label define GE18_A_2  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define GE18_B_1  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "MORE THAN ONE WEEK AGO"
                       2 "WITHIN THE LAST WEEK" ;
label define GE18_B_2  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define GE18_C    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "BY MOUTH (EAT, CHEW)"
                       2 "BY SMOKING IT" 3 "BY INHALING/SNORTING/SNIFFING IT"
                       4 "BY INJECTING IT INTO A VEIN"
                       5 "BY INJECTING IT SOMEWHERE ELSE" 6 "BY FREEBASING"
                       7 "SOME OTHER WAY" ;
label define GE18_D    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "LESS THAN ONCE PER MONTH"
                       2 "1-3 TIMES A MONTH" 3 "1-2 TIMES A WEEK"
                       4 "3-4 TIMES A WEEK" 5 "5-6 TIMES A WEEK"
                       6 "DAILY OR ALMOST EVERY DAY" 7 "2 OR 3 TIMES A DAY"
                       8 "4+ TIMES A DAY" ;
label define GE18_E    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NOT USED"
                       1 "LESS THAN ONCE PER MONTH" 2 "1-3 TIMES A MONTH"
                       3 "1-2 TIMES A WEEK" 4 "3-4 TIMES A WEEK"
                       5 "5-6 TIMES A WEEK" 6 "DAILY OR ALMOST EVERY DAY"
                       7 "2 OR 3 TIMES A DAY" 8 "4+ TIMES A DAY" ;
label define GE19      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define GE19_A    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define GE19B1_1  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NONE" 1 "BUTISOL"
                       2 "BUTICAPS" 3 "AMYTAL" 4 "MEBARAL" 5 "PLACIDYL"
                       6 "DORIDEN" 7 "NOLUDAR" 8 "NEMBUTAL" 9 "SECONAL"
                       10 "TUINAL" 11 "DALMANE" 12 "RESTORIL" 13 "HALCION"
                       14 "AMOBARBITAL" 15 "PHENOBARBITAL"
                       16 "METHAQUALONE (INCL.SOPR,QUAALUDE)"
                       17 "CHLORAL HYDRATE" 18 "PENTOBARBITAL"
                       19 "SECOBARBITAL" 20 "FLURAZEPAN" 21 "NOCTEC" ;
label define GE19B1_2  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NONE" 1 "BUTISOL"
                       2 "BUTICAPS" 3 "AMYTAL" 4 "MEBARAL" 5 "PLACIDYL"
                       6 "DORIDEN" 7 "NOLUDAR" 8 "NEMBUTAL" 9 "SECONAL"
                       10 "TUINAL" 11 "DALMANE" 12 "RESTORIL" 13 "HALCION"
                       14 "AMOBARBITAL" 15 "PHENOBARBITAL"
                       16 "METHAQUALONE (INCL.SOPR,QUAALUDE)"
                       17 "CHLORAL HYDRATE" 18 "PENTOBARBITAL"
                       19 "SECOBARBITAL" 20 "FLURAZEPAN" 21 "NOCTEC" ;
label define GE19B2_1  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NONE" 1 "VALIUM"
                       2 "LIBRIUM" 3 "LIMBITROL" 4 "MENRIUM" 5 "SERAX"
                       6 "TRANXENE" 7 "ATIVAN" 8 "CENTRAX" 9 "XANAX"
                       10 "PAXIPAM" 11 "BUSPAR" 12 "MILTOWN" 13 "EQUANIL"
                       14 "DEPROL" 15 "VISARIL" 16 "ATARAX" 17 "DURRAX"
                       18 "DIAZEPAM" 19 "SK-LYGEN" 20 "MEPROBAMATE"
                       21 "HYDROXYZINE" 22 "BENADRYL" 23 "CLONAZEPAM"
                       24 "KLONOPIN" ;
label define GE19B2_2  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NONE" 1 "VALIUM"
                       2 "LIBRIUM" 3 "LIMBITROL" 4 "MENRIUM" 5 "SERAX"
                       6 "TRANXENE" 7 "ATIVAN" 8 "CENTRAX" 9 "XANAX"
                       10 "PAXIPAM" 11 "BUSPAR" 12 "MILTOWN" 13 "EQUANIL"
                       14 "DEPROL" 15 "VISARIL" 16 "ATARAX" 17 "DURRAX"
                       18 "DIAZEPAM" 19 "SK-LYGEN" 20 "MEPROBAMATE"
                       21 "HYDROXYZINE" 22 "BENADRYL" 23 "CLONAZEPAM"
                       24 "KLONOPIN" ;
label define GE19_C    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define GE20      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define GE20_A_1  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM"
                       1 "LESS THAN ONE WEEK AFTER ADM"
                       2 "AT LEAST ONE WEEK AFTER ADM" ;
label define GE20_A_2  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define GE20_B_1  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "MORE THAN ONE WEEK AGO"
                       2 "WITHIN THE LAST WEEK" ;
label define GE20_B_2  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define GE20_C    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "BY MOUTH (EAT, CHEW)"
                       2 "BY SMOKING IT" 3 "BY INHALING/SNORTING/SNIFFING IT"
                       4 "BY INJECTING IT INTO A VEIN"
                       5 "BY INJECTING IT SOMEWHERE ELSE" 6 "BY FREEBASING"
                       7 "SOME OTHER WAY" ;
label define GE20_D    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "LESS THAN ONCE PER MONTH"
                       2 "1-3 TIMES A MONTH" 3 "1-2 TIMES A WEEK"
                       4 "3-4 TIMES A WEEK" 5 "5-6 TIMES A WEEK"
                       6 "DAILY OR ALMOST EVERY DAY" 7 "2 OR 3 TIMES A DAY"
                       8 "4+ TIMES A DAY" ;
label define GE20_E_1  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "CIRCLED" ;
label define GE20_E_2  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 2 "CIRCLED" ;
label define GE20_E_3  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 3 "CIRCLED" ;
label define GE20_E_4  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 4 "CIRCLED" ;
label define GE20_F    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "SEDATIVES/SLEEPING PILLS"
                       2 "BARBITURATES" 3 "BENZODIAZEPINES"
                       4 "OTHER TRANQUILIZERS" ;
label define GE21      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define GE21_A    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define GE21_B_1  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "DEXEDRINE" 2 "DEXAMYL"
                       3 "ESKATROL" 4 "BENZEDRINE" 5 "BIPHETAMINE"
                       6 "DESOXYN" 7 "TENUATE" 8 "TEPANIL" 9 "DIDREX"
                       10 "PLEGINE" 11 "PRELUDIN" 12 "IONAMIN" 13 "FASTIN"
                       14 "PONDIMIN" 15 "VORANIL" 16 "SANOREX" 17 "MAZANOR"
                       18 "RITALIN" 19 "CYLERT" 20 "DEXTROAMPHETAMINE"
                       21 "METHEDRINE" 22 "METHAMPHETAMINE (SPEED OR CRANK)"
                       23 "OBEDRIN-L.A." ;
label define GE21_B_2  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "DEXEDRINE" 2 "DEXAMYL"
                       3 "ESKATROL" 4 "BENZEDRINE" 5 "BIPHETAMINE"
                       6 "DESOXYN" 7 "TENUATE" 8 "TEPANIL" 9 "DIDREX"
                       10 "PLEGINE" 11 "PRELUDIN" 12 "IONAMIN" 13 "FASTIN"
                       14 "PONDIMIN" 15 "VORANIL" 16 "SANOREX" 17 "MAZANOR"
                       18 "RITALIN" 19 "CYLERT" 20 "DEXTROAMPHETAMINE"
                       21 "METHEDRINE" 22 "METHAMPHETAMINE (SPEED OR CRANK)"
                       23 "OBEDRIN-L.A." ;
label define GE21_B_3  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define GE21_C    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define GE22      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define GE22_A_1  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM"
                       1 "LESS THAN ONE WEEK AFTER ADM"
                       2 "AT LEAST ONE WEEK AFTER ADM" ;
label define GE22_A_2  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define GE22_B_1  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "MORE THAN ONE WEEK AGO"
                       2 "WITHIN THE LAST WEEK" ;
label define GE22_B_2  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define GE22_C    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "BY MOUTH (EAT, CHEW)"
                       2 "BY SMOKING IT" 3 "BY INHALING/SNORTING/SNIFFING IT"
                       4 "BY INJECTING IT INTO A VEIN"
                       5 "BY INJECTING IT SOMEWHERE ELSE" 6 "BY FREEBASING"
                       7 "SOME OTHER WAY" ;
label define GE22_D    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "LESS THAN ONCE PER MONTH"
                       2 "1-3 TIMES A MONTH" 3 "1-2 TIMES A WEEK"
                       4 "3-4 TIMES A WEEK" 5 "5-6 TIMES A WEEK"
                       6 "DAILY OR ALMOST EVERY DAY" 7 "2 OR 3 TIMES A DAY"
                       8 "4+ TIMES A DAY" ;
label define GE22_E    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NOT USED"
                       1 "LESS THAN ONCE PER MONTH" 2 "1-3 TIMES A MONTH"
                       3 "1-2 TIMES A WEEK" 4 "3-4 TIMES A WEEK"
                       5 "5-6 TIMES A WEEK" 6 "DAILY OR ALMOST EVERY DAY"
                       7 "2 OR 3 TIMES A DAY" 8 "4+ TIMES A DAY" ;
label define GE23      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NEITHER"
                       1 "MAJOR TRANQUILIZERS" 2 "MAJOR ANTIDEPRESSANTS"
                       3 "BOTH" ;
label define GE23_A    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NEITHER"
                       1 "MAJOR TRANQUILIZERS" 2 "MAJOR ANTIDEPRESSANTS"
                       3 "BOTH" ;
label define GE24      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define GE24_A_1  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM"
                       1 "LESS THAN ONE WEEK AFTER ADM"
                       2 "AT LEAST ONE WEEK AFTER ADM" ;
label define GE24_A_2  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define GE24_B_1  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "MORE THAN ONE WEEK AGO"
                       2 "WITHIN THE LAST WEEK" ;
label define GE24_B_2  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define GE24_C    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "BY MOUTH (EAT, CHEW)"
                       2 "BY SMOKING IT" 3 "BY INHALING/SNORTING/SNIFFING IT"
                       4 "BY INJECTING IT INTO A VEIN"
                       5 "BY INJECTING IT SOMEWHERE ELSE" 6 "BY FREEBASING"
                       7 "SOME OTHER WAY" ;
label define GE24_D    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "LESS THAN ONCE PER MONTH"
                       2 "1-3 TIMES A MONTH" 3 "1-2 TIMES A WEEK"
                       4 "3-4 TIMES A WEEK" 5 "5-6 TIMES A WEEK"
                       6 "DAILY OR ALMOST EVERY DAY" 7 "2 OR 3 TIMES A DAY"
                       8 "4+ TIMES A DAY" ;
label define GE24_E    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NOT USED"
                       1 "LESS THAN ONCE PER MONTH" 2 "1-3 TIMES A MONTH"
                       3 "1-2 TIMES A WEEK" 4 "3-4 TIMES A WEEK"
                       5 "5-6 TIMES A WEEK" 6 "DAILY OR ALMOST EVERY DAY"
                       7 "2 OR 3 TIMES A DAY" 8 "4+ TIMES A DAY" ;
label define GE25      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define GE25_A_1  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM"
                       1 "LESS THAN ONE WEEK AFTER ADM"
                       2 "AT LEAST ONE WEEK AFTER ADM" ;
label define GE25_A_2  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define GE25_B_1  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "MORE THAN ONE WEEK AGO"
                       2 "WITHIN THE LAST WEEK" ;
label define GE25_B_2  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define GE25_C    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "LESS THAN ONCE PER MONTH"
                       2 "1-3 TIMES A MONTH" 3 "1-2 TIMES A WEEK"
                       4 "3-4 TIMES A WEEK" 5 "5-6 TIMES A WEEK"
                       6 "DAILY OR ALMOST EVERY DAY" 7 "2 OR 3 TIMES A DAY"
                       8 "4+ TIMES A DAY" ;
label define GE26      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NONE" 10 "ALCOHOL"
                       20 "MARIJUANA, HASHISH, THC"
                       30 "HALLUCINOGENS OR PSYCHEDELICS"
                       40 "COCAINE IN ANY FORM" 41 "CRACK" 50 "HEROIN"
                       51 "HEROIN AND COCAINE TOGETHER AT THE SAME"
                       60 "NARCOTICS OR OPIATES SUCH AS MORPHINE, C"
                       61 "STREET OR ILLEGAL METHADONE"
                       70 "DOWNERS OR DEPRESSANTS SUCH AS SEDATIVES"
                       80 "AMPHETAMINES OR OTHER STIMULANTS, SPEED,"
                       81 "METHAMPHETAMINES OR ICE" 90 "ANY OTHER DRUGS"
                       91 "INHALANTS, SUCH AS GLUE, GASOLINE, PAINT" ;
label define GE26_A_1  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM"
                       1 "LESS THAN ONE WEEK AFTER ADM"
                       2 "AT LEAST ONE WEEK AFTER ADM" ;
label define GE26_A_2  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define GE26_B_1  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "MORE THAN ONE WEEK AGO"
                       2 "WITHIN THE LAST WEEK" ;
label define GE26_B_2  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define GE26_C    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "BY MOUTH (EAT, CHEW)"
                       2 "BY SMOKING IT" 3 "BY INHALING/SNORTING/SNIFFING IT"
                       4 "BY INJECTING IT INTO A VEIN"
                       5 "BY INJECTING IT SOMEWHERE ELSE" 6 "BY FREEBASING"
                       7 "SOME OTHER WAY" ;
label define GE26_D    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "LESS THAN ONCE PER MONTH"
                       2 "1-3 TIMES A MONTH" 3 "1-2 TIMES A WEEK"
                       4 "3-4 TIMES A WEEK" 5 "5-6 TIMES A WEEK"
                       6 "DAILY OR ALMOST EVERY DAY" 7 "2 OR 3 TIMES A DAY"
                       8 "4+ TIMES A DAY" ;
label define GE27      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define GE27_A    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 10 "ALCOHOL"
                       20 "MARIJUANA, HASHISH, THC"
                       30 "HALLUCINOGENS OR PSYCHEDELICS"
                       40 "COCAINE IN ANY FORM" 41 "CRACK" 50 "HEROIN"
                       51 "HEROIN AND COCAINE TOGETHER AT THE SAME"
                       60 "NARCOTICS OR OPIATES SUCH AS MORPHINE, C"
                       61 "STREET OR ILLEGAL METHADONE"
                       70 "DOWNERS OR DEPRESSANTS SUCH AS SEDATIVES"
                       80 "AMPHETAMINES OR OTHER STIMULANTS, SPEED,"
                       81 "METHAMPHETAMINES OR ICE" 90 "ANY OTHER DRUGS"
                       91 "INHALANTS, SUCH AS GLUE, GASOLINE, PAINT" ;
label define GE27_B_1  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM"
                       1 "LESS THAN ONE WEEK AFTER ADM"
                       2 "AT LEAST ONE WEEK AFTER ADM" ;
label define GE27_B_2  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define GE27_C_1  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "MORE THAN ONE WEEK AGO"
                       2 "WITHIN THE LAST WEEK" ;
label define GE27_C_2  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define GE27_D    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "BY MOUTH (EAT, CHEW)"
                       2 "BY SMOKING IT" 3 "BY INHALING/SNORTING/SNIFFING IT"
                       4 "BY INJECTING IT INTO A VEIN"
                       5 "BY INJECTING IT SOMEWHERE ELSE" 6 "BY FREEBASING"
                       7 "SOME OTHER WAY" ;
label define GE27_E    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "LESS THAN ONCE PER MONTH"
                       2 "1-3 TIMES A MONTH" 3 "1-2 TIMES A WEEK"
                       4 "3-4 TIMES A WEEK" 5 "5-6 TIMES A WEEK"
                       6 "DAILY OR ALMOST EVERY DAY" 7 "2 OR 3 TIMES A DAY"
                       8 "4+ TIMES A DAY" ;
label define GE28      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define GE28_A    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NONE" 10 "ALCOHOL"
                       20 "MARIJUANA, HASHISH, THC"
                       30 "HALLUCINOGENS OR PSYCHEDELICS"
                       40 "COCAINE IN ANY FORM" 41 "CRACK" 50 "HEROIN"
                       51 "HEROIN AND COCAINE TOGETHER AT THE SAME"
                       60 "NARCOTICS OR OPIATES SUCH AS MORPHINE, C"
                       61 "STREET OR ILLEGAL METHADONE"
                       70 "DOWNERS OR DEPRESSANTS SUCH AS SEDATIVES"
                       80 "AMPHETAMINES OR OTHER STIMULANTS, SPEED,"
                       81 "METHAMPHETAMINES OR ICE" 90 "ANY OTHER DRUGS"
                       91 "INHALANTS, SUCH AS GLUE, GASOLINE, PAINT" ;
label define GE28_B_1  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM"
                       1 "LESS THAN ONE WEEK AFTER ADM"
                       2 "AT LEAST ONE WEEK AFTER ADM" ;
label define GE28_B_2  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define GE28_C_1  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "MORE THAN ONE WEEK AGO"
                       2 "WITHIN THE LAST WEEK" ;
label define GE28_C_2  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define GE28_D    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "BY MOUTH (EAT, CHEW)"
                       2 "BY SMOKING IT" 3 "BY INHALING/SNORTING/SNIFFING IT"
                       4 "BY INJECTING IT INTO A VEIN"
                       5 "BY INJECTING IT SOMEWHERE ELSE" 6 "BY FREEBASING"
                       7 "SOME OTHER WAY" ;
label define GE28_E    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "LESS THAN ONCE PER MONTH"
                       2 "1-3 TIMES A MONTH" 3 "1-2 TIMES A WEEK"
                       4 "3-4 TIMES A WEEK" 5 "5-6 TIMES A WEEK"
                       6 "DAILY OR ALMOST EVERY DAY" 7 "2 OR 3 TIMES A DAY"
                       8 "4+ TIMES A DAY" ;
label define GE29      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define GE30      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define GE30_A    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define GE31      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define GE31A_1   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 99 "99 OR MORE" ;
label define GE31A_2   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define GE31A_3   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define GE31A_4   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define GE31A_5   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define GE31A_6   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define GE32      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define GE33_A    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NEVER" 1 "RARELY"
                       2 "SOMETIMES" 3 "OFTEN" 4 "ALWAYS" ;
label define GE33_B    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NEVER" 1 "RARELY"
                       2 "SOMETIMES" 3 "OFTEN" 4 "ALWAYS" ;
label define GE33_C    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NEVER" 1 "RARELY"
                       2 "SOMETIMES" 3 "OFTEN" 4 "ALWAYS" ;
label define GE33_D    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NEVER" 1 "RARELY"
                       2 "SOMETIMES" 3 "OFTEN" 4 "ALWAYS" ;
label define GE33_E    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NEVER" 1 "RARELY"
                       2 "SOMETIMES" 3 "OFTEN" 4 "ALWAYS" ;
label define GE33_F    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NEVER" 1 "RARELY"
                       2 "SOMETIMES" 3 "OFTEN" 4 "ALWAYS" ;
label define GE34      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NOT AT ALL" 1 "SOMEWHAT"
                       2 "VERY MUCH" ;
label define GE35      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NOT AT ALL" 1 "SOMEWHAT"
                       2 "VERY IMPORTANT" ;
label define GE36      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NOT AT ALL" 1 "A LITTLE"
                       2 "A LOT" ;
label define GE37      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NOT AT ALL" 1 "A LITTLE"
                       2 "A LOT" ;
label define GE38      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NOT AT ALL" 1 "SOMEWHAT"
                       2 "VERY TEMPTED" ;
label define GE39_A    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM"
                       0 "NOT AT ALL CONFIDENT/SURE"
                       1 "SOMEWHAT CONFIDENT/SURE" 2 "VERY CONFIDENT/SURE" ;
label define GE39_B    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM"
                       0 "NOT AT ALL CONFIDENT/SURE"
                       1 "SOMEWHAT CONFIDENT/SURE" 2 "VERY CONFIDENT/SURE" ;
label define GE39_C    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM"
                       0 "NOT AT ALL CONFIDENT/SURE"
                       1 "SOMEWHAT CONFIDENT/SURE" 2 "VERY CONFIDENT/SURE" ;
label define GE39_D    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM"
                       0 "NOT AT ALL CONFIDENT/SURE"
                       1 "SOMEWHAT CONFIDENT/SURE" 2 "VERY CONFIDENT/SURE" ;
label define GE39_E    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM"
                       0 "NOT AT ALL CONFIDENT/SURE"
                       1 "SOMEWHAT CONFIDENT/SURE" 2 "VERY CONFIDENT/SURE" ;
label define GE39_F    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM"
                       0 "NOT AT ALL CONFIDENT/SURE"
                       1 "SOMEWHAT CONFIDENT/SURE" 2 "VERY CONFIDENT/SURE" ;
label define GE39_G    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM"
                       0 "NOT AT ALL CONFIDENT/SURE"
                       1 "SOMEWHAT CONFIDENT/SURE" 2 "VERY CONFIDENT/SURE" ;
label define GE39_H    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM"
                       0 "NOT AT ALL CONFIDENT/SURE"
                       1 "SOMEWHAT CONFIDENT/SURE" 2 "VERY CONFIDENT/SURE" ;
label define GE39_I    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM"
                       0 "NOT AT ALL CONFIDENT/SURE"
                       1 "SOMEWHAT CONFIDENT/SURE" 2 "VERY CONFIDENT/SURE" ;
label define GE39_J    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM"
                       0 "NOT AT ALL CONFIDENT/SURE"
                       1 "SOMEWHAT CONFIDENT/SURE" 2 "VERY CONFIDENT/SURE" ;
label define GE39_K    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM"
                       0 "NOT AT ALL CONFIDENT/SURE"
                       1 "SOMEWHAT CONFIDENT/SURE" 2 "VERY CONFIDENT/SURE" ;
label define GE39_L    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM"
                       0 "NOT AT ALL CONFIDENT/SURE"
                       1 "SOMEWHAT CONFIDENT/SURE" 2 "VERY CONFIDENT/SURE" ;
label define GE39_M    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM"
                       0 "NOT AT ALL CONFIDENT/SURE"
                       1 "SOMEWHAT CONFIDENT/SURE" 2 "VERY CONFIDENT/SURE" ;
label define GE39_N    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM"
                       0 "NOT AT ALL CONFIDENT/SURE"
                       1 "SOMEWHAT CONFIDENT/SURE" 2 "VERY CONFIDENT/SURE" ;
label define GE39_O    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM"
                       0 "NOT AT ALL CONFIDENT/SURE"
                       1 "SOMEWHAT CONFIDENT/SURE" 2 "VERY CONFIDENT/SURE" ;
label define GE39_P    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM"
                       0 "NOT AT ALL CONFIDENT/SURE"
                       1 "SOMEWHAT CONFIDENT/SURE" 2 "VERY CONFIDENT/SURE" ;
label define GE39_Q    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM"
                       0 "NOT AT ALL CONFIDENT/SURE"
                       1 "SOMEWHAT CONFIDENT/SURE" 2 "VERY CONFIDENT/SURE" ;
label define GE39_R    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM"
                       0 "NOT AT ALL CONFIDENT/SURE"
                       1 "SOMEWHAT CONFIDENT/SURE" 2 "VERY CONFIDENT/SURE" ;
label define GE39_S    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM"
                       0 "NOT AT ALL CONFIDENT/SURE"
                       1 "SOMEWHAT CONFIDENT/SURE" 2 "VERY CONFIDENT/SURE" ;
label define GE39_T    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM"
                       0 "NOT AT ALL CONFIDENT/SURE"
                       1 "SOMEWHAT CONFIDENT/SURE" 2 "VERY CONFIDENT/SURE" ;
label define GE40      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define GE40_B_1  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM"
                       0 "NOT AT ALL CONFIDENT/SURE"
                       1 "SOMEWHAT CONFIDENT/SURE" 2 "VERY CONFIDENT/SURE" ;
label define GE40_B_2  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM"
                       0 "NOT AT ALL CONFIDENT/SURE"
                       1 "SOMEWHAT CONFIDENT/SURE" 2 "VERY CONFIDENT/SURE" ;
label define GE40_B_3  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM"
                       0 "NOT AT ALL CONFIDENT/SURE"
                       1 "SOMEWHAT CONFIDENT/SURE" 2 "VERY CONFIDENT/SURE" ;
label define GE41_A    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM"
                       0 "NOT AT ALL CONFIDENT/SURE"
                       1 "SOMEWHAT CONFIDENT/SURE" 2 "VERY CONFIDENT/SURE" ;
label define GE41_B    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM"
                       0 "NOT AT ALL CONFIDENT/SURE"
                       1 "SOMEWHAT CONFIDENT/SURE" 2 "VERY CONFIDENT/SURE" ;
label define GE42      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NOT AT ALL" 1 "SOMEWHAT"
                       2 "VERY DIFFICUT" ;
label define GE43      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "VERY POOR" 2 "FAIR"
                       3 "VERY GOOD" ;
label define GE44      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NOT AT ALL" 1 "SOMEWHAT"
                       2 "VERY MUCH" ;
label define GE45      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NOT AT ALL" 1 "SOMEWHAT"
                       2 "VERY DIFFICULT" ;
label define GE46      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "VERY POOR" 2 "FAIR"
                       3 "VERY GOOD" ;
label define GE47      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NOT AT ALL" 1 "SOMEWHAT"
                       2 "VERY MUCH" ;
label define GE48_A    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "STRONGLY DISAGREE"
                       2 "SOMEWHAT DISAGREE" 3 "SOMEWHAT AGREE"
                       4 "STRONGLY AGREE" ;
label define GE48_B    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "STRONGLY DISAGREE"
                       2 "SOMEWHAT DISAGREE" 3 "SOMEWHAT AGREE"
                       4 "STRONGLY AGREE" ;
label define GE48_C    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "STRONGLY DISAGREE"
                       2 "SOMEWHAT DISAGREE" 3 "SOMEWHAT AGREE"
                       4 "STRONGLY AGREE" ;
label define GE48_D    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "STRONGLY DISAGREE"
                       2 "SOMEWHAT DISAGREE" 3 "SOMEWHAT AGREE"
                       4 "STRONGLY AGREE" ;
label define GE48_E    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "STRONGLY DISAGREE"
                       2 "SOMEWHAT DISAGREE" 3 "SOMEWHAT AGREE"
                       4 "STRONGLY AGREE" ;
label define GE48_F    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "STRONGLY DISAGREE"
                       2 "SOMEWHAT DISAGREE" 3 "SOMEWHAT AGREE"
                       4 "STRONGLY AGREE" ;
label define GE48_G    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "STRONGLY DISAGREE"
                       2 "SOMEWHAT DISAGREE" 3 "SOMEWHAT AGREE"
                       4 "STRONGLY AGREE" ;
label define GE48_H    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "STRONGLY DISAGREE"
                       2 "SOMEWHAT DISAGREE" 3 "SOMEWHAT AGREE"
                       4 "STRONGLY AGREE" ;
label define GE48_I    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "STRONGLY DISAGREE"
                       2 "SOMEWHAT DISAGREE" 3 "SOMEWHAT AGREE"
                       4 "STRONGLY AGREE" ;
label define GE48_J    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "STRONGLY DISAGREE"
                       2 "SOMEWHAT DISAGREE" 3 "SOMEWHAT AGREE"
                       4 "STRONGLY AGREE" ;
label define GE48_K    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "STRONGLY DISAGREE"
                       2 "SOMEWHAT DISAGREE" 3 "SOMEWHAT AGREE"
                       4 "STRONGLY AGREE" ;
label define GE48_L    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "STRONGLY DISAGREE"
                       2 "SOMEWHAT DISAGREE" 3 "SOMEWHAT AGREE"
                       4 "STRONGLY AGREE" ;
label define GF1       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM"
                       0 "NEVER HAD VAGINAL SEX WITH A WOMAN" 1 "NONE"
                       2 "1 WOMAN" 3 "2-4 WOMEN" 4 "5-9 WOMEN"
                       5 "10-20 WOMEN" 6 "21-99 WOMEN" 7 "100+ WOMEN" ;
label define GF1_A     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "NEVER" 2 "SOMETIMES"
                       3 "USUALLY" 4 "EVERY TIME" ;
label define GF2       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "NONE" 2 "1 WOMAN"
                       3 "2-4 WOMEN" 4 "5-9 WOMEN" 5 "10-20 WOMEN"
                       6 "21-99 WOMEN" 7 "100+ WOMEN" ;
label define GF2_A     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "NEVER" 2 "SOMETIMES"
                       3 "USUALLY" 4 "EVERY TIME" ;
label define GF3       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define GF4       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define GF5       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NEVER HAD SEX WITH A MAN"
                       1 "NONE" 2 "1 MAN" 3 "2-4 MEN" 4 "5-9 MEN"
                       5 "10-20 MEN" 6 "21-99 MEN" 7 "100+ MEN" ;
label define GF5_A     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "NEVER" 2 "SOMETIMES"
                       3 "USUALLY" 4 "EVERY TIME" ;
label define GF6       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define GF7       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define GF8       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define GF9       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define GF9_A     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "1 PERSON" 2 "2-4 PEOPLE"
                       3 "5+ PEOPLE" ;
label define GF10      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM"
                       0 "NEVER HAD VAGINAL INTERCOURSE W/MAN" 1 "NONE"
                       2 "1 MAN" 3 "2-4 MEN" 4 "5-9 MEN" 5 "10-20 MEN"
                       6 "21-99 MEN" 7 "100+ MEN" ;
label define GF10_A    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "NEVER" 2 "SOMETIMES"
                       3 "USUALLY" 4 "EVERY TIME" ;
label define GF11      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM"
                       0 "NEVER HAD ANAL SEX WITH A MAN" 1 "NONE" 2 "1 MAN"
                       3 "2-4 MEN" 4 "5-9 MEN" 5 "10-20 MEN" 6 "21-99 MEN"
                       7 "100+ MEN" ;
label define GF11_A    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "NEVER" 2 "SOMETIMES"
                       3 "USUALLY" 4 "EVERY TIME" ;
label define GF12      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define GF13      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define GF14      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define GF15      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define GF16      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define GF16_A    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "1 MAN" 2 "2-4 MEN"
                       3 "5+ MEN" ;
label define GF17      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define GF17_A_1  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "CIRCLED" ;
label define GF17_A_2  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 2 "CIRCLED" ;
label define GF17_A_3  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 3 "CIRCLED" ;
label define GF17_A_4  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 4 "CIRCLED" ;
label define GF17_B    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "AT THIS PROG"
                       2 "SOME OTHER PLACE" 3 "BOTH" ;
label define GF17_C    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 99 "99 OR MORE" ;
label define GF17D_01  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "CIRCLED" ;
label define GF17D_02  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 2 "CIRCLED" ;
label define GF17D_14  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 14 "CIRCLED" ;
label define GF17D_23  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 23 "CIRCLED" ;
label define GF17D_24  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 24 "CIRCLED" ;
label define GF17D_61  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 61 "CIRCLED" ;
label define GF17D_62  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 62 "CIRCLED" ;
label define GF17D_91  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 91 "CIRCLED" ;
label define GF17_E    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NOT AT ALL" 1 "SOMEWHAT"
                       2 "VERY HELPFUL" ;
label define GF18      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define GG1       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "EXCELLENT" 2 "GOOD"
                       3 "FAIR" 4 "POOR" ;
label define GG2       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "MUCH BETTER" 2 "BETTER"
                       3 "THE SAME" 4 "WORSE" 5 "MUCH WORSE" ;
label define GG3       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "MUCH BETTER" 2 "BETTER"
                       3 "THE SAME" 4 "WORSE" 5 "MUCH WORSE" ;
label define GG4       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define GG4_A     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define GG4_B_1   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "CIRCLED" ;
label define GG4_B_2   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 2 "CIRCLED" ;
label define GG4_B_3   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 3 "CIRCLED" ;
label define GG4_B_4   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 4 "CIRCLED" ;
label define GG4_C     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 3 "1-3" 6 "4-6" 9 "7-9" ;
label define GG4_D     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NONE" 1 "VERY MILD"
                       2 "MILD" 3 "MODERATE" 4 "SEVERE" ;
label define GG4_E     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define GG4F_1    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "CIRCLED" ;
label define GG4F_2    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 2 "CIRCLED" ;
label define GG4F_3    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 3 "CIRCLED" ;
label define GG4F_4    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 4 "CIRCLED" ;
label define GG4F_5    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 5 "CIRCLED" ;
label define GG4F_6    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 6 "CIRCLED" ;
label define GG4G      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define GG5_A     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define GG6_A     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "LESS THAN 3 MOS"
                       2 "3 MOS OR MORE" ;
label define GG5_B     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define GG6_B     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "LESS THAN 3 MOS"
                       2 "3 MOS OR MORE" ;
label define GG5_C     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define GG6_C     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "LESS THAN 3 MOS"
                       2 "3 MOS OR MORE" ;
label define GG5_D     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define GG6_D     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "LESS THAN 3 MOS"
                       2 "3 MOS OR MORE" ;
label define GG5_E     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define GG6_E     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "LESS THAN 3 MOS"
                       2 "3 MOS OR MORE" ;
label define GG5_F     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define GG6_F     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "LESS THAN 3 MOS"
                       2 "3 MOS OR MORE" ;
label define GG7       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define GG7_A     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 99 "99 OR MORE" ;
label define GG8       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define GG9       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define GG10      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define GG11      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define GG12      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define GG12A_1   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "CIRCLED" ;
label define GG12A_2   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 2 "CIRCLED" ;
label define GG12A_3   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 3 "CIRCLED" ;
label define GG12A_4   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 4 "CIRCLED" ;
label define GG12B_1   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NO DIAGNOSIS"
                       1 "SUBSTANCE-RELATED DISORDERS" 2 "MENTAL DISORDERS"
                       3 "ALL OTHER DISORDERS" ;
label define GG12B_2   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NO DIAGNOSIS"
                       1 "SUBSTANCE-RELATED DISORDERS" 2 "MENTAL DISORDERS"
                       3 "ALL OTHER DISORDERS" ;
label define GG12B_3   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NO DIAGNOSIS"
                       1 "SUBSTANCE-RELATED DISORDERS" 2 "MENTAL DISORDERS"
                       3 "ALL OTHER DISORDERS" ;
label define GG13      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NOT AT ALL" 1 "SOMEWHAT"
                       2 "VERY MUCH" ;
label define GG14      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NOT AT ALL" 1 "SOMEWHAT"
                       2 "VERY IMPORTANT" ;
label define GG15      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define GG15_A    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "NOT AT ALL" 2 "SOMEWHAT"
                       3 "VERY SERIOUS" ;
label define GH1       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define GH1_A     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define GH2_A     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define GH3_A     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define GH2_B     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define GH3_B     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define GH2_C     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define GH3_C     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define GH2_D     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define GH3_D     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define GH2_E     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define GH3_E     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define GH2_F     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define GH3_F     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define GH2_G     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define GH3_G     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define GH2_H     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define GH3_H     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define GH2_I     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define GH3_I     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define GH2_J     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define GH3_J     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define GH2_K     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define GH3_K     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define GH2_L     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define GH3_L     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define GH4       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define GH5       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NEVER" 1 "1 OR 2 TIMES"
                       2 "3-5 TIMES" 3 "6-10 TIMES" 4 "11-49 TIMES"
                       5 "50+ TIMES" ;
label define GH6       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define GH6_A     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "NOT AT ALL" 2 "SOMEWHAT"
                       3 "VERY SERIOUS" ;
label define GH7       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NOT AT ALL" 1 "SOMEWHAT"
                       2 "VERY TROUBLED" ;
label define GH8       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define GH8_A     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define GH9       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NOT AT ALL" 1 "SOMEWHAT"
                       2 "VERY TROUBLED" ;
label define GJ1       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM"
                       1 "WORKING LEGITIMATE JOB/YOURSELF"
                       2 "HAD A JOB BUT WAS NOT WORKING" 3 "LOOKING FOR WORK"
                       4 "HOMEMAKER" 5 "GOING TO SCHOOL/TRAINNG PROG"
                       6 "UNABLE TO WORK, DISABLE" 7 "RETIRED"
                       8 "IN JAIL/RESI TREAT PROG/OTHER INSTI"
                       9 "INVOLVED IN DRUG RELATED ACTIVITY"
                       10 "INVOLVED IN OTHER ILLEGAL ACTIVITY"
                       11 "NOT WORKING/NOT INTEREST WORKING" 12 "OTHER" ;
label define GJ2       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define GJ2_A     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM"
                       1 "DID NOT EARN MONEY LEGALLY"
                       2 "DID EARN MONEY LEGALLY" ;
label define GJ2_B     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define GJ2_C     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 99 "99 OR MORE" ;
label define GJ2_D     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define GJ2_E     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM"
                       1 "SLACK WORK, LAYOFFS, STRIKE" 2 "SEASONAL WORKER"
                       3 "JOB TERMINATED" 4 "NEW JOB STARTED DURING WEEK"
                       5 "COULD ONLY FINE PART-TIME WORK"
                       6 "DRUG OR ALCOHOL PROB" 7 "ILLNESS" 8 "VACATION"
                       9 "BUSY WITH OTHER ACTIVITIES"
                       10 "DID NOT WANT/NEED FULL-TIME WORK"
                       11 "WORKWEEK USUALLY UNDER 35 HRS" 12 "UNABLE TO WORK"
                       13 "RETIRED" 14 "IN JAIL, RESIDENTAL TREATMNT PROG"
                       15 "INVOLVED IN ILLEGAL ACTIVITIES" 16 "OTHERS" ;
label define GJ2_F     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define GJ2_G     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM"
                       1 "SLACK WORK, LAYOFFS, STRIKE" 2 "SEASONAL WORKER"
                       3 "JOB TERMINATED" 4 "NEW JOB STARTED DURING WEEK"
                       5 "COULD ONLY FINE PART-TIME WORK"
                       6 "DRUG OR ALCOHOL PROB" 7 "ILLNESS" 8 "VACATION"
                       9 "BUSY WITH OTHER ACTIVITIES"
                       10 "DID NOT WANT/NEED FULL-TIME WORK"
                       11 "WORKWEEK USUALLY UNDER 35 HRS" 12 "UNABLE TO WORK"
                       13 "RETIRED" 14 "IN JAIL, RESIDENTAL TREATMNT PROG"
                       15 "INVOLVED IN ILLEGAL ACTIVITIES" 16 "OTHERS" ;
label define GJ3       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define GJ3_A_1   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "CIRCLED" ;
label define GJ3_A_2   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 2 "CIRCLED" ;
label define GJ3_A_3   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 3 "CIRCLED" ;
label define GJ3_A_4   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 4 "CIRCLED" ;
label define GJ3_A_5   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 5 "CIRCLED" ;
label define GJ3_A_6   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 6 "CIRCLED" ;
label define GJ3_A_7   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 7 "CIRCLED" ;
label define GJ3_B     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define GJ3_C_1   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "CIRCLED" ;
label define GJ3_C_2   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 2 "CIRCLED" ;
label define GJ3_C_3   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 3 "CIRCLED" ;
label define GJ3_C_4   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 4 "CIRCLED" ;
label define GJ3_C_5   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 5 "CIRCLED" ;
label define GJ3_C_6   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 6 "CIRCLED" ;
label define GJ3_C_7   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 7 "CIRCLED" ;
label define GJ3_C_8   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 8 "CIRCLED" ;
label define GJ3_C_9   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 9 "CIRCLED" ;
label define GJ3_C_10  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 10 "CIRCLED" ;
label define GJ3_C_11  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 11 "CIRCLED" ;
label define GJ4_0     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "CIRCLED" ;
label define GJ4_1     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "CIRCLED" ;
label define GJ4_2     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 2 "CIRCLED" ;
label define GJ4_3     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 3 "CIRCLED" ;
label define GJ4_4     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 4 "CIRCLED" ;
label define GJ4_5     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 5 "CIRCLED" ;
label define GJ4_6     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 6 "CIRCLED" ;
label define GJ4_7     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 7 "CIRCLED" ;
label define GJ4_8     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 8 "CIRCLED" ;
label define GJ4_9     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 9 "CIRCLED" ;
label define GJ4_10    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 10 "CIRCLED" ;
label define GJ4_11    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 11 "CIRCLED" ;
label define GJ4_12    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 12 "CIRCLED" ;
label define GJ4_13    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 13 "CIRCLED" ;
label define GJ4_14    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 14 "CIRCLED" ;
label define GJ4_15    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 15 "CIRCLED" ;
label define GJ4_16    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 16 "CIRCLED" ;
label define GJ5       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define GJ6       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define GJ7       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define GJ8       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define GJ9       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM"
                       1 "PROFESSIONAL AND TECHNICAL"
                       2 "MANAGER AND ADMINISTRATOR" 3 "SALES"
                       4 "CLERICAL OR OFFICE WORKER" 5 "CRAFT AND KINDRED"
                       6 "OPERATIVES" 7 "TRANSPORTATION EQUIPMENT OPERATIVES"
                       8 "LABORERS (FARM & NONFARM)" 10 "SERVICE WORKER"
                       86 "OTHER" ;
label define GJ9_A     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM"
                       1 "AGRICULTURE/FORESTRY/FISHERIES" 2 "CONSTRUCTION"
                       3 "MANUFACTURING"
                       4 "TRANSPORT./COMMUNIC./OTHER PUB UTILITIES"
                       5 "WHOLESALE TRADE" 6 "RETAIL TRADE"
                       7 "FINANCE/INSUR./REAL ESTATE"
                       8 "BUSINESS/REPAIR SERVICES" 9 "PERSONAL SERVICES"
                       10 "ENTERTAINMENT/REC. SVCS" 11 "PROF./RELATED SVCS"
                       12 "PUB ADMIN." 13 "INDUSTRY NOT REPORTED" ;
label define GJ9_B     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define GJ9_B_OC  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM"
                       1 "PROFESSIONAL AND TECHNICAL"
                       2 "MANAGER AND ADMINISTRATOR" 3 "SALES"
                       4 "CLERICAL OR OFFICE WORKER" 5 "CRAFT AND KINDRED"
                       6 "OPERATIVES" 7 "TRANSPORTATION EQUIPMENT OPERATIVES"
                       8 "LABORERS (FARM & NONFARM)" 10 "SERVICE WORKER"
                       86 "OTHER" ;
label define GJ9_C     -9.00 "LEGITIMATE SKIP" -8.00 "BLANK" -7.00 "REFUSAL"
                       -6.00 "MULTIPLE RESPONSE" -5.00 "BAD DATA"
                       -4.00 "DON'T KNOW" -3.00 "NOT APPLICABLE"
                       -2.00 "ILLEGIBLE" -1.00 "VARIABLE NOT ON FORM" ;
label define GJ9_COD   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "HOUR" 2 "WEEK" 3 "2 WKS"
                       4 "MONTH" 5 "YR" 6 "OTHER" ;
label define GJ10      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NOT AT ALL" 1 "SOMEWHAT"
                       2 "VERY MUCH" ;
label define GJ11      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NOT AT ALL" 1 "SOMEWHAT"
                       2 "VERY IMPORTANT" ;
label define GJ12      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define GJ12_A    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "NOT AT ALL" 2 "SOMEWHAT"
                       3 "VERY SERIOUS" ;
label define GK1_A     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define GK2_A     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define GK1_B     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define GK2_B     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define GK1_C     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define GK2_C     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define GK1_D     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define GK2_D     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define GK1_E     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define GK2_E     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define GK1_F     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define GK2_F     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define GK2_G     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define GK3       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define GK4       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define GK4_A     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define GK5       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define GK6_A     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define GK6_B     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define GK6_C     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define GK6_D     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define GK7       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define GK7_A     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "NOT AT ALL" 2 "SOMEWHAT"
                       3 "VERY SERIOUS" ;
label define GK8       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NOT AT ALL" 1 "SOMEWHAT"
                       2 "VERY MUCH" ;
label define GK9       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NOT AT ALL" 1 "SOMEWHAT"
                       2 "VERY IMPORTANT" ;
label define GL1       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 99 "99 OR MORE" ;
label define GL1_A     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define GL2       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define GL2_A     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define GL2_B     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YOU WERE SICK"
                       2 "FRIEND/FAMILY MEMBER SICK"
                       9 "OTHER ILLNESS RELATED" 10 "CHILD CARE ARRANGE PROB"
                       11 "FAMILY MEMBER OBJECTED"
                       12 "FAMILY MEMBER DID NOT ATTEND W/YOU"
                       13 "FRIENDS PUT YOU DOWN TO SEEK HELP"
                       14 "STIGMA/COME TO PROG/DISCOURAGED YOU"
                       15 "FEAR OF DRUG TEST/BY EMPLOYER"
                       16 "YOU WERE IN SCHOOL" 19 "OTHER PRESSURES"
                       20 "DIFFICULTY W/TRANSPORTATION"
                       21 "DAILY SCHEDULE PREVENTED YOU"
                       22 "YOU WERE INCARCERATED"
                       23 "OTHER ACTIVITY KEPT FROM ATTENDING"
                       24 "COULD NOT ATTEND DURING PROG HRS"
                       25 "YOU DID NOT CARE FOR LOCATION"
                       26 "DISTANCE TO PROG WAS TOO FAR"
                       29 "OTHER ACCESS RELATED" 30 "TX/WAS NOT YOU EXPECTED"
                       31 "FELT/GET BETTER HELP ELSEWHERE"
                       32 "NOT TREATED IN A PROFE MANNER"
                       33 "TOO MUCH PAPERWORK" 34 "TOO HIGH FEES"
                       35 "HAD TO WAIT TOO LONG"
                       36 "NOT FEEL COMFORTABLE W/COUNSELOR"
                       37 "YOU SOUGHT OTHER HELP"
                       38 "RESENTMENT OVER DRUG TEST"
                       39 "OTHER DISSATISFACTION REASON"
                       40 "PROB IMPROVED ON ITS OWN"
                       41 "IMMEDIATE CRISIS WAS RESOLVED"
                       42 "DID NOT THINK YOU NEED TX" 49 "TX NOT HELPFUL"
                       50 "YOU FORGOT APPOINTMENT" 51 "YOU WERE DRUNK/HIGH"
                       52 "FELT OVERWHELMED"
                       53 "COUNSELOR CANCELLED APPOINTMENT"
                       54 "AFRAID OF BAD DRUG TEST RESULT" 59 "OTHER" ;
label define GL2_C     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define GL2_D     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YOU WERE SICK"
                       2 "FRIEND/FAMILY MEMBER SICK"
                       9 "OTHER ILLNESS RELATED" 10 "CHILD CARE ARRANGE PROB"
                       11 "FAMILY MEMBER OBJECTED"
                       12 "FAMILY MEMBER DID NOT ATTEND W/YOU"
                       13 "FRIENDS PUT YOU DOWN TO SEEK HELP"
                       14 "STIGMA/COME TO PROG/DISCOURAGED YOU"
                       15 "FEAR OF DRUG TEST/BY EMPLOYER"
                       16 "YOU WERE IN SCHOOL" 19 "OTHER PRESSURES"
                       20 "DIFFICULTY W/TRANSPORTATION"
                       21 "DAILY SCHEDULE PREVENTED YOU"
                       22 "YOU WERE INCARCERATED"
                       23 "OTHER ACTIVITY KEPT FROM ATTENDING"
                       24 "COULD NOT ATTEND DURING PROG HRS"
                       25 "YOU DID NOT CARE FOR LOCATION"
                       26 "DISTANCE TO PROG WAS TOO FAR"
                       29 "OTHER ACCESS RELATED" 30 "TX/WAS NOT YOU EXPECTED"
                       31 "FELT/GET BETTER HELP ELSEWHERE"
                       32 "NOT TREATED IN A PROFE MANNER"
                       33 "TOO MUCH PAPERWORK" 34 "TOO HIGH FEES"
                       35 "HAD TO WAIT TOO LONG"
                       36 "NOT FEEL COMFORTABLE W/COUNSELOR"
                       37 "YOU SOUGHT OTHER HELP"
                       38 "RESENTMENT OVER DRUG TEST"
                       39 "OTHER DISSATISFACTION REASON"
                       40 "PROB IMPROVED ON ITS OWN"
                       41 "IMMEDIATE CRISIS WAS RESOLVED"
                       42 "DID NOT THINK YOU NEED TX" 49 "TX NOT HELPFUL"
                       50 "YOU FORGOT APPOINTMENT" 51 "YOU WERE DRUNK/HIGH"
                       52 "FELT OVERWHELMED"
                       53 "COUNSELOR CANCELLED APPOINTMENT"
                       54 "AFRAID OF BAD DRUG TEST RESULT" 59 "OTHER" ;
label define GL2_E     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define GL2_F_1   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YOU WERE SICK"
                       2 "FRIEND/FAMILY MEMBER SICK"
                       9 "OTHER ILLNESS RELATED" 10 "CHILD CARE ARRANGE PROB"
                       11 "FAMILY MEMBER OBJECTED"
                       12 "FAMILY MEMBER DID NOT ATTEND W/YOU"
                       13 "FRIENDS PUT YOU DOWN TO SEEK HELP"
                       14 "STIGMA/COME TO PROG/DISCOURAGED YOU"
                       15 "FEAR OF DRUG TEST/BY EMPLOYER"
                       16 "YOU WERE IN SCHOOL" 19 "OTHER PRESSURES"
                       20 "DIFFICULTY W/TRANSPORTATION"
                       21 "DAILY SCHEDULE PREVENTED YOU"
                       22 "YOU WERE INCARCERATED"
                       23 "OTHER ACTIVITY KEPT FROM ATTENDING"
                       24 "COULD NOT ATTEND DURING PROG HRS"
                       25 "YOU DID NOT CARE FOR LOCATION"
                       26 "DISTANCE TO PROG WAS TOO FAR"
                       29 "OTHER ACCESS RELATED" 30 "TX/WAS NOT YOU EXPECTED"
                       31 "FELT/GET BETTER HELP ELSEWHERE"
                       32 "NOT TREATED IN A PROFE MANNER"
                       33 "TOO MUCH PAPERWORK" 34 "TOO HIGH FEES"
                       35 "HAD TO WAIT TOO LONG"
                       36 "NOT FEEL COMFORTABLE W/COUNSELOR"
                       37 "YOU SOUGHT OTHER HELP"
                       38 "RESENTMENT OVER DRUG TEST"
                       39 "OTHER DISSATISFACTION REASON"
                       40 "PROB IMPROVED ON ITS OWN"
                       41 "IMMEDIATE CRISIS WAS RESOLVED"
                       42 "DID NOT THINK YOU NEED TX" 49 "TX NOT HELPFUL"
                       50 "YOU FORGOT APPOINTMENT" 51 "YOU WERE DRUNK/HIGH"
                       52 "FELT OVERWHELMED"
                       53 "COUNSELOR CANCELLED APPOINTMENT"
                       54 "AFRAID OF BAD DRUG TEST RESULT" 59 "OTHER" ;
label define GL2_F_2   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YOU WERE SICK"
                       2 "FRIEND/FAMILY MEMBER SICK"
                       9 "OTHER ILLNESS RELATED" 10 "CHILD CARE ARRANGE PROB"
                       11 "FAMILY MEMBER OBJECTED"
                       12 "FAMILY MEMBER DID NOT ATTEND W/YOU"
                       13 "FRIENDS PUT YOU DOWN TO SEEK HELP"
                       14 "STIGMA/COME TO PROG/DISCOURAGED YOU"
                       15 "FEAR OF DRUG TEST/BY EMPLOYER"
                       16 "YOU WERE IN SCHOOL" 19 "OTHER PRESSURES"
                       20 "DIFFICULTY W/TRANSPORTATION"
                       21 "DAILY SCHEDULE PREVENTED YOU"
                       22 "YOU WERE INCARCERATED"
                       23 "OTHER ACTIVITY KEPT FROM ATTENDING"
                       24 "COULD NOT ATTEND DURING PROG HRS"
                       25 "YOU DID NOT CARE FOR LOCATION"
                       26 "DISTANCE TO PROG WAS TOO FAR"
                       29 "OTHER ACCESS RELATED" 30 "TX/WAS NOT YOU EXPECTED"
                       31 "FELT/GET BETTER HELP ELSEWHERE"
                       32 "NOT TREATED IN A PROFE MANNER"
                       33 "TOO MUCH PAPERWORK" 34 "TOO HIGH FEES"
                       35 "HAD TO WAIT TOO LONG"
                       36 "NOT FEEL COMFORTABLE W/COUNSELOR"
                       37 "YOU SOUGHT OTHER HELP"
                       38 "RESENTMENT OVER DRUG TEST"
                       39 "OTHER DISSATISFACTION REASON"
                       40 "PROB IMPROVED ON ITS OWN"
                       41 "IMMEDIATE CRISIS WAS RESOLVED"
                       42 "DID NOT THINK YOU NEED TX" 49 "TX NOT HELPFUL"
                       50 "YOU FORGOT APPOINTMENT" 51 "YOU WERE DRUNK/HIGH"
                       52 "FELT OVERWHELMED"
                       53 "COUNSELOR CANCELLED APPOINTMENT"
                       54 "AFRAID OF BAD DRUG TEST RESULT" 59 "OTHER" ;
label define GL2_F_3   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YOU WERE SICK"
                       2 "FRIEND/FAMILY MEMBER SICK"
                       9 "OTHER ILLNESS RELATED" 10 "CHILD CARE ARRANGE PROB"
                       11 "FAMILY MEMBER OBJECTED"
                       12 "FAMILY MEMBER DID NOT ATTEND W/YOU"
                       13 "FRIENDS PUT YOU DOWN TO SEEK HELP"
                       14 "STIGMA/COME TO PROG/DISCOURAGED YOU"
                       15 "FEAR OF DRUG TEST/BY EMPLOYER"
                       16 "YOU WERE IN SCHOOL" 19 "OTHER PRESSURES"
                       20 "DIFFICULTY W/TRANSPORTATION"
                       21 "DAILY SCHEDULE PREVENTED YOU"
                       22 "YOU WERE INCARCERATED"
                       23 "OTHER ACTIVITY KEPT FROM ATTENDING"
                       24 "COULD NOT ATTEND DURING PROG HRS"
                       25 "YOU DID NOT CARE FOR LOCATION"
                       26 "DISTANCE TO PROG WAS TOO FAR"
                       29 "OTHER ACCESS RELATED" 30 "TX/WAS NOT YOU EXPECTED"
                       31 "FELT/GET BETTER HELP ELSEWHERE"
                       32 "NOT TREATED IN A PROFE MANNER"
                       33 "TOO MUCH PAPERWORK" 34 "TOO HIGH FEES"
                       35 "HAD TO WAIT TOO LONG"
                       36 "NOT FEEL COMFORTABLE W/COUNSELOR"
                       37 "YOU SOUGHT OTHER HELP"
                       38 "RESENTMENT OVER DRUG TEST"
                       39 "OTHER DISSATISFACTION REASON"
                       40 "PROB IMPROVED ON ITS OWN"
                       41 "IMMEDIATE CRISIS WAS RESOLVED"
                       42 "DID NOT THINK YOU NEED TX" 49 "TX NOT HELPFUL"
                       50 "YOU FORGOT APPOINTMENT" 51 "YOU WERE DRUNK/HIGH"
                       52 "FELT OVERWHELMED"
                       53 "COUNSELOR CANCELLED APPOINTMENT"
                       54 "AFRAID OF BAD DRUG TEST RESULT" 59 "OTHER" ;
label define GL3       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define GL3_A     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 99 "99 OR MORE" ;
label define GL4       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define GL5       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define GL5_A_1   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "CIRCLED" ;
label define GL5_A_2   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 2 "CIRCLED" ;
label define GL5_A_3   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 3 "CIRCLED" ;
label define GL5_A_4   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 4 "CIRCLED" ;
label define GL5_B_1   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "CIRCLED" ;
label define GL5_B_2   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 2 "CIRCLED" ;
label define GL5_B_11  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 11 "CIRCLED" ;
label define GL5_B_12  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 12 "CIRCLED" ;
label define GL5_B_13  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 13 "CIRCLED" ;
label define GL5_B_21  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 21 "CIRCLED" ;
label define GL5_B_22  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 22 "CIRCLED" ;
label define GL5_B_23  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 23 "CIRCLED" ;
label define GL5_B_31  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 31 "CIRCLED" ;
label define GL5_B_71  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 71 "CIRCLED" ;
label define GL5_B_91  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 91 "CIRCLED" ;
label define GL5_C     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 99 "99 OR MORE" ;
label define GL5_D     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NOT AT ALL" 1 "SOMEWHAT"
                       2 "VERY MUCH" ;
label define GL6       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define GL6_A_A   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "CIRCLED" ;
label define GL6_A_B   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 2 "CIRCLED" ;
label define GL6_A_C   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 3 "CIRCLED" ;
label define GL6_A_D   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 4 "CIRCLED" ;
label define GL6_A_E   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 5 "CIRCLED" ;
label define GL6_A_F   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 6 "CIRCLED" ;
label define GL6_A_G   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 7 "CIRCLED" ;
label define GL6_A_H   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 8 "CIRCLED" ;
label define GL6_A_I   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 9 "CIRCLED" ;
label define GL6_A_J   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 10 "CIRCLED" ;
label define GL6_B_1   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM"
                       1 "COMMUNITY MENTAL HEALTH PROG"
                       2 "ALC REHABILITATION CENTER"
                       3 "28-DAY/OTHER SHORT TERM TX"
                       4 "THREAPEUTIC COMMUNITY" 5 "HALFWAY HOUSE"
                       6 "DETOXIFICATION TX UNIT"
                       7 "EMERGENCY ROOM/CRISIS CENTER" 8 "PRIV THERAPIST"
                       9 "OTHER OUTPATIENT TX" 10 "OTHER INPATIENT TX" ;
label define GL6_C_1   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define GL6_D_1   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "PROG" 2 "OUTSIDE SOURCE"
                       3 "SELF" ;
label define GL6_E_1   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NOT AT ALL" 1 "SOMEWHAT"
                       2 "VERY HELPFUL" ;
label define GL6_B_2   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM"
                       1 "COMMUNITY MENTAL HEALTH PROG"
                       2 "ALC REHABILITATION CENTER"
                       3 "28-DAY/OTHER SHORT TERM TX"
                       4 "THREAPEUTIC COMMUNITY" 5 "HALFWAY HOUSE"
                       6 "DETOXIFICATION TX UNIT"
                       7 "EMERGENCY ROOM/CRISIS CENTER" 8 "PRIV THERAPIST"
                       9 "OTHER OUTPATIENT TX" 10 "OTHER INPATIENT TX" ;
label define GL6_C_2   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define GL6_D_2   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "PROG" 2 "OUTSIDE SOURCE"
                       3 "SELF" ;
label define GL6_E_2   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NOT AT ALL" 1 "SOMEWHAT"
                       2 "VERY HELPFUL" ;
label define GL6_B_3   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM"
                       1 "COMMUNITY MENTAL HEALTH PROG"
                       2 "ALC REHABILITATION CENTER"
                       3 "28-DAY/OTHER SHORT TERM TX"
                       4 "THREAPEUTIC COMMUNITY" 5 "HALFWAY HOUSE"
                       6 "DETOXIFICATION TX UNIT"
                       7 "EMERGENCY ROOM/CRISIS CENTER" 8 "PRIV THERAPIST"
                       9 "OTHER OUTPATIENT TX" 10 "OTHER INPATIENT TX" ;
label define GL6_C_3   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define GL6_D_3   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "PROG" 2 "OUTSIDE SOURCE"
                       3 "SELF" ;
label define GL6_E_3   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NOT AT ALL" 1 "SOMEWHAT"
                       2 "VERY HELPFUL" ;
label define GL6_B_4   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM"
                       1 "COMMUNITY MENTAL HEALTH PROG"
                       2 "ALC REHABILITATION CENTER"
                       3 "28-DAY/OTHER SHORT TERM TX"
                       4 "THREAPEUTIC COMMUNITY" 5 "HALFWAY HOUSE"
                       6 "DETOXIFICATION TX UNIT"
                       7 "EMERGENCY ROOM/CRISIS CENTER" 8 "PRIV THERAPIST"
                       9 "OTHER OUTPATIENT TX" 10 "OTHER INPATIENT TX" ;
label define GL6_C_4   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 99 "99 OR MORE" ;
label define GL6_D_4   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "PROG" 2 "OUTSIDE SOURCE"
                       3 "SELF" ;
label define GL6_E_4   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NOT AT ALL" 1 "SOMEWHAT"
                       2 "VERY HELPFUL" ;
label define GL7       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define GL7_A_A   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "CIRCLED" ;
label define GL7_A_B   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 2 "CIRCLED" ;
label define GL7_A_C   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 3 "CIRCLED" ;
label define GL7_A_D   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 4 "CIRCLED" ;
label define GL7_A_E   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 5 "CIRCLED" ;
label define GL7_A_F   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 6 "CIRCLED" ;
label define GL7_A_G   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 7 "CIRCLED" ;
label define GL7_A_H   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 8 "CIRCLED" ;
label define GL7_A_I   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 9 "CIRCLED" ;
label define GL7_B_1   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM"
                       1 "PRIV PHYSICIAN/PSYCHI/PSYCHO"
                       2 "28-DAY/OTHER SHORT TERM TX"
                       3 "THERAPEUTIC COMMUNITY" 4 "HALFWAY HOUSE"
                       5 "METHADONE TREAT PROG"
                       6 "INTENSIVE OUTPT (NON-METHADONE)"
                       7 "DETOXIFICATION TX UNIT"
                       8 "OTHER OUTPATIENT DRUG TX"
                       9 "OTHER INPATIENT DRUG TX" ;
label define GL7_C_1   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 99 "99 OR MORE" ;
label define GL7_D_1   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "PROG" 2 "OUTSIDE SOURCE"
                       3 "SELF" ;
label define GL7_E_1   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NOT AT ALL" 1 "SOMEWHAT"
                       2 "VERY HELPFUL" ;
label define GL7_B_2   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM"
                       1 "PRIV PHYSICIAN/PSYCHI/PSYCHO"
                       2 "28-DAY/OTHER SHORT TERM TX"
                       3 "THERAPEUTIC COMMUNITY" 4 "HALFWAY HOUSE"
                       5 "METHADONE TREAT PROG"
                       6 "INTENSIVE OUTPT (NON-METHADONE)"
                       7 "DETOXIFICATION TX UNIT"
                       8 "OTHER OUTPATIENT DRUG TX"
                       9 "OTHER INPATIENT DRUG TX" ;
label define GL7_C_2   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define GL7_D_2   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "PROG" 2 "OUTSIDE SOURCE"
                       3 "SELF" ;
label define GL7_E_2   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NOT AT ALL" 1 "SOMEWHAT"
                       2 "VERY HELPFUL" ;
label define GL7_B_3   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM"
                       1 "PRIV PHYSICIAN/PSYCHI/PSYCHO"
                       2 "28-DAY/OTHER SHORT TERM TX"
                       3 "THERAPEUTIC COMMUNITY" 4 "HALFWAY HOUSE"
                       5 "METHADONE TREAT PROG"
                       6 "INTENSIVE OUTPT (NON-METHADONE)"
                       7 "DETOXIFICATION TX UNIT"
                       8 "OTHER OUTPATIENT DRUG TX"
                       9 "OTHER INPATIENT DRUG TX" ;
label define GL7_C_3   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define GL7_D_3   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "PROG" 2 "OUTSIDE SOURCE"
                       3 "SELF" ;
label define GL7_E_3   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NOT AT ALL" 1 "SOMEWHAT"
                       2 "VERY HELPFUL" ;
label define GL7_B_4   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM"
                       1 "PRIV PHYSICIAN/PSYCHI/PSYCHO"
                       2 "28-DAY/OTHER SHORT TERM TX"
                       3 "THERAPEUTIC COMMUNITY" 4 "HALFWAY HOUSE"
                       5 "METHADONE TREAT PROG" 6 "NON-METHADONE"
                       7 "DETOXIFICATION TX UNIT"
                       8 "OTHER OUTPATIENT DRUG TX"
                       9 "OTHER INPATIENT DRUG TX" ;
label define GL7_C_4   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define GL7_D_4   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "PROG" 2 "OUTSIDE SOURCE"
                       3 "SELF" ;
label define GL7_E_4   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NOT AT ALL" 1 "SOMEWHAT"
                       2 "VERY HELPFUL" ;
label define GL8_0     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "CIRCLED" ;
label define GL8_1     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "CIRCLED" ;
label define GL8_2     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 2 "CIRCLED" ;
label define GL8_11    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 11 "CIRCLED" ;
label define GL8_12    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 12 "CIRCLED" ;
label define GL8_13    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 13 "CIRCLED" ;
label define GL8_21    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 21 "CIRCLED" ;
label define GL8_22    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 22 "CIRCLED" ;
label define GL8_71    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 71 "CIRCLED" ;
label define GL8_91    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 91 "CIRCLED" ;
label define GL8_A_1   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NO ONE"
                       1 "PRIMARY/REG COUNSELOR" 2 "CASE MANAGER"
                       11 "OTHER COUNSELOR" 12 "OTHER CASE MANAGER"
                       13 "SOCIAL WORKER" 21 "PSYCHOLOGIST" 22 "PSYCHIATRIST"
                       71 "STAFF FROM ANOTHER AGENCY" 91 "OTHER" ;
label define GL8_A_2   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NO ONE"
                       1 "PRIMARY/REG COUNSELOR" 2 "CASE MANAGER"
                       11 "OTHER COUNSELOR" 12 "OTHER CASE MANAGER"
                       13 "SOCIAL WORKER" 21 "PSYCHOLOGIST" 22 "PSYCHIATRIST"
                       71 "STAFF FROM ANOTHER AGENCY" 91 "OTHER" ;
label define GL9       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 99 "99 OR MORE" ;
label define GL9_A     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define GL10      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define GL11      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NOT AT ALL" 1 "SOMEWHAT"
                       2 "A LOT" ;
label define GL12      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "POOR" 2 "FAIR" 3 "GOOD"
                       4 "EXCELLENT" ;
label define GL13_A    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NEVER" 1 "SOME SESSIONS"
                       2 "MOST SESSIONS" 3 "EVERY SESSION" ;
label define GL13_B    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NEVER" 1 "SOME SESSIONS"
                       2 "MOST SESSIONS" 3 "EVERY SESSION" ;
label define GL13_C    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NEVER" 1 "SOME SESSIONS"
                       2 "MOST SESSIONS" 3 "EVERY SESSION" ;
label define GL13_D    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NEVER" 1 "SOME SESSIONS"
                       2 "MOST SESSIONS" 3 "EVERY SESSION" ;
label define GL13_E    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NEVER" 1 "SOME SESSIONS"
                       2 "MOST SESSIONS" 3 "EVERY SESSION" ;
label define GL13_F    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NEVER" 1 "SOME SESSIONS"
                       2 "MOST SESSIONS" 3 "EVERY SESSION" ;
label define GL13_G    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NEVER" 1 "SOME SESSIONS"
                       2 "MOST SESSIONS" 3 "EVERY SESSION" ;
label define GL13_H    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NEVER" 1 "SOME SESSIONS"
                       2 "MOST SESSIONS" 3 "EVERY SESSION" ;
label define GL13_I    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NEVER" 1 "SOME SESSIONS"
                       2 "MOST SESSIONS" 3 "EVERY SESSION" ;
label define GL13_J    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NEVER" 1 "SOME SESSIONS"
                       2 "MOST SESSIONS" 3 "EVERY SESSION" ;
label define GL13_K    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define GL13_K_1  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NEVER" 1 "SOME SESSIONS"
                       2 "MOST SESSIONS" 3 "EVERY SESSION" ;
label define GL13_K_2  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NEVER" 1 "SOME SESSIONS"
                       2 "MOST SESSIONS" 3 "EVERY SESSION" ;
label define GL13_K_3  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NEVER" 1 "SOME SESSIONS"
                       2 "MOST SESSIONS" 3 "EVERY SESSION" ;
label define GL13_K_4  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NEVER" 1 "SOME SESSIONS"
                       2 "MOST SESSIONS" 3 "EVERY SESSION" ;
label define GL14_A    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NOT AT ALL" 1 "SOMEWHAT"
                       2 "VERY MUCH" ;
label define GL14_B    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NOT AT ALL" 1 "SOMEWHAT"
                       2 "VERY MUCH" ;
label define GL15_M    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define GL15_D    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define GL15_Y    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define GL16      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 99 "99 OR MORE" ;
label define GL16_A    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define GL17      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define GL18      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NOT AT ALL" 1 "SOMEWHAT"
                       2 "A LOT" ;
label define GL19      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "POOR" 2 "FAIR" 3 "GOOD"
                       4 "EXCELLENT" ;
label define GL20_A    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NEVER" 1 "SOME SESSIONS"
                       2 "MOST SESSIONS" 3 "EVERY SESSION" ;
label define GL20_B    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NEVER" 1 "SOME SESSIONS"
                       2 "MOST SESSIONS" 3 "EVERY SESSION" ;
label define GL20_C    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NEVER" 1 "SOME SESSIONS"
                       2 "MOST SESSIONS" 3 "EVERY SESSION" ;
label define GL20_D    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NEVER" 1 "SOME SESSIONS"
                       2 "MOST SESSIONS" 3 "EVERY SESSION" ;
label define GL20_E    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NEVER" 1 "SOME SESSIONS"
                       2 "MOST SESSIONS" 3 "EVERY SESSION" ;
label define GL20_F    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NEVER" 1 "SOME SESSIONS"
                       2 "MOST SESSIONS" 3 "EVERY SESSION" ;
label define GL20_G    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NEVER" 1 "SOME SESSIONS"
                       2 "MOST SESSIONS" 3 "EVERY SESSION" ;
label define GL20_H    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NEVER" 1 "SOME SESSIONS"
                       2 "MOST SESSIONS" 3 "EVERY SESSION" ;
label define GL20_I    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NEVER" 1 "SOME SESSIONS"
                       2 "MOST SESSIONS" 3 "EVERY SESSION" ;
label define GL20_J    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NEVER" 1 "SOME SESSIONS"
                       2 "MOST SESSIONS" 3 "EVERY SESSION" ;
label define GL20_K    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define GL20_K_1  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NEVER" 1 "SOME SESSIONS"
                       2 "MOST SESSIONS" 3 "EVERY SESSION" ;
label define GL20_K_2  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NEVER" 1 "SOME SESSIONS"
                       2 "MOST SESSIONS" 3 "EVERY SESSION" ;
label define GL20_K_3  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NEVER" 1 "SOME SESSIONS"
                       2 "MOST SESSIONS" 3 "EVERY SESSION" ;
label define GL20_K_4  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NEVER" 1 "SOME SESSIONS"
                       2 "MOST SESSIONS" 3 "EVERY SESSION" ;
label define GL21_A    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NOT AT ALL" 1 "SOMEWHAT"
                       2 "VERY MUCH" ;
label define GL21_B    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NOT AT ALL" 1 "SOMEWHAT"
                       2 "VERY MUCH" ;
label define GL22_M    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "JAN.-MARCH" 2 "APR.-JUNE"
                       3 "JULY-SEPT." 4 "OCT.-DEC." ;
label define GL22_Y    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define GL23      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define GL24      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define GL25      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM"
                       1 "PRIMARY/REGULAR COUNSELOR" 2 "CASE MANAGER"
                       11 "OTHER COUNSELOR" 12 "OTHER CASE MANAGER"
                       13 "SOCIAL WORKER" 21 "PSYCHOLOGIST" 22 "PSYCHIATRIST"
                       23 "NURSE" 71 "STAFF FROM OTHER AGENCY" 91 "OTHER" ;
label define GL26_M    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "JAN.-MARCH" 2 "APR.-JUNE"
                       3 "JULY-SEPT." 4 "OCT.-DEC." ;
label define GL26_Y    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define GL27      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO"
                       3 "DON'T KNOW" ;
label define GL28      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define GL28A_00  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "CIRCLED" ;
label define GL28A_01  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "CIRCLED" ;
label define GL28A_02  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 2 "CIRCLED" ;
label define GL28A_11  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 11 "CIRCLED" ;
label define GL28A_12  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 12 "CIRCLED" ;
label define GL28A_13  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 13 "CIRCLED" ;
label define GL28A_21  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 21 "CIRCLED" ;
label define GL28A_22  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 22 "CIRCLED" ;
label define GL28A_23  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 23 "CIRCLED" ;
label define GL28A_24  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 24 "CIRCLED" ;
label define GL28A_25  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 25 "CIRCLED" ;
label define GL28A_26  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 26 "CIRCLED" ;
label define GL28A_71  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 71 "CIRCLED" ;
label define GL28A_91  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 91 "CIRCLED" ;
label define GL28B     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "SELF"
                       1 "PRIMARY/REGULAR COUNSELOR" 2 "CASE MANAGER"
                       11 "OTHER COUNSELOR" 12 "OTHER CASE MANAGER"
                       13 "SOCIAL WORKER" 21 "PSYCHOLOGIST" 22 "PSYCHIATRIST"
                       23 "NURSE" 24 "VOCATIONAL COUNSELOR" 25 "PHYSICIAN"
                       26 "PHYSICIANS ASSISTANT"
                       71 "STAFF FROM ANOTHER AGENCY" 91 "OTHER" ;
label define GL29      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define GL29_A    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define GL29_B_A  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define GL29_B_B  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define GL29_B_C  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define GL29_B_D  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define GL29_B_E  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define GL29_B_F  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define GL29_B_G  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define GL29_B_H  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define GL29_B_I  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define GL29_B_J  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define GL29_B_K  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define GL29BK_1  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define GL29BK_2  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define GL29BK_3  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define GL29BK_4  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define GL29_C    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define GL29_D    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NONE" 1 "A LITTLE"
                       2 "A LOT" ;
label define GL29_E    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NOT AT ALL" 1 "SOMEWHAT"
                       2 "VERY HELPFUL" ;
label define GL30      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define GL30_A    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define GL30_B_M  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define GL30C_00  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "CIRCLED" ;
label define GL30C_01  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "CIRCLED" ;
label define GL30C_02  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 2 "CIRCLED" ;
label define GL30C_11  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 11 "CIRCLED" ;
label define GL30C_12  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 12 "CIRCLED" ;
label define GL30C_13  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 13 "CIRCLED" ;
label define GL30C_21  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 21 "CIRCLED" ;
label define GL30C_22  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 22 "CIRCLED" ;
label define GL30C_23  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 23 "CIRCLED" ;
label define GL30C_24  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 24 "CIRCLED" ;
label define GL30C_25  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 25 "CIRCLED" ;
label define GL30C_26  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 26 "CIRCLED" ;
label define GL30C_27  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 27 "CIRCLED" ;
label define GL30C_71  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 71 "CIRCLED" ;
label define GL30C_91  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 91 "CIRCLED" ;
label define GL30_D    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NONE" 1 "A LITTLE"
                       2 "A LOT" ;
label define GL31      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define GL32      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NOT AT ALL" 1 "SOMEWHAT"
                       2 "VERY MUCH" ;
label define GL33      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "DIFFICULT" 2 "EASY" ;
label define GL33_A    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "VERY DIFFICULT"
                       2 "SOMEWHAT DIFFICULT" ;
label define GL33_B    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "VERY EASY"
                       2 "SOMEWHAT EASY" ;
label define GL34      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NOT AT ALL" 1 "SOMEWHAT"
                       2 "VERY CLOSELY" ;
label define GL35      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NO PROB DRUG"
                       10 "ALCOHOL" 20 "MARIJUANA, HASHISH, THC"
                       30 "HALLUCINOGENS OR PSYCHEDELICS"
                       40 "COCAINE IN ANY FORM" 41 "CRACK" 50 "HEROIN"
                       51 "HEROIN AND COCAINE TOGETHER AT THE SAME"
                       60 "NARCOTICS OR OPIATES SUCH AS MORPHINE, C"
                       61 "STREET OR ILLEGAL METHADONE"
                       70 "DOWNERS OR DEPRESSANTS SUCH AS SEDATIVES"
                       80 "AMPHETAMINES OR OTHER STIMULANTS, SPEED,"
                       81 "METHAMPHETAMINES OR ICE" 90 "ANY OTHER DRUGS"
                       91 "INHALANTS, SUCH AS GLUE, GASOLINE, PAINT" ;
label define GL35_A    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define GL36      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "ABSTAIN/NEVER USE AGAIN"
                       2 "REDUCE YOUR LEVEL OF USE"
                       3 "QUIT FOR A WHILE BUT USE LATER"
                       4 "CONTINUE TO USE/BEFORE ENTER PROG"
                       5 "IF VOL: OTHER" ;
label define GL37      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NOT AT ALL" 1 "A LITTLE"
                       2 "A LOT" ;
label define GL38      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "SAME" 2 "DIFFERENT" ;
label define GL39      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define GL39_A    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define GL39_B    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "NOT AT ALL" 2 "SOMEWHAT"
                       3 "VERY MUCH" ;
label define GL40      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "NEVER DRINK"
                       2 "DRINK OCCASIONALLY" 3 "DRINK REGULARLY" ;
label define GL41      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define GL41_A    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM"
                       1 "QUIT FOR A WHILE/START LATER"
                       2 "QUIT/EVEN THOUGH YOU SLIP FEW TIME"
                       3 "QUIT/NEVER DRINK ALC AGAIN" ;
label define GL42      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM"
                       1 "CONTINUE TO DRINK LIKE BEFORE"
                       2 "DRINK MORE ALC THAN BEFORE"
                       3 "CUT BACK ON DRINKING/>CONTROLLED"
                       4 "QUIT FOR A WHILE/START LATER" 5 "IF VOL: OTHER" ;
label define GL43      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NOT AT ALL" 1 "A LITTLE"
                       2 "A LOT" ;
label define GL44_A    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "STRONGLY DISAGREE"
                       2 "SOMEWHAT DISAGREE" 3 "SOMEWHAT AGREE"
                       4 "STRONGLY AGREE" ;
label define GL44_B    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "STRONGLY DISAGREE"
                       2 "SOMEWHAT DISAGREE" 3 "SOMEWHAT AGREE"
                       4 "STRONGLY AGREE" ;
label define GL45_A    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "STRONGLY DISAGREE"
                       2 "SOMEWHAT DISAGREE" 3 "SOMEWHAT AGREE"
                       4 "STRONGLY AGREE" ;
label define GL45_B    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "STRONGLY DISAGREE"
                       2 "SOMEWHAT DISAGREE" 3 "SOMEWHAT AGREE"
                       4 "STRONGLY AGREE" ;
label define GL45_C    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "STRONGLY DISAGREE"
                       2 "SOMEWHAT DISAGREE" 3 "SOMEWHAT AGREE"
                       4 "STRONGLY AGREE" ;
label define GL45_D    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "STRONGLY DISAGREE"
                       2 "SOMEWHAT DISAGREE" 3 "SOMEWHAT AGREE"
                       4 "STRONGLY AGREE" ;
label define GL45_E    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "STRONGLY DISAGREE"
                       2 "SOMEWHAT DISAGREE" 3 "SOMEWHAT AGREE"
                       4 "STRONGLY AGREE" ;
label define GL45_F    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "STRONGLY DISAGREE"
                       2 "SOMEWHAT DISAGREE" 3 "SOMEWHAT AGREE"
                       4 "STRONGLY AGREE" ;
label define GL45_G    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "STRONGLY DISAGREE"
                       2 "SOMEWHAT DISAGREE" 3 "SOMEWHAT AGREE"
                       4 "STRONGLY AGREE" ;
label define GL45_H    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "STRONGLY DISAGREE"
                       2 "SOMEWHAT DISAGREE" 3 "SOMEWHAT AGREE"
                       4 "STRONGLY AGREE" ;
label define GL45_I    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "STRONGLY DISAGREE"
                       2 "SOMEWHAT DISAGREE" 3 "SOMEWHAT AGREE"
                       4 "STRONGLY AGREE" ;
label define GL45_J    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "STRONGLY DISAGREE"
                       2 "SOMEWHAT DISAGREE" 3 "SOMEWHAT AGREE"
                       4 "STRONGLY AGREE" ;
label define GL45_K    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "STRONGLY DISAGREE"
                       2 "SOMEWHAT DISAGREE" 3 "SOMEWHAT AGREE"
                       4 "STRONGLY AGREE" ;
label define GL45_L    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "STRONGLY DISAGREE"
                       2 "SOMEWHAT DISAGREE" 3 "SOMEWHAT AGREE"
                       4 "STRONGLY AGREE" ;
label define GL46      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define GL47_01   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "CIRCLED" ;
label define GL47_02   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 2 "CIRCLED" ;
label define GL47_11   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 11 "CIRCLED" ;
label define GL47_12   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 12 "CIRCLED" ;
label define GL47_13   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 13 "CIRCLED" ;
label define GL47_21   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 21 "CIRCLED" ;
label define GL47_22   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 22 "CIRCLED" ;
label define GL47_23   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 23 "CIRCLED" ;
label define GL47_71   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 71 "CIRCLED" ;
label define GL47_91   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 91 "CIRCLED" ;
label define GL48_A    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NEVER" 1 "SOME SESSIONS"
                       2 "MOST SESSIONS" 3 "EVERY SESSION" ;
label define GL48_B    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NEVER" 1 "SOME SESSIONS"
                       2 "MOST SESSIONS" 3 "EVERY SESSION" ;
label define GL48_C    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NEVER" 1 "SOME SESSIONS"
                       2 "MOST SESSIONS" 3 "EVERY SESSION" ;
label define GL48_D    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NEVER" 1 "SOME SESSIONS"
                       2 "MOST SESSIONS" 3 "EVERY SESSION" ;
label define GL48_E    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NEVER" 1 "SOME SESSIONS"
                       2 "MOST SESSIONS" 3 "EVERY SESSION" ;
label define GL48_F    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NEVER" 1 "SOME SESSIONS"
                       2 "MOST SESSIONS" 3 "EVERY SESSION" ;
label define GL48_G    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NEVER" 1 "SOME SESSIONS"
                       2 "MOST SESSIONS" 3 "EVERY SESSION" ;
label define GL48_H    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NEVER" 1 "SOME SESSIONS"
                       2 "MOST SESSIONS" 3 "EVERY SESSION" ;
label define GL48_I    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NEVER" 1 "SOME SESSIONS"
                       2 "MOST SESSIONS" 3 "EVERY SESSION" ;
label define GL48_J    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NEVER" 1 "SOME SESSIONS"
                       2 "MOST SESSIONS" 3 "EVERY SESSION" ;
label define GL48_K    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define GL48_K_1  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NEVER" 1 "SOME SESSIONS"
                       2 "MOST SESSIONS" 3 "EVERY SESSION" ;
label define GL48_K_2  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NEVER" 1 "SOME SESSIONS"
                       2 "MOST SESSIONS" 3 "EVERY SESSION" ;
label define GL48_K_3  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NEVER" 1 "SOME SESSIONS"
                       2 "MOST SESSIONS" 3 "EVERY SESSION" ;
label define GL48_K_4  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NEVER" 1 "SOME SESSIONS"
                       2 "MOST SESSIONS" 3 "EVERY SESSION" ;
label define GL49_A    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NOT AT ALL" 1 "SOMEWHAT"
                       2 "VERY MUCH" ;
label define GL49_B    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NOT AT ALL" 1 "SOMEWHAT"
                       2 "VERY MUCH" ;
label define GL50      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 99 "99 OR MORE" ;
label define GL50_A    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 999 "999 OR MORE" ;
label define GL51      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NOT AT ALL" 1 "A LITTLE"
                       2 "A LOT" ;
label define GL52      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "POOR" 2 "FAIR" 3 "GOOD"
                       4 "EXCELLENT" ;
label define GL55      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define GL56      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define GL57      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NOT AT ALL HELPFUL"
                       1 "SOMEWHAT HELPFUL" 2 "VERY HELPFUL" ;
label define GL58      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define GL58_A_1  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "CIRCLED" ;
label define GL58_A_2  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 2 "CIRCLED" ;
label define GL58_A_3  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 3 "CIRCLED" ;
label define GL58_A_4  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 4 "CIRCLED" ;
label define GL58_B    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define GL58_C_M  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define GL58_C_D  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define GL58_D    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "AT THIS PROG"
                       2 "AT SOME OTHER PLACE" 3 "BOTH" ;
label define GL59_A    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NOT AT ALL" 1 "SOMEWHAT"
                       2 "VERY MUCH" ;
label define GL59_B    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NOT AT ALL" 1 "SOMEWHAT"
                       2 "VERY MUCH" ;
label define GL60      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NOT AT ALL" 1 "SOMEWHAT"
                       2 "VERY MUCH" ;
label define GL63      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define GL64      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define GL65_01   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "CIRCLED" ;
label define GL65_02   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 2 "CIRCLED" ;
label define GL65_11   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 11 "CIRCLED" ;
label define GL65_12   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 12 "CIRCLED" ;
label define GL65_13   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 13 "CIRCLED" ;
label define GL65_21   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 21 "CIRCLED" ;
label define GL65_22   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 22 "CIRCLED" ;
label define GL65_23   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 23 "CIRCLED" ;
label define GL65_28   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 28 "CIRCLED" ;
label define GL65_71   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 71 "CIRCLED" ;
label define GL65_91   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 91 "CIRCLED" ;
label define GL65_A_1  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM"
                       1 "PRIMARY/REGULAR COUNSELOR" 2 "CASE MANAGER"
                       11 "OTHER COUNSELOR" 12 "OTHER CASE MANAGER"
                       13 "SOCIAL WORKER" 21 "PSYCHOLOGIST" 22 "PSYCHIATRIST"
                       23 "NURSE" 28 "CERTIFIED FAMILY COUNSELOR"
                       71 "STAFF FROM ANOTHER AGENCY" 91 "OTHER" ;
label define GL65_A_2  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM"
                       1 "PRIMARY/REGULAR COUNSELOR" 2 "CASE MANAGER"
                       11 "OTHER COUNSELOR" 12 "OTHER CASE MANAGER"
                       13 "SOCIAL WORKER" 21 "PSYCHOLOGIST" 22 "PSYCHIATRIST"
                       23 "NURSE" 28 "CERTIFIED FAMILY COUNSELOR"
                       71 "STAFF FROM ANOTHER AGENCY" 91 "OTHER" ;
label define GL66      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "INDIVIDUAL" 2 "GROUP"
                       3 "BOTH" ;
label define GL66_A    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define GL66_B    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define GL66_C_1  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "CIRCLED" ;
label define GL66_C_2  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 2 "CIRCLED" ;
label define GL66_C_3  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 3 "CIRCLED" ;
label define GL66_C_4  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 4 "CIRCLED" ;
label define GL66_C_5  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 5 "CIRCLED" ;
label define GL66_C_6  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 6 "CIRCLED" ;
label define GL66_C_7  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 7 "CIRCLED" ;
label define GL66_C_8  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 8 "CIRCLED" ;
label define GL66_C_9  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 9 "CIRCLED" ;
label define GL66_D    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NOT AT ALL HELPFUL"
                       1 "SOMEWHAT" 2 "VERY HELPFUL" ;
label define GL66_E    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define GL66_F    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define GL66_G_1  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "CIRCLED" ;
label define GL66_G_2  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 2 "CIRCLED" ;
label define GL66_G_3  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 3 "CIRCLED" ;
label define GL66_G_4  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 4 "CIRCLED" ;
label define GL66_G_5  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 5 "CIRCLED" ;
label define GL66_H_1  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "CIRCLED" ;
label define GL66_H_2  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 2 "CIRCLED" ;
label define GL66_H_3  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 3 "CIRCLED" ;
label define GL66_H_4  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 4 "CIRCLED" ;
label define GL66_H_5  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 5 "CIRCLED" ;
label define GL66_H_6  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 6 "CIRCLED" ;
label define GL66_H_7  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 7 "CIRCLED" ;
label define GL66_H_8  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 8 "CIRCLED" ;
label define GL66_H_9  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 9 "CIRCLED" ;
label define GL66_I    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NOT AT ALL HELPFUL"
                       1 "SOMEWHAT HELPFUL" 2 "VERY HELPFUL" ;
label define GL67      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "INDIVIDUAL" 2 "GROUP"
                       3 "BOTH" ;
label define GL67_A    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define GL67_B    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define GL67_C_1  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "CIRCLED" ;
label define GL67_C_2  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 2 "CIRCLED" ;
label define GL67_C_3  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 3 "CIRCLED" ;
label define GL67_C_4  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 4 "CIRCLED" ;
label define GL67_C_5  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 5 "CIRCLED" ;
label define GL67_C_6  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 6 "CIRCLED" ;
label define GL67_C_7  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 7 "CIRCLED" ;
label define GL67_C_8  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 8 "CIRCLED" ;
label define GL67_C_9  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 9 "CIRCLED" ;
label define GL67_D    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NOT AT ALL" 1 "SOMEWHAT"
                       2 "VERY HELPFUL" ;
label define GL67_E    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define GL67_F    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define GL67_G_1  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "CIRCLED" ;
label define GL67_G_2  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 2 "CIRCLED" ;
label define GL67_G_3  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 3 "CIRCLED" ;
label define GL67_G_4  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 4 "CIRCLED" ;
label define GL67_G_5  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 5 "CIRCLED" ;
label define GL67_H_1  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "CIRCLED" ;
label define GL67_H_2  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 2 "CIRCLED" ;
label define GL67_H_3  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 3 "CIRCLED" ;
label define GL67_H_4  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 4 "CIRCLED" ;
label define GL67_H_5  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 5 "CIRCLED" ;
label define GL67_H_6  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 6 "CIRCLED" ;
label define GL67_H_7  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 7 "CIRCLED" ;
label define GL67_H_8  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 8 "CIRCLED" ;
label define GL67_H_9  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 9 "CIRCLED" ;
label define GL67_I    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NOT AT ALL" 1 "SOMEWHAT"
                       2 "VERY" ;
label define GL68      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define GL68A_1   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "CIRCLED" ;
label define GL68A_2   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 2 "CIRCLED" ;
label define GL68A_3   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 3 "CIRCLED" ;
label define GL68A_4   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 4 "CIRCLED" ;
label define GL68A_5   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 5 "CIRCLED" ;
label define GL68A_6   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 6 "CIRCLED" ;
label define GL68B_1   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM"
                       1 "A COMMUNITY MENTAL HEALTH SERVICE"
                       2 "A PRIV PSYCHIATRIC HOSPITAL"
                       3 "ANY OTHER HOSPITAL OR FACILITY"
                       4 "AN EMERGENCY ROOM OR CRISIS CENTER"
                       5 "PRIV THERAPIST" 6 "OTHER" ;
label define GL68C_1   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "PROG" 2 "SOMEONE ELSE"
                       3 "SELF" ;
label define GL68D_1   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 99 "99 OR MORE" ;
label define GL68E_1   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NOT AT ALL" 1 "SOMEWHAT"
                       2 "VERY HELPFUL" ;
label define GL68F1_1  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "CIRCLED" ;
label define GL68F1_2  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 2 "CIRCLED" ;
label define GL68F111  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 11 "CIRCLED" ;
label define GL68F112  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 12 "CIRCLED" ;
label define GL68F113  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 13 "CIRCLED" ;
label define GL68F121  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 21 "CIRCLED" ;
label define GL68F122  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 22 "CIRCLED" ;
label define GL68F123  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 23 "CIRCLED" ;
label define GL68F128  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 28 "CIRCLED" ;
label define GL68F171  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 71 "CIRCLED" ;
label define GL68F191  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 91 "CIRCLED" ;
label define GL68G_1   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM"
                       1 "PRIMARY/REGULAR COUNSELOR" 2 "CASE MANAGER"
                       11 "OTHER COUNSELOR" 12 "OTHER CASE MANAGER"
                       13 "SOCIAL WORKER" 21 "PSYCHOLOGIST" 22 "PSYCHIATRIST"
                       23 "NURSE" 28 "CERTIFIED FAMILY COUNSELOR"
                       71 "STAFF FROM ANOTHER AGENCY" 91 "OTHER" ;
label define GL68B_2   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM"
                       1 "A COMMUNITY MENTAL HEALTH SERVICE"
                       2 "A PRIV PSYCHIATRIC HOSPITAL"
                       3 "ANY OTHER HOSPITAL OR FACILITY"
                       4 "AN EMERGENCY ROOM OR CRISIS CENTER"
                       5 "PRIV THERAPIST" 6 "OTHER" ;
label define GL68C_2   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "PROG" 2 "SOMEONE ELSE"
                       3 "SELF" ;
label define GL68D_2   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define GL68E_2   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NOT AT ALL" 1 "SOMEWHAT"
                       2 "VERY HELPFUL" ;
label define GL68F2_1  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "CIRCLED" ;
label define GL68F2_2  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 2 "CIRCLED" ;
label define GL68F211  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 11 "CIRCLED" ;
label define GL68F212  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 12 "CIRCLED" ;
label define GL68F213  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 13 "CIRCLED" ;
label define GL68F221  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 21 "CIRCLED" ;
label define GL68F222  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 22 "CIRCLED" ;
label define GL68F223  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 23 "CIRCLED" ;
label define GL68F228  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 28 "CIRCLED" ;
label define GL68F271  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 71 "CIRCLED" ;
label define GL68F291  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 91 "CIRCLED" ;
label define GL68G_2   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM"
                       1 "PRIMARY/REGULAR COUNSELOR" 2 "CASE MANAGER"
                       11 "OTHER COUNSELOR" 12 "OTHER CASE MANAGER"
                       13 "SOCIAL WORKER" 21 "PSYCHOLOGIST" 22 "PSYCHIATRIST"
                       23 "NURSE" 28 "CERTIFIED FAMILY COUNSELOR"
                       71 "STAFF FROM ANOTHER AGENCY" 91 "OTHER" ;
label define GL69      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define GL69_A_1  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "CIRCLED" ;
label define GL69_B_1  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define GL69_A_2  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 2 "CIRCLED" ;
label define GL69_B_2  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define GL69_A_3  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 3 "CIRCLED" ;
label define GL69_B_3  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define GL69_A_4  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 4 "CIRCLED" ;
label define GL69_B_4  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define GL69_A_5  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 5 "CIRCLED" ;
label define GL69_B_5  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define GL70      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define GL71      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define GL72_01   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "CIRCLED" ;
label define GL72_02   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 2 "CIRCLED" ;
label define GL72_22   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 22 "CIRCLED" ;
label define GL72_23   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 23 "CIRCLED" ;
label define GL72_24   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 24 "CIRCLED" ;
label define GL72_25   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 25 "CIRCLED" ;
label define GL72_26   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 26 "CIRCLED" ;
label define GL72_71   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 71 "CIRCLED" ;
label define GL72_91   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 91 "CIRCLED" ;
label define GL72_A1   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM"
                       1 "PRIMARY/REGULAR COUNSELOR" 2 "CASE MANAGER"
                       22 "PSYCHIATRIST" 23 "NURSE" 24 "PHYSICIAN"
                       25 "PHYSICIANS ASSISTANT" 26 "DENTIST"
                       71 "STAFF FROM ANOTHER AGENCY" 91 "OTHER" ;
label define GL72_A2   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM"
                       1 "PRIMARY/REGULAR COUNSELOR" 2 "CASE MANAGER"
                       22 "PSYCHIATRIST" 23 "NURSE" 24 "PHYSICIAN"
                       25 "PHYSICIANS ASSISTANT" 26 "DENTIST"
                       71 "STAFF FROM ANOTHER AGENCY" 91 "OTHER" ;
label define GL73      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define GL73_A    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define GL73_B01  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "CIRCLED" ;
label define GL73_B02  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 2 "CIRCLED" ;
label define GL73_B03  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 3 "CIRCLED" ;
label define GL73_B04  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 4 "CIRCLED" ;
label define GL73_B05  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 5 "CIRCLED" ;
label define GL73_B06  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 6 "CIRCLED" ;
label define GL73_B07  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 7 "CIRCLED" ;
label define GL73_B08  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 8 "CIRCLED" ;
label define GL73_B09  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 9 "CIRCLED" ;
label define GL73_C    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NOT AT ALL" 1 "SOMEWHAT"
                       2 "VERY HELPFUL" ;
label define GL74      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define GL74_A    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define GL74_B01  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "CIRCLED" ;
label define GL74_B02  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 2 "CIRCLED" ;
label define GL74_B03  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 3 "CIRCLED" ;
label define GL74_B04  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 4 "CIRCLED" ;
label define GL74_B05  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 5 "CIRCLED" ;
label define GL74_B06  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 6 "CIRCLED" ;
label define GL74_B07  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 7 "CIRCLED" ;
label define GL74_B08  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 8 "CIRCLED" ;
label define GL74_B09  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 9 "CIRCLED" ;
label define GL74_C    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NOT AT ALL HELPFUL"
                       1 "SOMEWHAT HELPFUL" 2 "VERY HELPFUL" ;
label define GL75      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define GL75_A_1  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "CIRCLED" ;
label define GL75_A_2  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 2 "CIRCLED" ;
label define GL75_A_3  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 3 "CIRCLED" ;
label define GL75_A_4  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 4 "CIRCLED" ;
label define GL75_A_5  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 5 "CIRCLED" ;
label define GL75_A_6  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 6 "CIRCLED" ;
label define GL75B_1   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM"
                       1 "PRIV PHYSICIAN OR DENTIST"
                       2 "HOSPITAL OR PUB HEALTH CLINIC"
                       3 "MILITARY OR VA HOSPITAL OR CLINIC"
                       4 "HEALTH COOPERATIVE" 5 "OTHER MEDICAL" 6 "OTHER" ;
label define GL75C_1   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "PROG" 2 "SOMEONE ELSE"
                       3 "SELF" ;
label define GL75D_1   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define GL75E_1   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NOT AT ALL" 1 "SOMEWHAT"
                       2 "VERY HELPFUL" ;
label define GL75F101  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "CIRCLED" ;
label define GL75F102  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 2 "CIRCLED" ;
label define GL75F122  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 22 "CIRCLED" ;
label define GL75F123  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 23 "CIRCLED" ;
label define GL75F124  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 24 "CIRCLED" ;
label define GL75F125  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 25 "CIRCLED" ;
label define GL75F126  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 26 "CIRCLED" ;
label define GL75F171  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 71 "CIRCLED" ;
label define GL75F191  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 91 "CIRCLED" ;
label define GL75G_1   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM"
                       1 "PRIMARY/REGULAR COUNSELOR" 2 "CASE MANAGER"
                       22 "PSYCHIATRIST" 23 "NURSE" 24 "PHYSICIAN"
                       25 "PHYSICIANS ASSISTANT" 26 "DENTIST"
                       71 "STAFF FROM ANOTHER AGENCY" 91 "OTHER" ;
label define GL75B_2   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM"
                       1 "PRIV PHYSICIAN OR DENTIST"
                       2 "HOSPITAL OR PUB HEALTH CLINIC"
                       3 "MILITARY OR VA HOSPITAL OR CLINIC"
                       4 "HEALTH COOPERATIVE" 5 "OTHER MEDICAL" 6 "OTHER" ;
label define GL75C_2   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "PROG" 2 "SOMEONE ELSE"
                       3 "SELF" ;
label define GL75D_2   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define GL75E_2   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NOT AT ALL" 1 "SOMEWHAT"
                       2 "VERY HELPFUL" ;
label define GL75F201  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "CIRCLED" ;
label define GL75F202  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 2 "CIRCLED" ;
label define GL75F222  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 22 "CIRCLED" ;
label define GL75F223  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 23 "CIRCLED" ;
label define GL75F224  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 24 "CIRCLED" ;
label define GL75F225  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 25 "CIRCLED" ;
label define GL75F226  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 26 "CIRCLED" ;
label define GL75F271  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 71 "CIRCLED" ;
label define GL75F291  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 91 "CIRCLED" ;
label define GL75G_2   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM"
                       1 "PRIMARY/REGULAR COUNSELOR" 2 "CASE MANAGER"
                       22 "PSYCHIATRIST" 23 "NURSE" 24 "PHYSICIAN"
                       25 "PHYSICIANS ASSISTANT" 26 "DENTIST"
                       71 "STAFF FROM ANOTHER AGENCY" 91 "OTHER" ;
label define GL76      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define GL76_A_1  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "CIRCLED" ;
label define GL76_A_2  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 2 "CIRCLED" ;
label define GL76_A_3  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 3 "CIRCLED" ;
label define GL76_A_4  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 4 "CIRCLED" ;
label define GL77      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define GL77_A    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define GL77B_01  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "CIRCLED" ;
label define GL77B_02  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 2 "CIRCLED" ;
label define GL77B_11  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 11 "CIRCLED" ;
label define GL77B_12  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 12 "CIRCLED" ;
label define GL77B_13  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 13 "CIRCLED" ;
label define GL77B_21  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 21 "CIRCLED" ;
label define GL77B_22  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 22 "CIRCLED" ;
label define GL77B_23  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 23 "CIRCLED" ;
label define GL77B_24  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 24 "CIRCLED" ;
label define GL77B_25  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 25 "CIRCLED" ;
label define GL77B_26  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 26 "CIRCLED" ;
label define GL77B_27  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 27 "CIRCLED" ;
label define GL77B_28  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 28 "CIRCLED" ;
label define GL77B_71  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 71 "CIRCLED" ;
label define GL77B_91  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 91 "CIRCLED" ;
label define GL77_C_1  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "CIRCLED" ;
label define GL77_C_2  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 2 "CIRCLED" ;
label define GL77_C_3  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 3 "CIRCLED" ;
label define GL77_C_4  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 4 "CIRCLED" ;
label define GL77_C_5  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 5 "CIRCLED" ;
label define GL77_C_6  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 6 "CIRCLED" ;
label define GL77_C_7  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 7 "CIRCLED" ;
label define GL77_C_8  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 8 "CIRCLED" ;
label define GL78      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define GL79      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define GL80_01   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "CIRCLED" ;
label define GL80_02   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 2 "CIRCLED" ;
label define GL80_11   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 11 "CIRCLED" ;
label define GL80_12   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 12 "CIRCLED" ;
label define GL80_13   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 13 "CIRCLED" ;
label define GL80_21   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 21 "CIRCLED" ;
label define GL80_22   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 22 "CIRCLED" ;
label define GL80_23   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 23 "CIRCLED" ;
label define GL80_28   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 28 "CIRCLED" ;
label define GL80_71   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 71 "CIRCLED" ;
label define GL80_91   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 91 "CIRCLED" ;
label define GL80_A1   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM"
                       1 "PRIMARY/REGULAR COUNSELOR" 2 "CASE MANAGER"
                       11 "OTHER COUSELOR" 12 "OTHER CASE MANAGER"
                       13 "SOCIAL WORKER" 21 "PSYCHOLOGIST" 22 "PSYCHIATRIST"
                       23 "NURSE" 28 "CERTIFIED FAMILY COUNSELOR"
                       71 "STAFF FROM ANOTHER AGENCY" 91 "OTHER" ;
label define GL80_A2   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM"
                       1 "PRIMARY/REGULAR COUNSELOR" 2 "CASE MANAGER"
                       11 "OTHER COUSELOR" 12 "OTHER CASE MANAGER"
                       13 "SOCIAL WORKER" 21 "PSYCHOLOGIST" 22 "PSYCHIATRIST"
                       23 "NURSE" 28 "CERTIFIED FAMILY COUNSELOR"
                       71 "STAFF FROM ANOTHER AGENCY" 91 "OTHER" ;
label define GL81_01   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "CIRCLED" ;
label define GL81_02   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 2 "CIRCLED" ;
label define GL81_03   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 3 "CIRCLED" ;
label define GL81_A    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define GL81_B    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define GL81_C_1  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "CIRCLED" ;
label define GL81_C_2  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 2 "CIRCLED" ;
label define GL81_C_3  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 3 "CIRCLED" ;
label define GL81_C_4  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 4 "CIRCLED" ;
label define GL81_C_5  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 5 "CIRCLED" ;
label define GL81_C_6  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 6 "CIRCLED" ;
label define GL81_D    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NOT AT ALL" 1 "SOMEWHAT"
                       2 "VERY HELPFUL" ;
label define GL81_E    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define GL81_F    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define GL81_G_1  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "CIRCLED" ;
label define GL81_G_2  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 2 "CIRCLED" ;
label define GL81_G_3  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 3 "CIRCLED" ;
label define GL81_G_4  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 4 "CIRCLED" ;
label define GL81_G_5  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 5 "CIRCLED" ;
label define GL81_H_1  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "CIRCLED" ;
label define GL81_H_2  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 2 "CIRCLED" ;
label define GL81_H_3  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 3 "CIRCLED" ;
label define GL81_H_4  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 4 "CIRCLED" ;
label define GL81_H_5  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 5 "CIRCLED" ;
label define GL81_H_6  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 6 "CIRCLED" ;
label define GL81_I    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NOT AT ALL" 1 "SOMEWHAT"
                       2 "VERY HELPFUL" ;
label define GL81_J    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define GL81_K_1  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "CIRCLED" ;
label define GL81_K_2  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 2 "CIRCLED" ;
label define GL81_K_3  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 3 "CIRCLED" ;
label define GL81_K_4  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 4 "CIRCLED" ;
label define GL81_K_5  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 5 "CIRCLED" ;
label define GL81_K_6  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 6 "CIRCLED" ;
label define GL81_K_7  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 7 "CIRCLED" ;
label define GL81_K_8  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 8 "CIRCLED" ;
label define GL81_L_1  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "CIRCLED" ;
label define GL81_L_2  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 2 "CIRCLED" ;
label define GL81_L_3  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 3 "CIRCLED" ;
label define GL81_L_4  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 4 "CIRCLED" ;
label define GL81_L_5  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 5 "CIRCLED" ;
label define GL81_L_6  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 6 "CIRCLED" ;
label define GL81_M    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NOT AT ALL" 1 "SOMEWHAT"
                       2 "VERY HELPFUL" ;
label define GL82_01   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "CIRCLED" ;
label define GL82_02   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 2 "CIRCLED" ;
label define GL82_03   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 3 "CIRCLED" ;
label define GL82_A    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define GL82_B    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define GL82_C_1  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "CIRCLED" ;
label define GL82_C_2  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 2 "CIRCLED" ;
label define GL82_C_3  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 3 "CIRCLED" ;
label define GL82_C_4  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 4 "CIRCLED" ;
label define GL82_C_5  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 5 "CIRCLED" ;
label define GL82_C_6  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 6 "CIRCLED" ;
label define GL82_D    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NOT AT ALL" 1 "SOMEWHAT"
                       2 "VERY HELPFUL" ;
label define GL82_E    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define GL82_F    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define GL82_G_1  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "CIRCLED" ;
label define GL82_G_2  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 2 "CIRCLED" ;
label define GL82_G_3  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 3 "CIRCLED" ;
label define GL82_G_4  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 4 "CIRCLED" ;
label define GL82_G_5  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 5 "CIRCLED" ;
label define GL82_H_1  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "CIRCLED" ;
label define GL82_H_2  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 2 "CIRCLED" ;
label define GL82_H_3  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 3 "CIRCLED" ;
label define GL82_H_4  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 4 "CIRCLED" ;
label define GL82_H_5  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 5 "CIRCLED" ;
label define GL82_H_6  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 6 "CIRCLED" ;
label define GL82_I    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NOT AT ALL" 1 "SOMEWHAT"
                       2 "VERY HELPFUL" ;
label define GL82_J    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define GL82_K_1  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "CIRCLED" ;
label define GL82_K_2  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 2 "CIRCLED" ;
label define GL82_K_3  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 3 "CIRCLED" ;
label define GL82_K_4  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 4 "CIRCLED" ;
label define GL82_K_5  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 5 "CIRCLED" ;
label define GL82_K_6  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 6 "CIRCLED" ;
label define GL82_K_7  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 7 "CIRCLED" ;
label define GL82_K_8  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 8 "CIRCLED" ;
label define GL82_L_1  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "CIRCLED" ;
label define GL82_L_2  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 2 "CIRCLED" ;
label define GL82_L_3  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 3 "CIRCLED" ;
label define GL82_L_4  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 4 "CIRCLED" ;
label define GL82_L_5  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 5 "CIRCLED" ;
label define GL82_L_6  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 6 "CIRCLED" ;
label define GL82_M    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NOT AT ALL" 1 "SOMEWHAT"
                       2 "VERY HELPFUL" ;
label define GL83      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define GL83A_1   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "CIRCLED" ;
label define GL83A_2   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 2 "CIRCLED" ;
label define GL83A_3   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 3 "CIRCLED" ;
label define GL83A_4   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 4 "CIRCLED" ;
label define GL83A_5   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 5 "CIRCLED" ;
label define GL83B_1   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM"
                       1 "SOCIAL SERVICES OR FAMILY SERVICES"
                       2 "MENTAL HEALTH CENTER"
                       3 "CHURCH OF RELIGIOUS ORGANIZATION"
                       4 "PRIV MARITAL OR FAMILY COUNSELR" 5 "OTHER" ;
label define GL83C_1   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "PROG" 2 "SOMEONE ELSE"
                       3 "SELF" ;
label define GL83D_1   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define GL83E_1   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NOT AT ALL" 1 "SOMEWHAT"
                       2 "VERY HELPFUL" ;
label define GL83F1_1  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "CIRCLED" ;
label define GL83F1_2  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 2 "CIRCLED" ;
label define GL83F111  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 11 "CIRCLED" ;
label define GL83F112  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 12 "CIRCLED" ;
label define GL83F113  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 13 "CIRCLED" ;
label define GL83F121  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 21 "CIRCLED" ;
label define GL83F122  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 22 "CIRCLED" ;
label define GL83F123  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 23 "CIRCLED" ;
label define GL83F128  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 28 "CIRCLED" ;
label define GL83F171  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 71 "CIRCLED" ;
label define GL83F191  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 91 "CIRCLED" ;
label define GL83G_1   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM"
                       1 "PRIMARY/REGULAR COUNSELOR" 2 "CASE MANAGER"
                       11 "OTHER COUNSELOR" 12 "OTHER CASE MANAGER"
                       13 "SOCIAL WORKER" 21 "PSYCHOLOGIST" 22 "PSYCHIATRIST"
                       23 "NURSE" 28 "CERTIFIED FAMILY COUNSELOR"
                       71 "STAFF FROM ANOTHER AGENCY" 91 "OTHER" ;
label define GL83B_2   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM"
                       1 "SOCIAL SERVICES OR FAMILY SERVICES"
                       2 "MENTAL HEALTH CENTER"
                       3 "CHURCH OF RELIGIOUS ORGANIZATION"
                       4 "PRIV MARITAL OR FAMILY COUNSELR" 5 "OTHER" ;
label define GL83C_2   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "PROG" 2 "SOMEONE ELSE"
                       3 "SELF" ;
label define GL83D_2   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define GL83E_2   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NOT AT ALL" 1 "SOMEWHAT"
                       2 "VERY HELPFUL" ;
label define GL83F2_1  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "CIRCLED" ;
label define GL83F2_2  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 2 "CIRCLED" ;
label define GL83F211  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 11 "CIRCLED" ;
label define GL83F212  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 12 "CIRCLED" ;
label define GL83F213  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 13 "CIRCLED" ;
label define GL83F221  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 21 "CIRCLED" ;
label define GL83F222  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 22 "CIRCLED" ;
label define GL83F223  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 23 "CIRCLED" ;
label define GL83F228  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 28 "CIRCLED" ;
label define GL83F271  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 71 "CIRCLED" ;
label define GL83F291  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 91 "CIRCLED" ;
label define GL83G_2   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM"
                       1 "PRIMARY/REGULAR COUNSELOR" 2 "CASE MANAGER"
                       11 "OTHER COUNSELOR" 12 "OTHER CASE MANAGER"
                       13 "SOCIAL WORKER" 21 "PSYCHOLOGIST" 22 "PSYCHIATRIST"
                       23 "NURSE" 28 "CERTIFIED FAMILY COUNSELOR"
                       71 "STAFF FROM ANOTHER AGENCY" 91 "OTHER" ;
label define GL84      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define GL85      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define GL86_01   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "CIRCLED" ;
label define GL86_02   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 2 "CIRCLED" ;
label define GL86_11   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 11 "CIRCLED" ;
label define GL86_12   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 12 "CIRCLED" ;
label define GL86_13   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 13 "CIRCLED" ;
label define GL86_21   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 21 "CIRCLED" ;
label define GL86_22   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 22 "CIRCLED" ;
label define GL86_23   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 23 "CIRCLED" ;
label define GL86_27   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 27 "CIRCLED" ;
label define GL86_29   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 29 "TEACHER" ;
label define GL86_71   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 71 "CIRCLED" ;
label define GL86_91   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 91 "CIRCLED" ;
label define GL86_A1   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM"
                       1 "PRIMARY/REGULAR COUNSELOR" 2 "CASE MANAGER"
                       11 "OTHER COUNSELOR" 12 "OTHER CASE MANAGER"
                       13 "SOCIAL WORKER" 21 "PSYCHOLOGIST" 22 "PSYCHIATRIST"
                       23 "NURSE" 27 "VOCATIONAL COUNSELOR" 29 "TEACHER"
                       71 "STAFF FROM ANOTHER AGENCY" 91 "OTHER" ;
label define GL86_A2   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM"
                       1 "PRIMARY/REGULAR COUNSELOR" 2 "CASE MANAGER"
                       11 "OTHER COUNSELOR" 12 "OTHER CASE MANAGER"
                       13 "SOCIAL WORKER" 21 "PSYCHOLOGIST" 22 "PSYCHIATRIST"
                       23 "NURSE" 27 "VOCATIONAL COUNSELOR" 29 "TEACHER"
                       71 "STAFF FROM ANOTHER AGENCY" 91 "OTHER" ;
label define GL87_01   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "CIRCLED" ;
label define GL87_02   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 2 "CIRCLED" ;
label define GL87_03   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 3 "CIRCLED" ;
label define GL87_B    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define GL87_C    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define GL87_D    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "DEGREE" 2 "DIPLOMA"
                       3 "CERTIFICATE" 4 "OTHER" ;
label define GL87_E    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define GL87_F    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NOT AT ALL" 1 "SOMEWHAT"
                       2 "VERY HELPFUL" ;
label define GL87_G_1  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "CIRCLED" ;
label define GL87_G_2  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 2 "CIRCLED" ;
label define GL87_G_3  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 3 "CIRCLED" ;
label define GL87_G_4  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 4 "CIRCLED" ;
label define GL87_G_5  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 5 "CIRCLED" ;
label define GL87_G_6  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 6 "CIRCLED" ;
label define GL87_G_7  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 7 "CIRCLED" ;
label define GL87_G_8  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 8 "CIRCLED" ;
label define GL87_H    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define GL87_I    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define GL87_J    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NOT AT ALL" 1 "SOMEWHAT"
                       2 "VERY HELPFUL" ;
label define GL87_K    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define GL87_L_1  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "CIRCLED" ;
label define GL87_L_2  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 2 "CIRCLED" ;
label define GL87_L_3  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 3 "CIRCLED" ;
label define GL87_L_4  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 4 "CIRCLED" ;
label define GL87_L_5  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 5 "CIRCLED" ;
label define GL87_L_6  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 6 "CIRCLED" ;
label define GL87_M    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "ALL INDIVIDUAL"
                       2 "ALL GROUP" 3 "BOTH INDIVIDUAL/GROUP" ;
label define GL87_N    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define GL87_O    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define GL87_P    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NOT AT ALL" 1 "SOMEWHAT"
                       2 "VERY HELPFUL" ;
label define GL88_01   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "CIRCLED" ;
label define GL88_02   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 2 "CIRCLED" ;
label define GL88_03   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 3 "CIRCLED" ;
label define GL88_B    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define GL88_C    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define GL88_D    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "DEGREE" 2 "DIPLOMA"
                       3 "CERTIFICATE" 4 "OTHER" ;
label define GL88_E    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define GL88_F    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NOT AT ALL" 1 "SOMEWHAT"
                       2 "VERY HELPFUL" ;
label define GL88_G_1  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "CIRCLED" ;
label define GL88_G_2  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 2 "CIRCLED" ;
label define GL88_G_3  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 3 "CIRCLED" ;
label define GL88_G_4  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 4 "CIRCLED" ;
label define GL88_G_5  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 5 "CIRCLED" ;
label define GL88_G_6  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 6 "CIRCLED" ;
label define GL88_G_7  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 7 "CIRCLED" ;
label define GL88_G_8  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 8 "CIRCLED" ;
label define GL88_H    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define GL88_I    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define GL88_J    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NOT AT ALL" 1 "SOMEWHAT"
                       2 "VERY HELPFUL" ;
label define GL88_K    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define GL88_L_1  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "CIRCLED" ;
label define GL88_L_2  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 2 "CIRCLED" ;
label define GL88_L_3  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 3 "CIRCLED" ;
label define GL88_L_4  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 4 "CIRCLED" ;
label define GL88_L_5  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 5 "CIRCLED" ;
label define GL88_L_6  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 6 "CIRCLED" ;
label define GL88_M    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "ALL INDIVIDUAL"
                       2 "ALL GROUP" 3 "BOTH INDIVIDUAL/GROUP" ;
label define GL88_N    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define GL88_O    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define GL88_P    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NOT AT ALL" 1 "SOMEWHAT"
                       2 "VERY HELPFUL" ;
label define GL89      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define GL89_A_1  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "CIRCLED" ;
label define GL89_A_2  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 2 "CIRCLED" ;
label define GL89_A_3  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 3 "CIRCLED" ;
label define GL89_A_4  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 4 "CIRCLED" ;
label define GL89_A_5  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 5 "CIRCLED" ;
label define GL89_A_6  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 6 "CIRCLED" ;
label define GL89_A_7  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 7 "CIRCLED" ;
label define GL89_A_8  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 8 "CIRCLED" ;
label define GL89_A_9  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 9 "CIRCLED" ;
label define GL89B_1   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM"
                       1 "STATE OFFICE OF EMPLOYMENT" 2 "DVR/OVR/VESID"
                       3 "JTPA/PIC" 4 "PUB EMPLOYMENT/TRAINING AGENCIES"
                       5 "PRIV EMPLOYMENT/TRAINING AGENCIES"
                       6 "BUSINESS ORGANIZATIONS"
                       7 "VOCATIONAL/TECHNICAL/CMMNTY COLLEGE"
                       8 "CHARITABLE AGENCIES" 9 "OTHER" ;
label define GL89C_1   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "PROG" 2 "SOMEONE ELSE"
                       3 "SELF" ;
label define GL89D_1   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 99 "99 OR MORE" ;
label define GL89E_1   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NOT AT ALL" 1 "SOMEWHAT"
                       2 "VERY HELPFUL" ;
label define GL89F1_1  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "CIRCLED" ;
label define GL89F1_2  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 2 "CIRCLED" ;
label define GL89F111  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 11 "CIRCLED" ;
label define GL89F112  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 12 "CIRCLED" ;
label define GL89F113  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 13 "CIRCLED" ;
label define GL89F121  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 21 "CIRCLED" ;
label define GL89F122  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 22 "CIRCLED" ;
label define GL89F123  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 23 "CIRCLED" ;
label define GL89F127  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 27 "CIRCLED" ;
label define GL89F129  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 29 "CIRCLED" ;
label define GL89F171  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 71 "CIRCLED" ;
label define GL89F191  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 91 "CIRCLED" ;
label define GL89G_1   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM"
                       1 "PRIMARY/REGULAR COUNSELOR" 2 "CASE MANAGER"
                       11 "OTHER COUNSELOR" 12 "OTHER CASE MANAGER"
                       13 "SOCIAL WORKER" 21 "PSYCHOLOGIST" 22 "PSYCHIATRIST"
                       23 "NURSE" 27 "VOCATIONAL COUNSELOR" 29 "TEACHER"
                       71 "STAFF FROM ANOTHER AGENCY" 91 "OTHER" ;
label define GL89B_2   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM"
                       1 "STATE OFFICE OF EMPLOYMENT" 2 "DVR/OVR/VESID"
                       3 "JTPA/PIC" 4 "PUB EMPLOYMENT/TRAINING AGENCIES"
                       5 "PRIV EMPLOYMENT/TRAINING AGENCIES"
                       6 "BUSINESS ORGANIZATIONS"
                       7 "VOCATIONAL/TECHNICAL/CMMNTY COLLEGE"
                       8 "CHARITABLE AGENCIES" 9 "OTHER" ;
label define GL89C_2   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "PROG" 2 "SOMEONE ELSE"
                       3 "SELF" ;
label define GL89D_2   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define GL89E_2   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NOT AT ALL" 1 "SOMEWHAT"
                       2 "VERY HELPFUL" ;
label define GL89F2_1  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "CIRCLED" ;
label define GL89F2_2  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 2 "CIRCLED" ;
label define GL89F211  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 11 "CIRCLED" ;
label define GL89F212  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 12 "CIRCLED" ;
label define GL89F213  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 13 "CIRCLED" ;
label define GL89F221  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 21 "CIRCLED" ;
label define GL89F222  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 22 "CIRCLED" ;
label define GL89F223  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 23 "CIRCLED" ;
label define GL89F227  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 27 "CIRCLED" ;
label define GL89F229  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 29 "CIRCLED" ;
label define GL89F271  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 71 "CIRCLED" ;
label define GL89F291  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 91 "CIRCLED" ;
label define GL89G_2   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM"
                       1 "PRIMARY/REGULAR COUNSELOR" 2 "CASE MANAGER"
                       11 "OTHER COUNSELOR" 12 "OTHER CASE MANAGER"
                       13 "SOCIAL WORKER" 21 "PSYCHOLOGIST" 22 "PSYCHIATRIST"
                       23 "NURSE" 27 "VOCATIONAL COUNSELOR" 29 "TEACHER"
                       71 "STAFF FROM ANOTHER AGENCY" 91 "OTHER" ;
label define GL90      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define GL91      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define GL92_01   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "CIRCLED" ;
label define GL92_02   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 2 "CIRCLED" ;
label define GL92_11   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 11 "CIRCLED" ;
label define GL92_12   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 12 "CIRCLED" ;
label define GL92_13   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 13 "CIRCLED" ;
label define GL92_21   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 21 "CIRCLED" ;
label define GL92_22   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 22 "CIRCLED" ;
label define GL92_23   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 23 "CIRCLED" ;
label define GL92_27   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 27 "CIRCLED" ;
label define GL92_29   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 29 "CIRCLED" ;
label define GL92_71   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 71 "CIRCLED" ;
label define GL92_91   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 91 "CIRCLED" ;
label define GL92A_1   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM"
                       1 "PRIMARY/REGULAR COUNSELOR" 2 "CASE MANAGER"
                       11 "OTHER COUNSELOR" 12 "OTHER CASE MANAGER"
                       13 "SOCIAL WORKER" 21 "PSYCHOLOGIST" 22 "PSYCHIATRIST"
                       23 "NURSE" 27 "VOCATIONAL COUNSELOR" 29 "TEACHER"
                       71 "STAFF FROM ANOTHER AGENCY" 91 "OTHER" ;
label define GL92A_2   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM"
                       1 "PRIMARY/REGULAR COUNSELOR" 2 "CASE MANAGER"
                       11 "OTHER COUNSELOR" 12 "OTHER CASE MANAGER"
                       13 "SOCIAL WORKER" 21 "PSYCHOLOGIST" 22 "PSYCHIATRIST"
                       23 "NURSE" 27 "VOCATIONAL COUNSELOR" 29 "TEACHER"
                       71 "STAFF FROM ANOTHER AGENCY" 91 "OTHER" ;
label define GL93      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define GL93_A    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define GL93_B_1  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "CIRCLED" ;
label define GL93_B_2  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 2 "CIRCLED" ;
label define GL93_B_3  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 3 "CIRCLED" ;
label define GL93_B_4  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 4 "CIRCLED" ;
label define GL93_B_5  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 5 "CIRCLED" ;
label define GL93_B_6  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 6 "CIRCLED" ;
label define GL93_B_7  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 7 "CIRCLED" ;
label define GL93_B_8  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 8 "CIRCLED" ;
label define GL93_C    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NOT AT ALL" 1 "SOMEWHAT"
                       2 "VERY HELPFUL" ;
label define GL94      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define GL94_A    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define GL94_B_1  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "CIRCLED" ;
label define GL94_B_2  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 2 "CIRCLED" ;
label define GL94_B_3  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 3 "CIRCLED" ;
label define GL94_B_4  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 4 "CIRCLED" ;
label define GL94_B_5  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 5 "CIRCLED" ;
label define GL94_B_6  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 6 "CIRCLED" ;
label define GL94_B_7  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 7 "CIRCLED" ;
label define GL94_B_8  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 8 "CIRCLED" ;
label define GL94_C    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NOT AT ALL" 1 "SOMEWHAT"
                       2 "VERY HELPFUL" ;
label define GL95      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define GL95_A_1  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "CIRCLED" ;
label define GL95_A_2  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 2 "CIRCLED" ;
label define GL95_A_3  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 3 "CIRCLED" ;
label define GL95_A_4  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 4 "CIRCLED" ;
label define GL95_A_5  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 5 "CIRCLED" ;
label define GL95_A_6  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 6 "CIRCLED" ;
label define GL95B_1   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "PUB SCHOOL SYSTEM"
                       2 "JUNIOR COMMUNITY COLLEGE"
                       3 "FOUR YR COLLEGE/GRADUATE PROG"
                       4 "PRIV EDUCATION PROG" 5 "PUB AGENCIES" 6 "OTHER" ;
label define GL95C_1   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "PROG" 2 "SOMEONE ELSE"
                       3 "SELF" ;
label define GL95D_1   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define GL95E_1   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NOT AT ALL" 1 "SOMEWHAT"
                       2 "VERY HELPFUL" ;
label define GL95F1_1  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "CIRCLED" ;
label define GL95F1_2  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 2 "CIRCLED" ;
label define GL95F127  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 27 "CIRCLED" ;
label define GL95F129  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 29 "CIRCLED" ;
label define GL95F171  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 71 "CIRCLED" ;
label define GL95F191  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 91 "CIRCLED" ;
label define GL95G_1   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM"
                       1 "PRIMARY/REGULAR COUNSELOR" 2 "CASE MANAGER"
                       27 "PROG VOCATIONAL COUNSELOR" 29 "TEACHER"
                       71 "STAFF FROM ANOTHER AGENCY" 91 "OTHER PROG STAFF" ;
label define GL95B_2   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "PUB SCHOOL SYSTEM"
                       2 "JUNIOR COMMUNITY COLLEGE"
                       3 "FOUR YR COLLEGE/GRADUATE PROG"
                       4 "PRIV EDUCATION PROG" 5 "PUB AGENCIES" 6 "OTHER" ;
label define GL95C_2   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "PROG" 2 "SOMEONE ELSE"
                       3 "SELF" ;
label define GL95D_2   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define GL95E_2   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NOT AT ALL" 1 "SOMEWHAT"
                       2 "VERY HELPFUL" ;
label define GL95F2_1  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "CIRCLED" ;
label define GL95F2_2  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 2 "CIRCLED" ;
label define GL95F227  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 27 "CIRCLED" ;
label define GL95F229  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 29 "CIRCLED" ;
label define GL95F271  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 71 "CIRCLED" ;
label define GL95F291  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 91 "CIRCLED" ;
label define GL95G_2   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM"
                       1 "PRIMARY/REGULAR COUNSELOR" 2 "CASE MANAGER"
                       27 "PROG VOCATIONAL COUNSELOR" 29 "TEACHER"
                       71 "STAFF FROM ANOTHER AGENCY" 91 "OTHER PROG STAFF" ;
label define GL96      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define GL97      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define GL98_01   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "CIRCLED" ;
label define GL98_02   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 2 "CIRCLED" ;
label define GL98_11   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 11 "CIRCLED" ;
label define GL98_12   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 12 "CIRCLED" ;
label define GL98_13   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 13 "CIRCLED" ;
label define GL98_21   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 21 "CIRCLED" ;
label define GL98_22   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 22 "CIRCLED" ;
label define GL98_23   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 23 "CIRCLED" ;
label define GL98_27   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 27 "CIRCLED" ;
label define GL98_28   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 28 "CIRCLED" ;
label define GL98_29   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 29 "CIRCLED" ;
label define GL98_71   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 71 "CIRCLED" ;
label define GL98_91   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 91 "CIRCLED" ;
label define GL98A_1   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM"
                       1 "PRIMARY/REGULAR COUNSELOR" 2 "CASE MANAGER"
                       11 "OTHER COUNSELOR" 12 "OTHER CASE MANAGER"
                       13 "SOCIAL WORKER" 21 "PSYCHOLOGIST" 22 "PSYCHIATRIST"
                       23 "NURSE" 27 "VOCATIONAL COUNSELOR"
                       28 "CERTIFIED FAMILY COUNSELOR" 29 "TEACHER"
                       71 "STAFF FROM ANOTHER AGENCY" 91 "OTHER" ;
label define GL98A_2   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM"
                       1 "PRIMARY/REGULAR COUNSELOR" 2 "CASE MANAGER"
                       11 "OTHER COUNSELOR" 12 "OTHER CASE MANAGER"
                       13 "SOCIAL WORKER" 21 "PSYCHOLOGIST" 22 "PSYCHIATRIST"
                       23 "NURSE" 27 "VOCATIONAL COUNSELOR"
                       28 "CERTIFIED FAMILY COUNSELOR" 29 "TEACHER"
                       71 "STAFF FROM ANOTHER AGENCY" 91 "OTHER" ;
label define GL99      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 99 "99 OR MORE" ;
label define GL99_A_1  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "CIRCLED" ;
label define GL99_A_2  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 2 "CIRCLED" ;
label define GL99_A_3  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 3 "CIRCLED" ;
label define GL99_A_4  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 4 "CIRCLED" ;
label define GL99_A_5  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 5 "CIRCLED" ;
label define GL99_A_6  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 6 "CIRCLED" ;
label define GL99_B    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NOT AT ALL" 1 "SOMEWHAT"
                       2 "VERY HELPFUL" ;
label define GL100     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define GL100A_1  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "CIRCLED" ;
label define GL100A_2  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 2 "CIRCLED" ;
label define GL100A_3  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 3 "CIRCLED" ;
label define GL100A_4  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 4 "CIRCLED" ;
label define GL100A_5  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 5 "CIRCLED" ;
label define GL100A_6  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 6 "CIRCLED" ;
label define GL100_B   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NOT AT ALL" 1 "SOMEWHAT"
                       2 "VERY HELPFUL" ;
label define GL101     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define GL101A_1  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "CIRCLED" ;
label define GL101A_2  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 2 "CIRCLED" ;
label define GL101A_3  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 3 "CIRCLED" ;
label define GL101A_4  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 4 "CIRCLED" ;
label define GL101A_5  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 5 "CIRCLED" ;
label define GL101A_6  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 6 "CIRCLED" ;
label define GL101B_1  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "TASC PROG STAFF"
                       2 "PAROLE OR PROBATION OFFICER" 3 "PRIV LAWYER"
                       4 "LEGAL AID" 5 "PUB DEFENDR/COURT APPOINTD COULSL"
                       6 "OTHER LEGAL" ;
label define GL101C_1  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "PROG" 2 "SOMEONE ELSE"
                       3 "SELF" ;
label define GL101D_1  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define GL101E_1  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NOT AT ALL" 1 "SOMEWHAT"
                       2 "VERY" ;
label define GL101B_2  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "TASC PROG STAFF"
                       2 "PAROLE OR PROBATION OFFICER" 3 "PRIV LAWYER"
                       4 "LEGAL AID" 5 "PUB DEFENDER/CT APPTD COUNSEL"
                       6 "OTHER LEGAL" ;
label define GL101C_2  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "PROG" 2 "SOMEONE ELSE"
                       3 "SELF" ;
label define GL101D_2  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define GL101E_2  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NOT AT ALL" 1 "SOMEWHAT"
                       2 "VERY HELPFUL" ;
label define GL102     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define GL103     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define GL104_01  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "CIRCLED" ;
label define GL104_02  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 2 "CIRCLED" ;
label define GL104_11  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 11 "CIRCLED" ;
label define GL104_12  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 12 "CIRCLED" ;
label define GL104_13  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 13 "CIRCLED" ;
label define GL104_21  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 21 "CIRCLED" ;
label define GL104_22  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 22 "CIRCLED" ;
label define GL104_23  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 23 "CIRCLED" ;
label define GL104_27  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 27 "CIRCLED" ;
label define GL104_28  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 28 "CIRCLED" ;
label define GL104_29  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 29 "CIRCLED" ;
label define GL104_71  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 71 "CIRCLED" ;
label define GL104_91  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 91 "CIRCLED" ;
label define GL104A_1  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM"
                       1 "PRIMARY/REGULAR COUNSELOR" 2 "CASE MANAGER"
                       11 "OTHER COUNSELOR" 12 "OTHER CASE MANAGER"
                       13 "SOCIAL WORKER" 21 "PSYCHOLOGIST" 22 "PSYCHIATRIST"
                       23 "NURSE" 27 "VOCATIONAL COUNSELOR"
                       28 "CERTIFIED FAMILY COUNSELOR" 29 "TEACHER"
                       71 "STAFF FROM ANOTHER AGENCY" 91 "OTHER" ;
label define GL104A_2  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM"
                       1 "PRIMARY/REGULAR COUNSELOR" 2 "CASE MANAGER"
                       11 "OTHER COUNSELOR" 12 "OTHER CASE MANAGER"
                       13 "SOCIAL WORKER" 21 "PSYCHOLOGIST" 22 "PSYCHIATRIST"
                       23 "NURSE" 27 "VOCATIONAL COUNSELOR"
                       28 "CERTIFIED FAMILY COUNSELOR" 29 "TEACHER"
                       71 "STAFF FROM ANOTHER AGENCY" 91 "OTHER" ;
label define GL105     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define GL105A_1  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "CIRCLED" ;
label define GL105A_2  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 2 "CIRCLED" ;
label define GL105A_3  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 3 "CIRCLED" ;
label define GL105A_4  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 4 "CIRCLED" ;
label define GL105A_5  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 5 "CIRCLED" ;
label define GL105A_6  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 6 "CIRCLED" ;
label define GL105_B   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NOT AT ALL" 1 "SOMEWHAT"
                       2 "VERY HELPFUL" ;
label define GL106     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define GL106A_1  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "CIRCLED" ;
label define GL106A_2  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 2 "CIRCLED" ;
label define GL106A_3  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 3 "CIRCLED" ;
label define GL106A_4  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 4 "CIRCLED" ;
label define GL106A_5  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 5 "CIRCLED" ;
label define GL106A_6  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 6 "CIRCLED" ;
label define GL106_B   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NOT AT ALL" 1 "SOMEWHAT"
                       2 "VERY HELPFUL" ;
label define GL107     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define GL107A51  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 51 "CIRCLED" ;
label define GL107A52  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 52 "CIRCLED" ;
label define GL107A53  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 53 "CIRCLED" ;
label define GL107A54  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 54 "CIRCLED" ;
label define GL107A91  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 91 "CIRCLED" ;
label define GL107B_1  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 51 "SOCIAL SERVICES"
                       52 "VOCATIONAL REHABILITATION" 53 "VETERANS AFFAIRS"
                       54 "SOCIAL SECURITY" 91 "OTHER" ;
label define GL107C_1  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "PROG" 2 "SOMEONE ELSE"
                       3 "SELF" ;
label define GL107D_1  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define GL107E_1  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NOT AT ALL" 1 "SOMEWHAT"
                       2 "VERY HELPFUL" ;
label define GL107B_2  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 51 "SOCIAL SERVICES"
                       52 "VOCATIONAL REHABILITATION" 53 "VETERANS AFFAIRS"
                       54 "SOCIAL SECURITY" 91 "OTHER" ;
label define GL107C_2  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "PROG" 2 "SOMEONE ELSE"
                       3 "SELF" ;
label define GL107D_2  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define GL107E_2  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NOT AT ALL" 1 "SOMEWHAT"
                       2 "VERY HELPFUL" ;
label define GL108     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define GL108_A   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define GL108_B   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NOT AT ALL" 1 "SOMEWHAT"
                       2 "VERY HELPFUL" ;
label define GL109     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define GL110     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define GL111_A   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NOT AT ALL" 1 "SOMEWHAT"
                       2 "VERY MUCH" ;
label define GL111_B   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NOT AT ALL" 1 "SOMEWHAT"
                       2 "VERY MUCH" ;
label define GL113_01  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "CIRCLED" ;
label define GL113_02  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 2 "CIRCLED" ;
label define GL113_11  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 11 "CIRCLED" ;
label define GL113_12  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 12 "CIRCLED" ;
label define GL113_13  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 13 "CIRCLED" ;
label define GL113_21  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 21 "CIRCLED" ;
label define GL113_22  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 22 "CIRCLED" ;
label define GL113_23  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 23 "CIRCLED" ;
label define GL113_24  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 24 "CIRCLED" ;
label define GL113_25  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 25 "CIRCLED" ;
label define GL113_26  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 26 "CIRCLED" ;
label define GL113_27  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 27 "CIRCLED" ;
label define GL113_28  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 28 "CIRCLED" ;
label define GL113_29  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 29 "CIRCLED" ;
label define GL113_71  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 71 "CIRCLED" ;
label define GL113_91  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 91 "CIRCLED" ;
label define GL114_A   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NEVER" 1 "SOME SESSIONS"
                       2 "MOST SESSIONS" 3 "EVERY SESSION" ;
label define GL114_B   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NEVER" 1 "SOME SESSIONS"
                       2 "MOST SESSIONS" 3 "EVERY SESSION" ;
label define GL114_C   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NEVER" 1 "SOME SESSIONS"
                       2 "MOST SESSIONS" 3 "EVERY SESSION" ;
label define GL114_D   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NEVER" 1 "SOME SESSIONS"
                       2 "MOST SESSIONS" 3 "EVERY SESSION" ;
label define GL114_E   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NEVER" 1 "SOME SESSIONS"
                       2 "MOST SESSIONS" 3 "EVERY SESSION" ;
label define GL114_F   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NEVER" 1 "SOME SESSIONS"
                       2 "MOST SESSIONS" 3 "EVERY SESSION" ;
label define GL114_G   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NEVER" 1 "SOME SESSIONS"
                       2 "MOST SESSIONS" 3 "EVERY SESSION" ;
label define GL114_H   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NEVER" 1 "SOME SESSIONS"
                       2 "MOST SESSIONS" 3 "EVERY SESSION" ;
label define GL114_I   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NEVER" 1 "SOME SESSIONS"
                       2 "MOST SESSIONS" 3 "EVERY SESSION" ;
label define GL114_J   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NEVER" 1 "SOME SESSIONS"
                       2 "MOST SESSIONS" 3 "EVERY SESSION" ;
label define GL114_K   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define GL114K_1  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NEVER" 1 "SOME SESSIONS"
                       2 "MOST SESSIONS" 3 "EVERY SESSION" ;
label define GL114K_2  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NEVER" 1 "SOME SESSIONS"
                       2 "MOST SESSIONS" 3 "EVERY SESSION" ;
label define GL114K_3  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NEVER" 1 "SOME SESSIONS"
                       2 "MOST SESSIONS" 3 "EVERY SESSION" ;
label define GL114K_4  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NEVER" 1 "SOME SESSIONS"
                       2 "MOST SESSIONS" 3 "EVERY SESSION" ;
label define GL115     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NO SERVICES"
                       1 "REGULAR ADDICTION GROUP" 2 "OTHER GROUP COUNSELING"
                       3 "INDIVIDUAL COUNSELING" 4 "12-STEP/SELF-HELP GROUP"
                       5 "CRISIS COUNSELING" 6 "UNSCHEDULED HELP"
                       7 "TALKS/FILMS/DISCUSSIONS" 8 "DRUG COUNSELING"
                       9 "ALCOHOL COUNSELING" 10 "DRUG TESTING"
                       11 "PSYCHOLOGICAL/MENTAL HEALTH"
                       12 "FAMILY RELATIONSHIP COUNSELING" 13 "MEDICATION"
                       14 "MEDICAL" 15 "LEGAL" 16 "EDUCATION/JOB TRAINING"
                       17 "HELP FINDING A JOB" 18 "OTHER JOB ASSISTANCE"
                       19 "FINANCIAL ASSISTANCE" 91 "OTHER" ;
label define GL116     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NO SERVICES"
                       1 "REGULAR ADDICTION GROUP"
                       2 "OTHER GROUP COUNSELLING" 3 "INDIVIDUAL COUNSELING"
                       4 "12-STEP/SELF-HELP GROUP" 5 "CRISIS COUNSELING"
                       6 "UNSCHEDULED HELP" 7 "TALKS/FILMS/DISCUSSIONS"
                       8 "DRUG COUNSELING" 9 "ALCOHOL COUNSELING"
                       10 "DRUG TESTING" 11 "PSYCHOLOGICAL/MENTAL HEALTH"
                       12 "FAMILY RELATIONSHIP COUNSELING" 13 "MEDICATION"
                       14 "MEDICAL" 15 "LEGAL" 16 "EDUCATION/JOB TRAINING"
                       17 "HELP FINDING A JOB" 18 "OTHER JOB ASSISTANCE"
                       19 "FINANCIAL ASSISTANCE" 91 "OTHER" ;
label define GL117     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define GL117_B1  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "SELF"
                       2 "COUNSELOR OR CASE MANAGER" 3 "ANOTHER STAFF MEMBER"
                       4 "ANOTHER CLIENT/RESIDENT/PATIENT"
                       5 "THE PROG OVERALL"
                       6 "SOMETHING/SOMEONE OUTSIDE PROG" 7 "OTHER" ;
label define GL117_B2  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "SELF"
                       2 "COUNSELOR OR CASE MANAGER" 3 "ANOTHER STAFF MEMBER"
                       4 "ANOTHER CLIENT/RESIDENT/PATIENT"
                       5 "THE PROG OVERALL"
                       6 "SOMETHING/SOMEONE OUTSIDE PROG" 7 "OTHER" ;
label define GL117_B3  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "SELF"
                       2 "COUNSELOR OR CASE MANAGER" 3 "ANOTHER STAFF MEMBER"
                       4 "ANOTHER CLIENT/RESIDENT/PATIENT"
                       5 "THE PROG OVERALL"
                       6 "SOMETHING/SOMEONE OUTSIDE PROG" 7 "OTHER" ;
label define GL117_B4  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "SELF"
                       2 "COUNSELOR OR CASE MANAGER" 3 "ANOTHER STAFF MEMBER"
                       4 "ANOTHER CLIENT/RESIDENT/PATIENT"
                       5 "THE PROG OVERALL"
                       6 "SOMETHING/SOMEONE OUTSIDE PROG" 7 "OTHER" ;
label define GL117_B5  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "SELF"
                       2 "COUNSELOR OR CASE MANAGER" 3 "ANOTHER STAFF MEMBER"
                       4 "ANOTHER CLIENT/RESIDENT/PATIENT"
                       5 "THE PROG OVERALL"
                       6 "SOMETHING/SOMEONE OUTSIDE PROG" 7 "OTHER" ;
label define GL118     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define GL118_A   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "A LITTLE" 2 "A LOT" ;
label define GL119     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NOT AT ALL" 1 "A LITTLE"
                       2 "A LOT" ;
label define GL120     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "VERY FEW" 2 "SOME"
                       3 "MOST" ;
label define GL121_A   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NONE" 1 "A LITTLE"
                       2 "A LOT" ;
label define GL121_B   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NONE" 1 "A LITTLE"
                       2 "A LOT" ;
label define GL121_C   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NONE" 1 "A LITTLE"
                       2 "A LOT" ;
label define GL121_D   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NONE" 1 "A LITTLE"
                       2 "A LOT" ;
label define GL121_E   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NONE" 1 "A LITTLE"
                       2 "A LOT" ;
label define GL121_F   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NONE" 1 "A LITTLE"
                       2 "A LOT" ;
label define GL122     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NOT AT ALL" 1 "SOMEWHAT"
                       2 "VERY LIKELY" ;
label define GL124     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NOT AT ALL"
                       1 "A LITTLE BIT" 2 "VERY MUCH" ;
label define GL125     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NOT AT ALL"
                       1 "A LITTLE BIT" 2 "VERY MUCH" ;
label define GL126     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NOT AT ALL"
                       1 "A LITTLE BIT" 2 "VERY MUCH" ;
label define GL127     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NOT AT ALL"
                       1 "A LITTLE BIT" 2 "VERY MUCH" ;
label define GL128     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NOT AT ALL"
                       1 "A LITTLE BIT" 2 "VERY MUCH" ;
label define GM1       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define GM2       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "CORRECT"
                       5 "ERROR/CANT DO/REFUSE" ;
label define GM3       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "CORRECT"
                       5 "ERROR/CANT DO/REFUSE" ;
label define GM4       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "CORRECT"
                       5 "ERROR/CANT DO/REFUSE" ;
label define GM5       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "CORRECT"
                       5 "ERROR/CANT DO/REFUSE" ;
label define GM6       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "CORRECT"
                       5 "ERROR/CANT DO/REFUSE" ;
label define GM7       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "CORRECT"
                       5 "ERROR/CANT DO/REFUSE" ;
label define GM8       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "CORRECT"
                       5 "ERROR/CANT DO/REFUSE" ;
label define GM9       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "CORRECT"
                       5 "ERROR/CANT DO/REFUSE" ;
label define GM10A     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "CORRECT"
                       5 "ERROR/CANT DO/REFUSE" ;
label define GM10B     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "CORRECT"
                       5 "ERROR/CANT DO/REFUSE" ;
label define GM11A     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "CORRECT"
                       5 "ERROR/CANT DO/REFUSE" ;
label define GM11B     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "CORRECT"
                       5 "ERROR/CANT DO/REFUSE" ;
label define GM11C     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "CORRECT"
                       5 "ERROR/CANT DO/REFUSE" ;
label define GM12A     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "CORRECT" 5 "ERROR"
                       7 "SAYS CANT DO" ;
label define GM12B     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "CORRECT" 5 "ERROR"
                       7 "SAYS CANT DO" ;
label define GM12C     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "CORRECT" 5 "ERROR"
                       7 "SAYS CANT DO" ;
label define GM12D     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "CORRECT" 5 "ERROR"
                       7 "SAYS CANT DO" ;
label define GM12E     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "CORRECT" 5 "ERROR"
                       7 "SAYS CANT DO" ;
label define GM13      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NO ERROR" 1 "1 ERROR"
                       2 "2 ERRORS" 3 "3 ERRORS" 4 "4 ERRORS" 5 "5 ERRORS" ;
label define GM14A     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "CORRECT"
                       5 "ERROR/CANT DO/REFUSE" ;
label define GM14B     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "CORRECT"
                       5 "ERROR/CANT DO/REFUSE" ;
label define GM14C     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "CORRECT"
                       5 "ERROR/CANT DO/REFUSE" ;
label define GM15A     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "CORRECT"
                       5 "ERROR/CANT DO/REFUSE" 6 "HANDICAP" ;
label define GM15B     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "CORRECT"
                       5 "ERROR/CANT DO/REFUSE" 6 "HANDICAP" ;
label define GM16      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "CORRECT"
                       5 "ERROR/CANT DO/REFUSE" 6 "HANDICAP" ;
label define GM17      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "CORRECT"
                       5 "ERROR/CANT DO/REFUSE" 6 "HANDICAP"
                       7 "CANT READ ENGLISH" ;
label define GM18A     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "CORRECT"
                       5 "ERROR/CANT DO/REFUSE" 6 "HANDICAP" ;
label define GM18B     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "CORRECT"
                       5 "ERROR/CANT DO/REFUSE" 6 "HANDICAP" ;
label define GM18C     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "CORRECT"
                       5 "ERROR/CANT DO/REFUSE" 6 "HANDICAP" ;
label define GM19      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "CORRECT"
                       5 "ERROR/CANT DO" 6 "HANDICAP"
                       7 "CANT WRITE (ENGLISH)" ;
label define GM20      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "CORRECT"
                       5 "ERROR/CANT DO" 6 "HANDICAP" ;
label define GM21      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define GN1       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define GN2       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define GN2A      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define GN3_1_1   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "CIRCLED" ;
label define GN3_1_2   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "MILD" 2 "MODERATE"
                       3 "EXTREME" ;
label define GN3_2_1   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 2 "CIRCLED" ;
label define GN3_2_2   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "MILD" 2 "MODERATE"
                       3 "EXTREME" ;
label define GN3_3_1   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 3 "CIRCLED" ;
label define GN3_3_2   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "MILD" 2 "MODERATE"
                       3 "EXTREME" ;
label define GN3_4_1   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 4 "CIRCLED" ;
label define GN3_4_2   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "MILD" 2 "MODERATE"
                       3 "EXTREME" ;
label define GN4       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define GN4A1     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "CIRCLED" ;
label define GN4A2     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 2 "CIRCLED" ;
label define GN4A3     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 3 "CIRCLED" ;
label define GN4A4     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 4 "CIRCLED" ;
label define GN4A5     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 5 "CIRCLED" ;
label define GN4A6     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 6 "CIRCLED" ;
label define GN5       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "EAGER" 2 "RECEPTIVE"
                       3 "NO REACTION" 4 "RELUCTANT" 5 "REFUSED"
                       6 "NOT DISCUSSED" ;
label define GN6       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define GN6A1     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define GN6A2     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define SEX       1 "MALE" 2 "FEMALE" ;
label define AGE       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 55 "55 OR OLDER" ;
label define AGEGRP    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "18-20" 2 "21-25"
                       3 "26-30" 4 "31-35" 5 "36-44" 6 "OVER 44" ;
label define RACE      1 "CAUCASIAN/WHITE" 2 "AFRO-AMERICAN/BLACK"
                       3 "HISPANIC" 4 "OTHER" ;
label define RACESEX   1 "CAUCASIAN/WHITE MALE" 2 "AFRO-AMERICAN/BLACK MALE"
                       3 "HISPANIC MALE" 4 "OTHER MALE"
                       5 "CAUCASIAN/WHITE FEMALE"
                       6 "AFRO-AMERICAN/BLACK FEMALE" 7 "HISPANIC FEMALE"
                       8 "OTHER FEMALE" ;
label define MSTAT     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "LEGALLY MARRIED"
                       2 "SEPARATED" 3 "DIVORCED" 4 "WIDOWED"
                       5 "LIVING AS MARRIED" 6 "NEVER MARRIED" ;
label define FTWORK    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NONE" 1 "1 TO 13 WEEKS"
                       2 "14 TO 39 WEEKS" 3 "40 TO 52 WEEKS" ;
label define EDLEV     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NONE"
                       1 "GRADE SCHOOL OR LESS" 2 "HIGH SCHOOL"
                       3 "HIGH SCHOOL DEGREE" 4 "SOME COLLEGE"
                       5 "JR COLLEGE/ASSOCIATE DEGREE" 6 "COLLEGE DEGREE"
                       7 "ADVANCED DEGREE" ;
label define HLTHINS   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NONE" 1 "PRIVATE /OTHER"
                       2 "PUBLIC" ;
label define MAJSRC    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NO INCOME" 1 "LEGAL WORK"
                       2 "PUBLIC ASSISTANCE" 3 "SOCIAL SECURITY"
                       4 "FAMILY,FRIENDS" 5 "ILLEGAL SOURCES"
                       6 "OTHER SOURCES" ;
label define REFER     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM"
                       0 "SELF (ONLY IF NO OTHER PRIMARY OR SECOND"
                       1 "MEDICAL SERVICE" 10 "COMMUNITY AGENCY"
                       20 "LEGAL SYSTEM" 30 "PROBATION & PAROLE"
                       40 "PRISON SYSTEM" 50 "FAMILY OR FRIENDS" 60 "SCHOOL"
                       70 "EMPLOYER" 80 "VETERAN" 90 "OTHER" ;
label define CJ_STAT   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NO LEGAL STATUS"
                       1 "IN JAIL/DETENTION" 2 "PROBATION" 3 "PAROLE"
                       4 "CASE PENDING" ;
label define RESTRICT  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NO WEEKS RESTRICTED"
                       1 "1 TO 4 WEEKS RESTRICTED"
                       2 "5 TO 13 WEEKS RESTRICTED"
                       3 "14 TO 26 WEEKS RESTRICTED"
                       4 "27 TO 39 WEEKS RESTRICTED"
                       5 "40 TO 50 WEEKS RESTRICTED"
                       6 "51 TO 52 WEEKS RESTRICTED" ;
label define SLFEFF3   -9.0000 "LEGITIMATE SKIP" -8.0000 "BLANK"
                       -7.0000 "REFUSAL" -6.0000 "MULTIPLE RESPONSE"
                       -5.0000 "BAD DATA" -4.0000 "DON'T KNOW"
                       -3.0000 "NOT APPLICABLE" -2.0000 "ILLEGIBLE"
                       -1.0000 "VARIABLE NOT ON FORM" ;
label define SLFEST3   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define SCACT3    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define SCPRE3    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define SCIDEA3   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define THALLY3   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define TP12ST3   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define TPHELP3   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define TPSELF3   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define PDRUG     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NO FAVORITE DRUG"
                       10 "ALCOHOL" 20 "MARIJUANA" 30 "HALLUCINOGEN"
                       40 "COCAINE/CRACK" 50 "HEROIN"
                       60 "NARCOTICS/OTHER OPIATES" 70 "SEDATIVES"
                       80 "AMPHETAMINES" 90 "OTHER" 91 "INHALANTS" ;
label define PDRUGFRQ  -9 "NO PRIMARY DRUG DENOTED" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NO USE"
                       1 "LESS THAN ONCE A MONTH" 2 "1 TO 3 TIMES A MONTH"
                       3 "1 TO 2 TIMES A WEEK" 4 "3 TO 4 TIMES A WEEK"
                       5 "5 TO 6 TIMES A WEEK" 6 "DAILY OR ALMOST EVERY DAY"
                       7 "2 TO 3 TIMES A DAY" 8 "4 OR MORE TIMES A DAY" ;
label define FAVDRUG   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NO FAVORITE DRUG"
                       10 "ALCOHOL" 20 "MARIJUANA" 30 "HALLUCINOGEN"
                       40 "COCAINE/CRACK" 50 "HEROIN"
                       60 "NARCOTICS/OTHER OPIATES" 70 "SEDATIVES"
                       80 "AMPHETAMINES" 90 "OTHER" 91 "INHALANTS" ;
label define HERHX     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NEVER USED"
                       1 "USED 1-5 TIMES ONLY"
                       2 "USED SPORADICALLY OR MONTHLY"
                       3 "USED MORE THAN 4 WKS ON WEEKLY BASIS"
                       4 "USED MORE THAN 4 WEEKS ON DAILY BASIS" ;
label define COCHX     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NEVER USED"
                       1 "USED 1-5 TIMES ONLY"
                       2 "USED SPORATICALLY OR MONTHLY"
                       3 "USED MORE THAN 4 WEEKS ON WKLY BASIS"
                       4 "USED MORE THAN 4 WEEKS ON DAILY BASIS" ;
label define DRUGTX    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define HVY_ALC   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NOT A HEAVY USER"
                       1 "HEAVY ALCOHOL USER" ;
label define DRUGPAT   1 "HEROIN/NARCOTIC/NO COKE"
                       2 "COKE W/HEROIN OR NARCOTICS" 3 "COKE ONLY"
                       4 "COKE AND ALCOHOL" 5 "COKE PLUS OTHER DRUGS"
                       6 "MARIJUANA AND/OR ALCOHOL" 7 "RESIDUAL" ;
label define ALCWK     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "LESS THAN WEEKLY USE"
                       1 "WEEKLY OR MORE USE" ;
label define MRJWK     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "LESS THAN WEEKLY USE"
                       1 "WEEKLY OR MORE USE" ;
label define COCWK     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "LESS THAN WEEKLY USE"
                       1 "WEEKLY OR MORE USE" ;
label define CRKWK     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "LESS THAN WEEKLY USE"
                       1 "WEEKLY OR MORE USE" ;
label define HERWK     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "LESS THAN WEEKLY USE"
                       1 "WEEKLY OR MORE USE" ;
label define NARWK     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "LESS THAN WEEKLY USE"
                       1 "WEEKLY OR MORE USE" ;
label define SEDWK     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "LESS THAN WEEKLY USE"
                       1 "WEEKLY OR MORE USE" ;
label define AMPWK     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "LESS THAN WEEKLY USE"
                       1 "WEEKLY OR MORE USE" ;
label define HALWK     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "LESS THAN WEEKLY USE"
                       1 "WEEKLY OR MORE USE" ;
label define INHWK     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "LESS THAN WEEKLY USE"
                       1 "WEEKLY OR MORE USE" ;
label define TOPS_PAT  1 "HEROIN" 2 "HEROIN AND OPIOIDS" 3 "OTHER OPIOIDS"
                       4 "MULTIPLE NON-OPIOID" 5 "SINGLE NON-OPIOID"
                       6 "MARIJUANA AND/OR ALCOHOL" 7 "RESIDUAL/MINIMAL USE" ;
label define DRGTXAGE  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 55 "55 OR OLDER" ;


#delimit cr


/***************************************************************************

 Section 4: Missing Values

 This section will replace numeric missing values (i.e., -9) with generic
 system missing ".".  By default the code in this section is commented out.
 Users wishing to apply the generic missing values should remove the comment
 at the beginning and end of this section.  Note that Stata allows you to
 specify up to 27 unique missing value codes.

****************************************************************/

/*
replace CASEID = . if (CASEID <= -1 )
replace GDC_M = . if (GDC_M <= -1 )
replace GDC_Y = . if (GDC_Y <= -1 )
replace GT_L_I = . if (GT_L_I <= -1 )
replace GA3 = . if (GA3 <= -1 )
replace GA3_A = . if (GA3_A <= -1 )
replace GA3_B = . if (GA3_B <= -1 )
replace GA4 = . if (GA4 <= -1 )
replace GA5 = . if (GA5 <= -1 )
replace GA6 = . if (GA6 <= -1 )
replace GA7 = . if (GA7 <= -1 )
replace GA8 = . if (GA8 <= -1 )
replace GA8_A = . if (GA8_A <= -1 )
replace GA8_B = . if (GA8_B <= -1 )
replace GA8_C = . if (GA8_C <= -1 )
replace GA8_D = . if (GA8_D <= -1 )
replace GA8_E = . if (GA8_E <= -1 )
replace GA9 = . if (GA9 <= -1 )
replace GA10 = . if (GA10 <= -1 )
replace GA11 = . if (GA11 <= -1 )
replace GA12 = . if (GA12 <= -1 )
replace GA13 = . if (GA13 <= -1 )
replace GA13A_02 = . if (GA13A_02 <= -1 )
replace GA13A_03 = . if (GA13A_03 <= -1 )
replace GA13A_04 = . if (GA13A_04 <= -1 )
replace GA13A_05 = . if (GA13A_05 <= -1 )
replace GA13A_06 = . if (GA13A_06 <= -1 )
replace GA14 = . if (GA14 <= -1 )
replace GA14A_02 = . if (GA14A_02 <= -1 )
replace GA14A_03 = . if (GA14A_03 <= -1 )
replace GA14A_04 = . if (GA14A_04 <= -1 )
replace GA14A_05 = . if (GA14A_05 <= -1 )
replace GA14A_06 = . if (GA14A_06 <= -1 )
replace GA15_00 = . if (GA15_00 <= -1 )
replace GA15_01 = . if (GA15_01 <= -1 )
replace GA15_02 = . if (GA15_02 <= -1 )
replace GA15_03 = . if (GA15_03 <= -1 )
replace GA16 = . if (GA16 <= -1 )
replace GA17 = . if (GA17 <= -1 )
replace GA18 = . if (GA18 <= -1 )
replace GA19 = . if (GA19 <= -1 )
replace GA19_A = . if (GA19_A <= -1 )
replace GA19_B = . if (GA19_B <= -1 )
replace GA20 = . if (GA20 <= -1 )
replace GA21 = . if (GA21 <= -1 )
replace GA22 = . if (GA22 <= -1 )
replace GA23_A = . if (GA23_A <= -1 )
replace GA23_B = . if (GA23_B <= -1 )
replace GA23_C = . if (GA23_C <= -1 )
replace GA24_A = . if (GA24_A <= -1 )
replace GA24_B = . if (GA24_B <= -1 )
replace GA24_C = . if (GA24_C <= -1 )
replace GA24_D = . if (GA24_D <= -1 )
replace GA24_E = . if (GA24_E <= -1 )
replace GA24_F = . if (GA24_F <= -1 )
replace GA25 = . if (GA25 <= -1 )
replace GA26 = . if (GA26 <= -1 )
replace GA27 = . if (GA27 <= -1 )
replace GA27A = . if (GA27A <= -1 )
replace GB1 = . if (GB1 <= -1 )
replace GB1_A = . if (GB1_A <= -1 )
replace GB1_B = . if (GB1_B <= -1 )
replace GB1_C = . if (GB1_C <= -1 )
replace GB1_D = . if (GB1_D <= -1 )
replace GB1_E = . if (GB1_E <= -1 )
replace GB1_F = . if (GB1_F <= -1 )
replace GB1_G = . if (GB1_G <= -1 )
replace GB2 = . if (GB2 <= -1 )
replace GB2_A = . if (GB2_A <= -1 )
replace GB3_0 = . if (GB3_0 <= -1 )
replace GB3_1 = . if (GB3_1 <= -1 )
replace GB3_2 = . if (GB3_2 <= -1 )
replace GB3_3 = . if (GB3_3 <= -1 )
replace GB3_4 = . if (GB3_4 <= -1 )
replace GB3_5 = . if (GB3_5 <= -1 )
replace GB3_6 = . if (GB3_6 <= -1 )
replace GB4 = . if (GB4 <= -1 )
replace GB4_A = . if (GB4_A <= -1 )
replace GB5 = . if (GB5 <= -1 )
replace GC1 = . if (GC1 <= -1 )
replace GC1_A_01 = . if (GC1_A_01 <= -1 )
replace GC1_A_02 = . if (GC1_A_02 <= -1 )
replace GC1_A_03 = . if (GC1_A_03 <= -1 )
replace GC1_A_04 = . if (GC1_A_04 <= -1 )
replace GC1_A_05 = . if (GC1_A_05 <= -1 )
replace GC1_A_06 = . if (GC1_A_06 <= -1 )
replace GC1_A_07 = . if (GC1_A_07 <= -1 )
replace GC1_B = . if (GC1_B <= -1 )
replace GC1_C = . if (GC1_C <= -1 )
replace GC1_D = . if (GC1_D <= -1 )
replace GC1_E = . if (GC1_E <= -1 )
replace GC2 = . if (GC2 <= -1 )
replace GC3 = . if (GC3 <= -1 )
replace GC3_A = . if (GC3_A <= -1 )
replace GC3_B = . if (GC3_B <= -1 )
replace GC4_00 = . if (GC4_00 <= -1 )
replace GC4_01 = . if (GC4_01 <= -1 )
replace GC4_02 = . if (GC4_02 <= -1 )
replace GC4_03 = . if (GC4_03 <= -1 )
replace GC4_04 = . if (GC4_04 <= -1 )
replace GC4_05 = . if (GC4_05 <= -1 )
replace GC4_06 = . if (GC4_06 <= -1 )
replace GC4_07 = . if (GC4_07 <= -1 )
replace GC4_08 = . if (GC4_08 <= -1 )
replace GC4_09 = . if (GC4_09 <= -1 )
replace GC5 = . if (GC5 <= -1 )
replace GC5_A = . if (GC5_A <= -1 )
replace GC6 = . if (GC6 <= -1 )
replace GC6_A = . if (GC6_A <= -1 )
replace GC7 = . if (GC7 <= -1 )
replace GC7_A = . if (GC7_A <= -1 )
replace GC7_B_1 = . if (GC7_B_1 <= -1 )
replace GC7_B_2 = . if (GC7_B_2 <= -1 )
replace GD1 = . if (GD1 <= -1 )
replace GD1_A = . if (GD1_A <= -1 )
replace GD1_B_1 = . if (GD1_B_1 <= -1 )
replace GD1_B_2 = . if (GD1_B_2 <= -1 )
replace GD1_C = . if (GD1_C <= -1 )
replace GD2 = . if (GD2 <= -1 )
replace GD2_A = . if (GD2_A <= -1 )
replace GD2_B = . if (GD2_B <= -1 )
replace GD2_C_1 = . if (GD2_C_1 <= -1 )
replace GD2_C_2 = . if (GD2_C_2 <= -1 )
replace GD2_D = . if (GD2_D <= -1 )
replace GD3 = . if (GD3 <= -1 )
replace GD3_A = . if (GD3_A <= -1 )
replace GD4 = . if (GD4 <= -1 )
replace GD4_A = . if (GD4_A <= -1 )
replace GD5 = . if (GD5 <= -1 )
replace GD5_A_1 = . if (GD5_A_1 <= -1 )
replace GD5_A_2 = . if (GD5_A_2 <= -1 )
replace GD5_B = . if (GD5_B <= -1 )
replace GD6 = . if (GD6 <= -1 )
replace GD6_A_1 = . if (GD6_A_1 <= -1 )
replace GD6_A_2 = . if (GD6_A_2 <= -1 )
replace GD6_B = . if (GD6_B <= -1 )
replace GD7 = . if (GD7 <= -1 )
replace GD7_A_1 = . if (GD7_A_1 <= -1 )
replace GD7_A_2 = . if (GD7_A_2 <= -1 )
replace GD7_B = . if (GD7_B <= -1 )
replace GD8 = . if (GD8 <= -1 )
replace GD8_A = . if (GD8_A <= -1 )
replace GD9 = . if (GD9 <= -1 )
replace GD10 = . if (GD10 <= -1 )
replace GD10_A = . if (GD10_A <= -1 )
replace GD11 = . if (GD11 <= -1 )
replace GD11_A = . if (GD11_A <= -1 )
replace GD12 = . if (GD12 <= -1 )
replace GD13 = . if (GD13 <= -1 )
replace GD14 = . if (GD14 <= -1 )
replace GD15 = . if (GD15 <= -1 )
replace GD16 = . if (GD16 <= -1 )
replace GD17 = . if (GD17 <= -1 )
replace GD18 = . if (GD18 <= -1 )
replace GD19 = . if (GD19 <= -1 )
replace GE1 = . if (GE1 <= -1 )
replace GE2 = . if (GE2 <= -1 )
replace GE3 = . if (GE3 <= -1 )
replace GE4 = . if (GE4 <= -1 )
replace GE5 = . if (GE5 <= -1 )
replace GE6 = . if (GE6 <= -1 )
replace GE7 = . if (GE7 <= -1 )
replace GE8 = . if (GE8 <= -1 )
replace GE9 = . if (GE9 <= -1 )
replace GE10 = . if (GE10 <= -1 )
replace GE11 = . if (GE11 <= -1 )
replace GE12 = . if (GE12 <= -1 )
replace GE12_A = . if (GE12_A <= -1 )
replace GE13 = . if (GE13 <= -1 )
replace GE13_A_1 = . if (GE13_A_1 <= -1 )
replace GE13_A_2 = . if (GE13_A_2 <= -1 )
replace GE13_A_3 = . if (GE13_A_3 <= -1 )
replace GE14 = . if (GE14 <= -1 )
replace GE14_A_1 = . if (GE14_A_1 <= -1 )
replace GE14_A_2 = . if (GE14_A_2 <= -1 )
replace GE14_B_1 = . if (GE14_B_1 <= -1 )
replace GE14_B_2 = . if (GE14_B_2 <= -1 )
replace GE14_C = . if (GE14_C <= -1 )
replace GE15 = . if (GE15 <= -1 )
replace GE15_A_1 = . if (GE15_A_1 <= -1 )
replace GE15_A_2 = . if (GE15_A_2 <= -1 )
replace GE15_B_1 = . if (GE15_B_1 <= -1 )
replace GE15_B_2 = . if (GE15_B_2 <= -1 )
replace GE15_C = . if (GE15_C <= -1 )
replace GE15_D = . if (GE15_D <= -1 )
replace GE15_E = . if (GE15_E <= -1 )
replace GE16 = . if (GE16 <= -1 )
replace GE16_A_1 = . if (GE16_A_1 <= -1 )
replace GE16_A_2 = . if (GE16_A_2 <= -1 )
replace GE16_B_1 = . if (GE16_B_1 <= -1 )
replace GE16_B_2 = . if (GE16_B_2 <= -1 )
replace GE16_C = . if (GE16_C <= -1 )
replace GE16_D = . if (GE16_D <= -1 )
replace GE16_E = . if (GE16_E <= -1 )
replace GE16_F = . if (GE16_F <= -1 )
replace GE17 = . if (GE17 <= -1 )
replace GE17_A = . if (GE17_A <= -1 )
replace GE17_B_1 = . if (GE17_B_1 <= -1 )
replace GE17_B_2 = . if (GE17_B_2 <= -1 )
replace GE17_B_3 = . if (GE17_B_3 <= -1 )
replace GE17_C = . if (GE17_C <= -1 )
replace GE18 = . if (GE18 <= -1 )
replace GE18_A_1 = . if (GE18_A_1 <= -1 )
replace GE18_A_2 = . if (GE18_A_2 <= -1 )
replace GE18_B_1 = . if (GE18_B_1 <= -1 )
replace GE18_B_2 = . if (GE18_B_2 <= -1 )
replace GE18_C = . if (GE18_C <= -1 )
replace GE18_D = . if (GE18_D <= -1 )
replace GE18_E = . if (GE18_E <= -1 )
replace GE19 = . if (GE19 <= -1 )
replace GE19_A = . if (GE19_A <= -1 )
replace GE19B1_1 = . if (GE19B1_1 <= -1 )
replace GE19B1_2 = . if (GE19B1_2 <= -1 )
replace GE19B2_1 = . if (GE19B2_1 <= -1 )
replace GE19B2_2 = . if (GE19B2_2 <= -1 )
replace GE19_C = . if (GE19_C <= -1 )
replace GE20 = . if (GE20 <= -1 )
replace GE20_A_1 = . if (GE20_A_1 <= -1 )
replace GE20_A_2 = . if (GE20_A_2 <= -1 )
replace GE20_B_1 = . if (GE20_B_1 <= -1 )
replace GE20_B_2 = . if (GE20_B_2 <= -1 )
replace GE20_C = . if (GE20_C <= -1 )
replace GE20_D = . if (GE20_D <= -1 )
replace GE20_E_1 = . if (GE20_E_1 <= -1 )
replace GE20_E_2 = . if (GE20_E_2 <= -1 )
replace GE20_E_3 = . if (GE20_E_3 <= -1 )
replace GE20_E_4 = . if (GE20_E_4 <= -1 )
replace GE20_F = . if (GE20_F <= -1 )
replace GE21 = . if (GE21 <= -1 )
replace GE21_A = . if (GE21_A <= -1 )
replace GE21_B_1 = . if (GE21_B_1 <= -1 )
replace GE21_B_2 = . if (GE21_B_2 <= -1 )
replace GE21_B_3 = . if (GE21_B_3 <= -1 )
replace GE21_C = . if (GE21_C <= -1 )
replace GE22 = . if (GE22 <= -1 )
replace GE22_A_1 = . if (GE22_A_1 <= -1 )
replace GE22_A_2 = . if (GE22_A_2 <= -1 )
replace GE22_B_1 = . if (GE22_B_1 <= -1 )
replace GE22_B_2 = . if (GE22_B_2 <= -1 )
replace GE22_C = . if (GE22_C <= -1 )
replace GE22_D = . if (GE22_D <= -1 )
replace GE22_E = . if (GE22_E <= -1 )
replace GE23 = . if (GE23 <= -1 )
replace GE23_A = . if (GE23_A <= -1 )
replace GE24 = . if (GE24 <= -1 )
replace GE24_A_1 = . if (GE24_A_1 <= -1 )
replace GE24_A_2 = . if (GE24_A_2 <= -1 )
replace GE24_B_1 = . if (GE24_B_1 <= -1 )
replace GE24_B_2 = . if (GE24_B_2 <= -1 )
replace GE24_C = . if (GE24_C <= -1 )
replace GE24_D = . if (GE24_D <= -1 )
replace GE24_E = . if (GE24_E <= -1 )
replace GE25 = . if (GE25 <= -1 )
replace GE25_A_1 = . if (GE25_A_1 <= -1 )
replace GE25_A_2 = . if (GE25_A_2 <= -1 )
replace GE25_B_1 = . if (GE25_B_1 <= -1 )
replace GE25_B_2 = . if (GE25_B_2 <= -1 )
replace GE25_C = . if (GE25_C <= -1 )
replace GE26 = . if (GE26 <= -1 )
replace GE26_A_1 = . if (GE26_A_1 <= -1 )
replace GE26_A_2 = . if (GE26_A_2 <= -1 )
replace GE26_B_1 = . if (GE26_B_1 <= -1 )
replace GE26_B_2 = . if (GE26_B_2 <= -1 )
replace GE26_C = . if (GE26_C <= -1 )
replace GE26_D = . if (GE26_D <= -1 )
replace GE27 = . if (GE27 <= -1 )
replace GE27_A = . if (GE27_A <= -1 )
replace GE27_B_1 = . if (GE27_B_1 <= -1 )
replace GE27_B_2 = . if (GE27_B_2 <= -1 )
replace GE27_C_1 = . if (GE27_C_1 <= -1 )
replace GE27_C_2 = . if (GE27_C_2 <= -1 )
replace GE27_D = . if (GE27_D <= -1 )
replace GE27_E = . if (GE27_E <= -1 )
replace GE28 = . if (GE28 <= -1 )
replace GE28_A = . if (GE28_A <= -1 )
replace GE28_B_1 = . if (GE28_B_1 <= -1 )
replace GE28_B_2 = . if (GE28_B_2 <= -1 )
replace GE28_C_1 = . if (GE28_C_1 <= -1 )
replace GE28_C_2 = . if (GE28_C_2 <= -1 )
replace GE28_D = . if (GE28_D <= -1 )
replace GE28_E = . if (GE28_E <= -1 )
replace GE29 = . if (GE29 <= -1 )
replace GE30 = . if (GE30 <= -1 )
replace GE30_A = . if (GE30_A <= -1 )
replace GE31 = . if (GE31 <= -1 )
replace GE31A_1 = . if (GE31A_1 <= -1 )
replace GE31A_2 = . if (GE31A_2 <= -1 )
replace GE31A_3 = . if (GE31A_3 <= -1 )
replace GE31A_4 = . if (GE31A_4 <= -1 )
replace GE31A_5 = . if (GE31A_5 <= -1 )
replace GE31A_6 = . if (GE31A_6 <= -1 )
replace GE32 = . if (GE32 <= -1 )
replace GE33_A = . if (GE33_A <= -1 )
replace GE33_B = . if (GE33_B <= -1 )
replace GE33_C = . if (GE33_C <= -1 )
replace GE33_D = . if (GE33_D <= -1 )
replace GE33_E = . if (GE33_E <= -1 )
replace GE33_F = . if (GE33_F <= -1 )
replace GE34 = . if (GE34 <= -1 )
replace GE35 = . if (GE35 <= -1 )
replace GE36 = . if (GE36 <= -1 )
replace GE37 = . if (GE37 <= -1 )
replace GE38 = . if (GE38 <= -1 )
replace GE39_A = . if (GE39_A <= -1 )
replace GE39_B = . if (GE39_B <= -1 )
replace GE39_C = . if (GE39_C <= -1 )
replace GE39_D = . if (GE39_D <= -1 )
replace GE39_E = . if (GE39_E <= -1 )
replace GE39_F = . if (GE39_F <= -1 )
replace GE39_G = . if (GE39_G <= -1 )
replace GE39_H = . if (GE39_H <= -1 )
replace GE39_I = . if (GE39_I <= -1 )
replace GE39_J = . if (GE39_J <= -1 )
replace GE39_K = . if (GE39_K <= -1 )
replace GE39_L = . if (GE39_L <= -1 )
replace GE39_M = . if (GE39_M <= -1 )
replace GE39_N = . if (GE39_N <= -1 )
replace GE39_O = . if (GE39_O <= -1 )
replace GE39_P = . if (GE39_P <= -1 )
replace GE39_Q = . if (GE39_Q <= -1 )
replace GE39_R = . if (GE39_R <= -1 )
replace GE39_S = . if (GE39_S <= -1 )
replace GE39_T = . if (GE39_T <= -1 )
replace GE40 = . if (GE40 <= -1 )
replace GE40_B_1 = . if (GE40_B_1 <= -1 )
replace GE40_B_2 = . if (GE40_B_2 <= -1 )
replace GE40_B_3 = . if (GE40_B_3 <= -1 )
replace GE41_A = . if (GE41_A <= -1 )
replace GE41_B = . if (GE41_B <= -1 )
replace GE42 = . if (GE42 <= -1 )
replace GE43 = . if (GE43 <= -1 )
replace GE44 = . if (GE44 <= -1 )
replace GE45 = . if (GE45 <= -1 )
replace GE46 = . if (GE46 <= -1 )
replace GE47 = . if (GE47 <= -1 )
replace GE48_A = . if (GE48_A <= -1 )
replace GE48_B = . if (GE48_B <= -1 )
replace GE48_C = . if (GE48_C <= -1 )
replace GE48_D = . if (GE48_D <= -1 )
replace GE48_E = . if (GE48_E <= -1 )
replace GE48_F = . if (GE48_F <= -1 )
replace GE48_G = . if (GE48_G <= -1 )
replace GE48_H = . if (GE48_H <= -1 )
replace GE48_I = . if (GE48_I <= -1 )
replace GE48_J = . if (GE48_J <= -1 )
replace GE48_K = . if (GE48_K <= -1 )
replace GE48_L = . if (GE48_L <= -1 )
replace GF1 = . if (GF1 <= -1 )
replace GF1_A = . if (GF1_A <= -1 )
replace GF2 = . if (GF2 <= -1 )
replace GF2_A = . if (GF2_A <= -1 )
replace GF3 = . if (GF3 <= -1 )
replace GF4 = . if (GF4 <= -1 )
replace GF5 = . if (GF5 <= -1 )
replace GF5_A = . if (GF5_A <= -1 )
replace GF6 = . if (GF6 <= -1 )
replace GF7 = . if (GF7 <= -1 )
replace GF8 = . if (GF8 <= -1 )
replace GF9 = . if (GF9 <= -1 )
replace GF9_A = . if (GF9_A <= -1 )
replace GF10 = . if (GF10 <= -1 )
replace GF10_A = . if (GF10_A <= -1 )
replace GF11 = . if (GF11 <= -1 )
replace GF11_A = . if (GF11_A <= -1 )
replace GF12 = . if (GF12 <= -1 )
replace GF13 = . if (GF13 <= -1 )
replace GF14 = . if (GF14 <= -1 )
replace GF15 = . if (GF15 <= -1 )
replace GF16 = . if (GF16 <= -1 )
replace GF16_A = . if (GF16_A <= -1 )
replace GF17 = . if (GF17 <= -1 )
replace GF17_A_1 = . if (GF17_A_1 <= -1 )
replace GF17_A_2 = . if (GF17_A_2 <= -1 )
replace GF17_A_3 = . if (GF17_A_3 <= -1 )
replace GF17_A_4 = . if (GF17_A_4 <= -1 )
replace GF17_B = . if (GF17_B <= -1 )
replace GF17_C = . if (GF17_C <= -1 )
replace GF17D_01 = . if (GF17D_01 <= -1 )
replace GF17D_02 = . if (GF17D_02 <= -1 )
replace GF17D_14 = . if (GF17D_14 <= -1 )
replace GF17D_23 = . if (GF17D_23 <= -1 )
replace GF17D_24 = . if (GF17D_24 <= -1 )
replace GF17D_61 = . if (GF17D_61 <= -1 )
replace GF17D_62 = . if (GF17D_62 <= -1 )
replace GF17D_91 = . if (GF17D_91 <= -1 )
replace GF17_E = . if (GF17_E <= -1 )
replace GF18 = . if (GF18 <= -1 )
replace GG1 = . if (GG1 <= -1 )
replace GG2 = . if (GG2 <= -1 )
replace GG3 = . if (GG3 <= -1 )
replace GG4 = . if (GG4 <= -1 )
replace GG4_A = . if (GG4_A <= -1 )
replace GG4_B_1 = . if (GG4_B_1 <= -1 )
replace GG4_B_2 = . if (GG4_B_2 <= -1 )
replace GG4_B_3 = . if (GG4_B_3 <= -1 )
replace GG4_B_4 = . if (GG4_B_4 <= -1 )
replace GG4_C = . if (GG4_C <= -1 )
replace GG4_D = . if (GG4_D <= -1 )
replace GG4_E = . if (GG4_E <= -1 )
replace GG4F_1 = . if (GG4F_1 <= -1 )
replace GG4F_2 = . if (GG4F_2 <= -1 )
replace GG4F_3 = . if (GG4F_3 <= -1 )
replace GG4F_4 = . if (GG4F_4 <= -1 )
replace GG4F_5 = . if (GG4F_5 <= -1 )
replace GG4F_6 = . if (GG4F_6 <= -1 )
replace GG4G = . if (GG4G <= -1 )
replace GG5_A = . if (GG5_A <= -1 )
replace GG6_A = . if (GG6_A <= -1 )
replace GG5_B = . if (GG5_B <= -1 )
replace GG6_B = . if (GG6_B <= -1 )
replace GG5_C = . if (GG5_C <= -1 )
replace GG6_C = . if (GG6_C <= -1 )
replace GG5_D = . if (GG5_D <= -1 )
replace GG6_D = . if (GG6_D <= -1 )
replace GG5_E = . if (GG5_E <= -1 )
replace GG6_E = . if (GG6_E <= -1 )
replace GG5_F = . if (GG5_F <= -1 )
replace GG6_F = . if (GG6_F <= -1 )
replace GG7 = . if (GG7 <= -1 )
replace GG7_A = . if (GG7_A <= -1 )
replace GG8 = . if (GG8 <= -1 )
replace GG9 = . if (GG9 <= -1 )
replace GG10 = . if (GG10 <= -1 )
replace GG11 = . if (GG11 <= -1 )
replace GG12 = . if (GG12 <= -1 )
replace GG12A_1 = . if (GG12A_1 <= -1 )
replace GG12A_2 = . if (GG12A_2 <= -1 )
replace GG12A_3 = . if (GG12A_3 <= -1 )
replace GG12A_4 = . if (GG12A_4 <= -1 )
replace GG12B_1 = . if (GG12B_1 <= -1 )
replace GG12B_2 = . if (GG12B_2 <= -1 )
replace GG12B_3 = . if (GG12B_3 <= -1 )
replace GG13 = . if (GG13 <= -1 )
replace GG14 = . if (GG14 <= -1 )
replace GG15 = . if (GG15 <= -1 )
replace GG15_A = . if (GG15_A <= -1 )
replace GH1 = . if (GH1 <= -1 )
replace GH1_A = . if (GH1_A <= -1 )
replace GH2_A = . if (GH2_A <= -1 )
replace GH3_A = . if (GH3_A <= -1 )
replace GH2_B = . if (GH2_B <= -1 )
replace GH3_B = . if (GH3_B <= -1 )
replace GH2_C = . if (GH2_C <= -1 )
replace GH3_C = . if (GH3_C <= -1 )
replace GH2_D = . if (GH2_D <= -1 )
replace GH3_D = . if (GH3_D <= -1 )
replace GH2_E = . if (GH2_E <= -1 )
replace GH3_E = . if (GH3_E <= -1 )
replace GH2_F = . if (GH2_F <= -1 )
replace GH3_F = . if (GH3_F <= -1 )
replace GH2_G = . if (GH2_G <= -1 )
replace GH3_G = . if (GH3_G <= -1 )
replace GH2_H = . if (GH2_H <= -1 )
replace GH3_H = . if (GH3_H <= -1 )
replace GH2_I = . if (GH2_I >= -9 & GH2_I <= -1)
replace GH3_I = . if (GH3_I <= -1 )
replace GH2_J = . if (GH2_J <= -1 )
replace GH3_J = . if (GH3_J <= -1 )
replace GH2_K = . if (GH2_K <= -1 )
replace GH3_K = . if (GH3_K <= -1 )
replace GH2_L = . if (GH2_L <= -1 )
replace GH3_L = . if (GH3_L <= -1 )
replace GH4 = . if (GH4 <= -1 )
replace GH5 = . if (GH5 <= -1 )
replace GH6 = . if (GH6 <= -1 )
replace GH6_A = . if (GH6_A <= -1 )
replace GH7 = . if (GH7 <= -1 )
replace GH8 = . if (GH8 <= -1 )
replace GH8_A = . if (GH8_A <= -1 )
replace GH9 = . if (GH9 <= -1 )
replace GJ1 = . if (GJ1 <= -1 )
replace GJ2 = . if (GJ2 <= -1 )
replace GJ2_A = . if (GJ2_A <= -1 )
replace GJ2_B = . if (GJ2_B <= -1 )
replace GJ2_C = . if (GJ2_C <= -1 )
replace GJ2_D = . if (GJ2_D <= -1 )
replace GJ2_E = . if (GJ2_E <= -1 )
replace GJ2_F = . if (GJ2_F <= -1 )
replace GJ2_G = . if (GJ2_G <= -1 )
replace GJ3 = . if (GJ3 <= -1 )
replace GJ3_A_1 = . if (GJ3_A_1 <= -1 )
replace GJ3_A_2 = . if (GJ3_A_2 <= -1 )
replace GJ3_A_3 = . if (GJ3_A_3 <= -1 )
replace GJ3_A_4 = . if (GJ3_A_4 <= -1 )
replace GJ3_A_5 = . if (GJ3_A_5 <= -1 )
replace GJ3_A_6 = . if (GJ3_A_6 <= -1 )
replace GJ3_A_7 = . if (GJ3_A_7 <= -1 )
replace GJ3_B = . if (GJ3_B <= -1 )
replace GJ3_C_1 = . if (GJ3_C_1 <= -1 )
replace GJ3_C_2 = . if (GJ3_C_2 <= -1 )
replace GJ3_C_3 = . if (GJ3_C_3 <= -1 )
replace GJ3_C_4 = . if (GJ3_C_4 <= -1 )
replace GJ3_C_5 = . if (GJ3_C_5 <= -1 )
replace GJ3_C_6 = . if (GJ3_C_6 <= -1 )
replace GJ3_C_7 = . if (GJ3_C_7 <= -1 )
replace GJ3_C_8 = . if (GJ3_C_8 <= -1 )
replace GJ3_C_9 = . if (GJ3_C_9 <= -1 )
replace GJ3_C_10 = . if (GJ3_C_10 <= -1 )
replace GJ3_C_11 = . if (GJ3_C_11 <= -1 )
replace GJ4_0 = . if (GJ4_0 <= -1 )
replace GJ4_1 = . if (GJ4_1 <= -1 )
replace GJ4_2 = . if (GJ4_2 <= -1 )
replace GJ4_3 = . if (GJ4_3 <= -1 )
replace GJ4_4 = . if (GJ4_4 <= -1 )
replace GJ4_5 = . if (GJ4_5 <= -1 )
replace GJ4_6 = . if (GJ4_6 <= -1 )
replace GJ4_7 = . if (GJ4_7 <= -1 )
replace GJ4_8 = . if (GJ4_8 <= -1 )
replace GJ4_9 = . if (GJ4_9 <= -1 )
replace GJ4_10 = . if (GJ4_10 <= -1 )
replace GJ4_11 = . if (GJ4_11 <= -1 )
replace GJ4_12 = . if (GJ4_12 <= -1 )
replace GJ4_13 = . if (GJ4_13 <= -1 )
replace GJ4_14 = . if (GJ4_14 <= -1 )
replace GJ4_15 = . if (GJ4_15 <= -1 )
replace GJ4_16 = . if (GJ4_16 <= -1 )
replace GJ5 = . if (GJ5 <= -1 )
replace GJ6 = . if (GJ6 <= -1 )
replace GJ7 = . if (GJ7 <= -1 )
replace GJ8 = . if (GJ8 <= -1 )
replace GJ9 = . if (GJ9 <= -1 )
replace GJ9_A = . if (GJ9_A <= -1 )
replace GJ9_B = . if (GJ9_B <= -1 )
replace GJ9_B_OC = . if (GJ9_B_OC <= -1 )
replace GJ9_C = . if (GJ9_C <= -1.00 )
replace GJ9_COD = . if (GJ9_COD <= -1 )
replace GJ10 = . if (GJ10 <= -1 )
replace GJ11 = . if (GJ11 <= -1 )
replace GJ12 = . if (GJ12 <= -1 )
replace GJ12_A = . if (GJ12_A <= -1 )
replace GK1_A = . if (GK1_A <= -1 )
replace GK2_A = . if (GK2_A <= -1 )
replace GK1_B = . if (GK1_B <= -1 )
replace GK2_B = . if (GK2_B <= -1 )
replace GK1_C = . if (GK1_C <= -1 )
replace GK2_C = . if (GK2_C <= -1 )
replace GK1_D = . if (GK1_D <= -1 )
replace GK2_D = . if (GK2_D <= -1 )
replace GK1_E = . if (GK1_E <= -1 )
replace GK2_E = . if (GK2_E <= -1 )
replace GK1_F = . if (GK1_F <= -1 )
replace GK2_F = . if (GK2_F <= -1 )
replace GK2_G = . if (GK2_G <= -1 )
replace GK3 = . if (GK3 <= -1 )
replace GK4 = . if (GK4 <= -1 )
replace GK4_A = . if (GK4_A <= -1 )
replace GK5 = . if (GK5 <= -1 )
replace GK6_A = . if (GK6_A <= -1 )
replace GK6_B = . if (GK6_B <= -1 )
replace GK6_C = . if (GK6_C <= -1 )
replace GK6_D = . if (GK6_D <= -1 )
replace GK7 = . if (GK7 <= -1 )
replace GK7_A = . if (GK7_A <= -1 )
replace GK8 = . if (GK8 <= -1 )
replace GK9 = . if (GK9 <= -1 )
replace GL1 = . if (GL1 <= -1 )
replace GL1_A = . if (GL1_A <= -1 )
replace GL2 = . if (GL2 <= -1 )
replace GL2_A = . if (GL2_A <= -1 )
replace GL2_B = . if (GL2_B <= -1 )
replace GL2_C = . if (GL2_C <= -1 )
replace GL2_D = . if (GL2_D <= -1 )
replace GL2_E = . if (GL2_E <= -1 )
replace GL2_F_1 = . if (GL2_F_1 <= -1 )
replace GL2_F_2 = . if (GL2_F_2 <= -1 )
replace GL2_F_3 = . if (GL2_F_3 <= -1 )
replace GL3 = . if (GL3 <= -1 )
replace GL3_A = . if (GL3_A <= -1 )
replace GL4 = . if (GL4 <= -1 )
replace GL5 = . if (GL5 <= -1 )
replace GL5_A_1 = . if (GL5_A_1 <= -1 )
replace GL5_A_2 = . if (GL5_A_2 <= -1 )
replace GL5_A_3 = . if (GL5_A_3 <= -1 )
replace GL5_A_4 = . if (GL5_A_4 <= -1 )
replace GL5_B_1 = . if (GL5_B_1 <= -1 )
replace GL5_B_2 = . if (GL5_B_2 <= -1 )
replace GL5_B_11 = . if (GL5_B_11 <= -1 )
replace GL5_B_12 = . if (GL5_B_12 <= -1 )
replace GL5_B_13 = . if (GL5_B_13 <= -1 )
replace GL5_B_21 = . if (GL5_B_21 <= -1 )
replace GL5_B_22 = . if (GL5_B_22 <= -1 )
replace GL5_B_31 = . if (GL5_B_31 <= -1 )
replace GL5_B_71 = . if (GL5_B_71 <= -1 )
replace GL5_B_91 = . if (GL5_B_91 <= -1 )
replace GL5_C = . if (GL5_C <= -1 )
replace GL5_D = . if (GL5_D <= -1 )
replace GL6 = . if (GL6 <= -1 )
replace GL6_A_A = . if (GL6_A_A <= -1 )
replace GL6_A_B = . if (GL6_A_B <= -1 )
replace GL6_A_C = . if (GL6_A_C <= -1 )
replace GL6_A_D = . if (GL6_A_D <= -1 )
replace GL6_A_E = . if (GL6_A_E <= -1 )
replace GL6_A_F = . if (GL6_A_F <= -1 )
replace GL6_A_G = . if (GL6_A_G <= -1 )
replace GL6_A_H = . if (GL6_A_H <= -1 )
replace GL6_A_I = . if (GL6_A_I <= -1 )
replace GL6_A_J = . if (GL6_A_J <= -1 )
replace GL6_B_1 = . if (GL6_B_1 <= -1 )
replace GL6_C_1 = . if (GL6_C_1 <= -1 )
replace GL6_D_1 = . if (GL6_D_1 <= -1 )
replace GL6_E_1 = . if (GL6_E_1 <= -1 )
replace GL6_B_2 = . if (GL6_B_2 <= -1 )
replace GL6_C_2 = . if (GL6_C_2 <= -1 )
replace GL6_D_2 = . if (GL6_D_2 <= -1 )
replace GL6_E_2 = . if (GL6_E_2 <= -1 )
replace GL6_B_3 = . if (GL6_B_3 <= -1 )
replace GL6_C_3 = . if (GL6_C_3 <= -1 )
replace GL6_D_3 = . if (GL6_D_3 <= -1 )
replace GL6_E_3 = . if (GL6_E_3 <= -1 )
replace GL6_B_4 = . if (GL6_B_4 <= -1 )
replace GL6_C_4 = . if (GL6_C_4 <= -1 )
replace GL6_D_4 = . if (GL6_D_4 <= -1 )
replace GL6_E_4 = . if (GL6_E_4 <= -1 )
replace GL7 = . if (GL7 <= -1 )
replace GL7_A_A = . if (GL7_A_A <= -1 )
replace GL7_A_B = . if (GL7_A_B <= -1 )
replace GL7_A_C = . if (GL7_A_C <= -1 )
replace GL7_A_D = . if (GL7_A_D <= -1 )
replace GL7_A_E = . if (GL7_A_E <= -1 )
replace GL7_A_F = . if (GL7_A_F <= -1 )
replace GL7_A_G = . if (GL7_A_G <= -1 )
replace GL7_A_H = . if (GL7_A_H <= -1 )
replace GL7_A_I = . if (GL7_A_I <= -1 )
replace GL7_B_1 = . if (GL7_B_1 <= -1 )
replace GL7_C_1 = . if (GL7_C_1 <= -1 )
replace GL7_D_1 = . if (GL7_D_1 <= -1 )
replace GL7_E_1 = . if (GL7_E_1 <= -1 )
replace GL7_B_2 = . if (GL7_B_2 <= -1 )
replace GL7_C_2 = . if (GL7_C_2 <= -1 )
replace GL7_D_2 = . if (GL7_D_2 <= -1 )
replace GL7_E_2 = . if (GL7_E_2 <= -1 )
replace GL7_B_3 = . if (GL7_B_3 <= -1 )
replace GL7_C_3 = . if (GL7_C_3 <= -1 )
replace GL7_D_3 = . if (GL7_D_3 <= -1 )
replace GL7_E_3 = . if (GL7_E_3 <= -1 )
replace GL7_B_4 = . if (GL7_B_4 <= -1 )
replace GL7_C_4 = . if (GL7_C_4 <= -1 )
replace GL7_D_4 = . if (GL7_D_4 <= -1 )
replace GL7_E_4 = . if (GL7_E_4 <= -1 )
replace GL8_0 = . if (GL8_0 <= -1 )
replace GL8_1 = . if (GL8_1 <= -1 )
replace GL8_2 = . if (GL8_2 <= -1 )
replace GL8_11 = . if (GL8_11 <= -1 )
replace GL8_12 = . if (GL8_12 <= -1 )
replace GL8_13 = . if (GL8_13 <= -1 )
replace GL8_21 = . if (GL8_21 <= -1 )
replace GL8_22 = . if (GL8_22 <= -1 )
replace GL8_71 = . if (GL8_71 <= -1 )
replace GL8_91 = . if (GL8_91 <= -1 )
replace GL8_A_1 = . if (GL8_A_1 <= -1 )
replace GL8_A_2 = . if (GL8_A_2 <= -1 )
replace GL9 = . if (GL9 <= -1 )
replace GL9_A = . if (GL9_A <= -1 )
replace GL10 = . if (GL10 <= -1 )
replace GL11 = . if (GL11 <= -1 )
replace GL12 = . if (GL12 <= -1 )
replace GL13_A = . if (GL13_A <= -1 )
replace GL13_B = . if (GL13_B <= -1 )
replace GL13_C = . if (GL13_C <= -1 )
replace GL13_D = . if (GL13_D <= -1 )
replace GL13_E = . if (GL13_E <= -1 )
replace GL13_F = . if (GL13_F <= -1 )
replace GL13_G = . if (GL13_G <= -1 )
replace GL13_H = . if (GL13_H <= -1 )
replace GL13_I = . if (GL13_I <= -1 )
replace GL13_J = . if (GL13_J <= -1 )
replace GL13_K = . if (GL13_K <= -1 )
replace GL13_K_1 = . if (GL13_K_1 <= -1 )
replace GL13_K_2 = . if (GL13_K_2 <= -1 )
replace GL13_K_3 = . if (GL13_K_3 <= -1 )
replace GL13_K_4 = . if (GL13_K_4 <= -1 )
replace GL14_A = . if (GL14_A <= -1 )
replace GL14_B = . if (GL14_B <= -1 )
replace GL15_M = . if (GL15_M <= -1 )
replace GL15_D = . if (GL15_D <= -1 )
replace GL15_Y = . if (GL15_Y <= -1 )
replace GL16 = . if (GL16 <= -1 )
replace GL16_A = . if (GL16_A <= -1 )
replace GL17 = . if (GL17 <= -1 )
replace GL18 = . if (GL18 <= -1 )
replace GL19 = . if (GL19 <= -1 )
replace GL20_A = . if (GL20_A <= -1 )
replace GL20_B = . if (GL20_B <= -1 )
replace GL20_C = . if (GL20_C <= -1 )
replace GL20_D = . if (GL20_D <= -1 )
replace GL20_E = . if (GL20_E <= -1 )
replace GL20_F = . if (GL20_F <= -1 )
replace GL20_G = . if (GL20_G <= -1 )
replace GL20_H = . if (GL20_H <= -1 )
replace GL20_I = . if (GL20_I <= -1 )
replace GL20_J = . if (GL20_J <= -1 )
replace GL20_K = . if (GL20_K <= -1 )
replace GL20_K_1 = . if (GL20_K_1 <= -1 )
replace GL20_K_2 = . if (GL20_K_2 <= -1 )
replace GL20_K_3 = . if (GL20_K_3 <= -1 )
replace GL20_K_4 = . if (GL20_K_4 <= -1 )
replace GL21_A = . if (GL21_A <= -1 )
replace GL21_B = . if (GL21_B <= -1 )
replace GL22_M = . if (GL22_M <= -1 )
replace GL22_Y = . if (GL22_Y <= -1 )
replace GL23 = . if (GL23 <= -1 )
replace GL24 = . if (GL24 <= -1 )
replace GL25 = . if (GL25 <= -1 )
replace GL26_M = . if (GL26_M <= -1 )
replace GL26_Y = . if (GL26_Y <= -1 )
replace GL27 = . if (GL27 <= -1 )
replace GL28 = . if (GL28 <= -1 )
replace GL28A_00 = . if (GL28A_00 <= -1 )
replace GL28A_01 = . if (GL28A_01 <= -1 )
replace GL28A_02 = . if (GL28A_02 <= -1 )
replace GL28A_11 = . if (GL28A_11 <= -1 )
replace GL28A_12 = . if (GL28A_12 <= -1 )
replace GL28A_13 = . if (GL28A_13 <= -1 )
replace GL28A_21 = . if (GL28A_21 <= -1 )
replace GL28A_22 = . if (GL28A_22 <= -1 )
replace GL28A_23 = . if (GL28A_23 <= -1 )
replace GL28A_24 = . if (GL28A_24 <= -1 )
replace GL28A_25 = . if (GL28A_25 <= -1 )
replace GL28A_26 = . if (GL28A_26 <= -1 )
replace GL28A_71 = . if (GL28A_71 <= -1 )
replace GL28A_91 = . if (GL28A_91 <= -1 )
replace GL28B = . if (GL28B <= -1 )
replace GL29 = . if (GL29 <= -1 )
replace GL29_A = . if (GL29_A <= -1 )
replace GL29_B_A = . if (GL29_B_A <= -1 )
replace GL29_B_B = . if (GL29_B_B <= -1 )
replace GL29_B_C = . if (GL29_B_C <= -1 )
replace GL29_B_D = . if (GL29_B_D <= -1 )
replace GL29_B_E = . if (GL29_B_E <= -1 )
replace GL29_B_F = . if (GL29_B_F <= -1 )
replace GL29_B_G = . if (GL29_B_G <= -1 )
replace GL29_B_H = . if (GL29_B_H <= -1 )
replace GL29_B_I = . if (GL29_B_I <= -1 )
replace GL29_B_J = . if (GL29_B_J <= -1 )
replace GL29_B_K = . if (GL29_B_K <= -1 )
replace GL29BK_1 = . if (GL29BK_1 <= -1 )
replace GL29BK_2 = . if (GL29BK_2 <= -1 )
replace GL29BK_3 = . if (GL29BK_3 <= -1 )
replace GL29BK_4 = . if (GL29BK_4 <= -1 )
replace GL29_C = . if (GL29_C <= -1 )
replace GL29_D = . if (GL29_D <= -1 )
replace GL29_E = . if (GL29_E <= -1 )
replace GL30 = . if (GL30 <= -1 )
replace GL30_A = . if (GL30_A <= -1 )
replace GL30_B_M = . if (GL30_B_M <= -1 )
replace GL30C_00 = . if (GL30C_00 <= -1 )
replace GL30C_01 = . if (GL30C_01 <= -1 )
replace GL30C_02 = . if (GL30C_02 <= -1 )
replace GL30C_11 = . if (GL30C_11 <= -1 )
replace GL30C_12 = . if (GL30C_12 <= -1 )
replace GL30C_13 = . if (GL30C_13 <= -1 )
replace GL30C_21 = . if (GL30C_21 <= -1 )
replace GL30C_22 = . if (GL30C_22 <= -1 )
replace GL30C_23 = . if (GL30C_23 <= -1 )
replace GL30C_24 = . if (GL30C_24 <= -1 )
replace GL30C_25 = . if (GL30C_25 <= -1 )
replace GL30C_26 = . if (GL30C_26 <= -1 )
replace GL30C_27 = . if (GL30C_27 <= -1 )
replace GL30C_71 = . if (GL30C_71 <= -1 )
replace GL30C_91 = . if (GL30C_91 <= -1 )
replace GL30_D = . if (GL30_D <= -1 )
replace GL31 = . if (GL31 <= -1 )
replace GL32 = . if (GL32 <= -1 )
replace GL33 = . if (GL33 <= -1 )
replace GL33_A = . if (GL33_A <= -1 )
replace GL33_B = . if (GL33_B <= -1 )
replace GL34 = . if (GL34 <= -1 )
replace GL35 = . if (GL35 <= -1 )
replace GL35_A = . if (GL35_A <= -1 )
replace GL36 = . if (GL36 <= -1 )
replace GL37 = . if (GL37 <= -1 )
replace GL38 = . if (GL38 <= -1 )
replace GL39 = . if (GL39 <= -1 )
replace GL39_A = . if (GL39_A <= -1 )
replace GL39_B = . if (GL39_B <= -1 )
replace GL40 = . if (GL40 <= -1 )
replace GL41 = . if (GL41 <= -1 )
replace GL41_A = . if (GL41_A <= -1 )
replace GL42 = . if (GL42 <= -1 )
replace GL43 = . if (GL43 <= -1 )
replace GL44_A = . if (GL44_A <= -1 )
replace GL44_B = . if (GL44_B <= -1 )
replace GL45_A = . if (GL45_A <= -1 )
replace GL45_B = . if (GL45_B <= -1 )
replace GL45_C = . if (GL45_C <= -1 )
replace GL45_D = . if (GL45_D <= -1 )
replace GL45_E = . if (GL45_E <= -1 )
replace GL45_F = . if (GL45_F <= -1 )
replace GL45_G = . if (GL45_G <= -1 )
replace GL45_H = . if (GL45_H <= -1 )
replace GL45_I = . if (GL45_I <= -1 )
replace GL45_J = . if (GL45_J <= -1 )
replace GL45_K = . if (GL45_K <= -1 )
replace GL45_L = . if (GL45_L <= -1 )
replace GL46 = . if (GL46 <= -1 )
replace GL47_01 = . if (GL47_01 <= -1 )
replace GL47_02 = . if (GL47_02 <= -1 )
replace GL47_11 = . if (GL47_11 <= -1 )
replace GL47_12 = . if (GL47_12 <= -1 )
replace GL47_13 = . if (GL47_13 <= -1 )
replace GL47_21 = . if (GL47_21 <= -1 )
replace GL47_22 = . if (GL47_22 <= -1 )
replace GL47_23 = . if (GL47_23 <= -1 )
replace GL47_71 = . if (GL47_71 <= -1 )
replace GL47_91 = . if (GL47_91 <= -1 )
replace GL48_A = . if (GL48_A <= -1 )
replace GL48_B = . if (GL48_B <= -1 )
replace GL48_C = . if (GL48_C <= -1 )
replace GL48_D = . if (GL48_D <= -1 )
replace GL48_E = . if (GL48_E <= -1 )
replace GL48_F = . if (GL48_F <= -1 )
replace GL48_G = . if (GL48_G <= -1 )
replace GL48_H = . if (GL48_H <= -1 )
replace GL48_I = . if (GL48_I <= -1 )
replace GL48_J = . if (GL48_J <= -1 )
replace GL48_K = . if (GL48_K <= -1 )
replace GL48_K_1 = . if (GL48_K_1 <= -1 )
replace GL48_K_2 = . if (GL48_K_2 <= -1 )
replace GL48_K_3 = . if (GL48_K_3 <= -1 )
replace GL48_K_4 = . if (GL48_K_4 <= -1 )
replace GL49_A = . if (GL49_A <= -1 )
replace GL49_B = . if (GL49_B <= -1 )
replace GL50 = . if (GL50 <= -1 )
replace GL50_A = . if (GL50_A <= -1 )
replace GL51 = . if (GL51 <= -1 )
replace GL52 = . if (GL52 <= -1 )
replace GL55 = . if (GL55 <= -1 )
replace GL56 = . if (GL56 <= -1 )
replace GL57 = . if (GL57 <= -1 )
replace GL58 = . if (GL58 <= -1 )
replace GL58_A_1 = . if (GL58_A_1 <= -1 )
replace GL58_A_2 = . if (GL58_A_2 <= -1 )
replace GL58_A_3 = . if (GL58_A_3 <= -1 )
replace GL58_A_4 = . if (GL58_A_4 <= -1 )
replace GL58_B = . if (GL58_B <= -1 )
replace GL58_C_M = . if (GL58_C_M <= -1 )
replace GL58_C_D = . if (GL58_C_D <= -1 )
replace GL58_D = . if (GL58_D <= -1 )
replace GL59_A = . if (GL59_A <= -1 )
replace GL59_B = . if (GL59_B <= -1 )
replace GL60 = . if (GL60 <= -1 )
replace GL63 = . if (GL63 <= -1 )
replace GL64 = . if (GL64 <= -1 )
replace GL65_01 = . if (GL65_01 <= -1 )
replace GL65_02 = . if (GL65_02 <= -1 )
replace GL65_11 = . if (GL65_11 <= -1 )
replace GL65_12 = . if (GL65_12 <= -1 )
replace GL65_13 = . if (GL65_13 <= -1 )
replace GL65_21 = . if (GL65_21 <= -1 )
replace GL65_22 = . if (GL65_22 <= -1 )
replace GL65_23 = . if (GL65_23 <= -1 )
replace GL65_28 = . if (GL65_28 <= -1 )
replace GL65_71 = . if (GL65_71 <= -1 )
replace GL65_91 = . if (GL65_91 <= -1 )
replace GL65_A_1 = . if (GL65_A_1 <= -1 )
replace GL65_A_2 = . if (GL65_A_2 <= -1 )
replace GL66 = . if (GL66 <= -1 )
replace GL66_A = . if (GL66_A <= -1 )
replace GL66_B = . if (GL66_B <= -1 )
replace GL66_C_1 = . if (GL66_C_1 <= -1 )
replace GL66_C_2 = . if (GL66_C_2 <= -1 )
replace GL66_C_3 = . if (GL66_C_3 <= -1 )
replace GL66_C_4 = . if (GL66_C_4 <= -1 )
replace GL66_C_5 = . if (GL66_C_5 <= -1 )
replace GL66_C_6 = . if (GL66_C_6 <= -1 )
replace GL66_C_7 = . if (GL66_C_7 <= -1 )
replace GL66_C_8 = . if (GL66_C_8 <= -1 )
replace GL66_C_9 = . if (GL66_C_9 <= -1 )
replace GL66_D = . if (GL66_D <= -1 )
replace GL66_E = . if (GL66_E <= -1 )
replace GL66_F = . if (GL66_F <= -1 )
replace GL66_G_1 = . if (GL66_G_1 <= -1 )
replace GL66_G_2 = . if (GL66_G_2 <= -1 )
replace GL66_G_3 = . if (GL66_G_3 <= -1 )
replace GL66_G_4 = . if (GL66_G_4 <= -1 )
replace GL66_G_5 = . if (GL66_G_5 <= -1 )
replace GL66_H_1 = . if (GL66_H_1 <= -1 )
replace GL66_H_2 = . if (GL66_H_2 <= -1 )
replace GL66_H_3 = . if (GL66_H_3 <= -1 )
replace GL66_H_4 = . if (GL66_H_4 <= -1 )
replace GL66_H_5 = . if (GL66_H_5 <= -1 )
replace GL66_H_6 = . if (GL66_H_6 <= -1 )
replace GL66_H_7 = . if (GL66_H_7 <= -1 )
replace GL66_H_8 = . if (GL66_H_8 <= -1 )
replace GL66_H_9 = . if (GL66_H_9 <= -1 )
replace GL66_I = . if (GL66_I <= -1 )
replace GL67 = . if (GL67 <= -1 )
replace GL67_A = . if (GL67_A <= -1 )
replace GL67_B = . if (GL67_B <= -1 )
replace GL67_C_1 = . if (GL67_C_1 <= -1 )
replace GL67_C_2 = . if (GL67_C_2 <= -1 )
replace GL67_C_3 = . if (GL67_C_3 <= -1 )
replace GL67_C_4 = . if (GL67_C_4 <= -1 )
replace GL67_C_5 = . if (GL67_C_5 <= -1 )
replace GL67_C_6 = . if (GL67_C_6 <= -1 )
replace GL67_C_7 = . if (GL67_C_7 <= -1 )
replace GL67_C_8 = . if (GL67_C_8 <= -1 )
replace GL67_C_9 = . if (GL67_C_9 <= -1 )
replace GL67_D = . if (GL67_D <= -1 )
replace GL67_E = . if (GL67_E <= -1 )
replace GL67_F = . if (GL67_F <= -1 )
replace GL67_G_1 = . if (GL67_G_1 <= -1 )
replace GL67_G_2 = . if (GL67_G_2 <= -1 )
replace GL67_G_3 = . if (GL67_G_3 <= -1 )
replace GL67_G_4 = . if (GL67_G_4 <= -1 )
replace GL67_G_5 = . if (GL67_G_5 <= -1 )
replace GL67_H_1 = . if (GL67_H_1 <= -1 )
replace GL67_H_2 = . if (GL67_H_2 <= -1 )
replace GL67_H_3 = . if (GL67_H_3 <= -1 )
replace GL67_H_4 = . if (GL67_H_4 <= -1 )
replace GL67_H_5 = . if (GL67_H_5 <= -1 )
replace GL67_H_6 = . if (GL67_H_6 <= -1 )
replace GL67_H_7 = . if (GL67_H_7 <= -1 )
replace GL67_H_8 = . if (GL67_H_8 <= -1 )
replace GL67_H_9 = . if (GL67_H_9 <= -1 )
replace GL67_I = . if (GL67_I <= -1 )
replace GL68 = . if (GL68 <= -1 )
replace GL68A_1 = . if (GL68A_1 <= -1 )
replace GL68A_2 = . if (GL68A_2 <= -1 )
replace GL68A_3 = . if (GL68A_3 <= -1 )
replace GL68A_4 = . if (GL68A_4 <= -1 )
replace GL68A_5 = . if (GL68A_5 <= -1 )
replace GL68A_6 = . if (GL68A_6 <= -1 )
replace GL68B_1 = . if (GL68B_1 <= -1 )
replace GL68C_1 = . if (GL68C_1 <= -1 )
replace GL68D_1 = . if (GL68D_1 <= -1 )
replace GL68E_1 = . if (GL68E_1 <= -1 )
replace GL68F1_1 = . if (GL68F1_1 <= -1 )
replace GL68F1_2 = . if (GL68F1_2 <= -1 )
replace GL68F111 = . if (GL68F111 <= -1 )
replace GL68F112 = . if (GL68F112 <= -1 )
replace GL68F113 = . if (GL68F113 <= -1 )
replace GL68F121 = . if (GL68F121 <= -1 )
replace GL68F122 = . if (GL68F122 <= -1 )
replace GL68F123 = . if (GL68F123 <= -1 )
replace GL68F128 = . if (GL68F128 <= -1 )
replace GL68F191 = . if (GL68F191 <= -1 )
replace GL68G_1 = . if (GL68G_1 <= -1 )
replace GL68B_2 = . if (GL68B_2 <= -1 )
replace GL68C_2 = . if (GL68C_2 <= -1 )
replace GL68D_2 = . if (GL68D_2 <= -1 )
replace GL68E_2 = . if (GL68E_2 <= -1 )
replace GL68F2_1 = . if (GL68F2_1 <= -1 )
replace GL68F2_2 = . if (GL68F2_2 <= -1 )
replace GL68F211 = . if (GL68F211 <= -1 )
replace GL68F212 = . if (GL68F212 <= -1 )
replace GL68F213 = . if (GL68F213 <= -1 )
replace GL68F221 = . if (GL68F221 <= -1 )
replace GL68F222 = . if (GL68F222 <= -1 )
replace GL68F223 = . if (GL68F223 <= -1 )
replace GL68F228 = . if (GL68F228 <= -1 )
replace GL68F271 = . if (GL68F271 <= -1 )
replace GL68F291 = . if (GL68F291 <= -1 )
replace GL68G_2 = . if (GL68G_2 <= -1 )
replace GL69 = . if (GL69 <= -1 )
replace GL69_A_1 = . if (GL69_A_1 <= -1 )
replace GL69_B_1 = . if (GL69_B_1 <= -1 )
replace GL69_A_2 = . if (GL69_A_2 <= -1 )
replace GL69_B_2 = . if (GL69_B_2 <= -1 )
replace GL69_A_3 = . if (GL69_A_3 <= -1 )
replace GL69_B_3 = . if (GL69_B_3 <= -1 )
replace GL69_A_4 = . if (GL69_A_4 <= -1 )
replace GL69_B_4 = . if (GL69_B_4 <= -1 )
replace GL69_A_5 = . if (GL69_A_5 <= -1 )
replace GL69_B_5 = . if (GL69_B_5 <= -1 )
replace GL70 = . if (GL70 <= -1 )
replace GL71 = . if (GL71 <= -1 )
replace GL72_01 = . if (GL72_01 <= -1 )
replace GL72_02 = . if (GL72_02 <= -1 )
replace GL72_22 = . if (GL72_22 <= -1 )
replace GL72_23 = . if (GL72_23 <= -1 )
replace GL72_24 = . if (GL72_24 <= -1 )
replace GL72_25 = . if (GL72_25 <= -1 )
replace GL72_26 = . if (GL72_26 <= -1 )
replace GL72_71 = . if (GL72_71 <= -1 )
replace GL72_91 = . if (GL72_91 <= -1 )
replace GL72_A1 = . if (GL72_A1 <= -1 )
replace GL72_A2 = . if (GL72_A2 <= -1 )
replace GL73 = . if (GL73 <= -1 )
replace GL73_A = . if (GL73_A <= -1 )
replace GL73_B01 = . if (GL73_B01 <= -1 )
replace GL73_B02 = . if (GL73_B02 <= -1 )
replace GL73_B03 = . if (GL73_B03 <= -1 )
replace GL73_B04 = . if (GL73_B04 <= -1 )
replace GL73_B05 = . if (GL73_B05 <= -1 )
replace GL73_B06 = . if (GL73_B06 <= -1 )
replace GL73_B07 = . if (GL73_B07 <= -1 )
replace GL73_B08 = . if (GL73_B08 <= -1 )
replace GL73_B09 = . if (GL73_B09 <= -1 )
replace GL73_C = . if (GL73_C <= -1 )
replace GL74 = . if (GL74 <= -1 )
replace GL74_A = . if (GL74_A <= -1 )
replace GL74_B01 = . if (GL74_B01 <= -1 )
replace GL74_B02 = . if (GL74_B02 <= -1 )
replace GL74_B03 = . if (GL74_B03 <= -1 )
replace GL74_B04 = . if (GL74_B04 <= -1 )
replace GL74_B05 = . if (GL74_B05 <= -1 )
replace GL74_B06 = . if (GL74_B06 <= -1 )
replace GL74_B07 = . if (GL74_B07 <= -1 )
replace GL74_B08 = . if (GL74_B08 <= -1 )
replace GL74_B09 = . if (GL74_B09 <= -1 )
replace GL74_C = . if (GL74_C <= -1 )
replace GL75 = . if (GL75 <= -1 )
replace GL75_A_1 = . if (GL75_A_1 <= -1 )
replace GL75_A_2 = . if (GL75_A_2 <= -1 )
replace GL75_A_3 = . if (GL75_A_3 <= -1 )
replace GL75_A_4 = . if (GL75_A_4 <= -1 )
replace GL75_A_5 = . if (GL75_A_5 <= -1 )
replace GL75_A_6 = . if (GL75_A_6 <= -1 )
replace GL75B_1 = . if (GL75B_1 <= -1 )
replace GL75C_1 = . if (GL75C_1 <= -1 )
replace GL75D_1 = . if (GL75D_1 <= -1 )
replace GL75E_1 = . if (GL75E_1 <= -1 )
replace GL75F101 = . if (GL75F101 <= -1 )
replace GL75F102 = . if (GL75F102 <= -1 )
replace GL75F122 = . if (GL75F122 <= -1 )
replace GL75F123 = . if (GL75F123 <= -1 )
replace GL75F124 = . if (GL75F124 <= -1 )
replace GL75F125 = . if (GL75F125 <= -1 )
replace GL75F126 = . if (GL75F126 <= -1 )
replace GL75F171 = . if (GL75F171 <= -1 )
replace GL75F191 = . if (GL75F191 <= -1 )
replace GL75G_1 = . if (GL75G_1 <= -1 )
replace GL75B_2 = . if (GL75B_2 <= -1 )
replace GL75C_2 = . if (GL75C_2 <= -1 )
replace GL75D_2 = . if (GL75D_2 <= -1 )
replace GL75E_2 = . if (GL75E_2 <= -1 )
replace GL75F201 = . if (GL75F201 <= -1 )
replace GL75F202 = . if (GL75F202 <= -1 )
replace GL75F222 = . if (GL75F222 <= -1 )
replace GL75F223 = . if (GL75F223 <= -1 )
replace GL75F224 = . if (GL75F224 <= -1 )
replace GL75F225 = . if (GL75F225 <= -1 )
replace GL75F226 = . if (GL75F226 <= -1 )
replace GL75F271 = . if (GL75F271 <= -1 )
replace GL75F291 = . if (GL75F291 <= -1 )
replace GL75G_2 = . if (GL75G_2 <= -1 )
replace GL76 = . if (GL76 <= -1 )
replace GL76_A_1 = . if (GL76_A_1 <= -1 )
replace GL76_A_2 = . if (GL76_A_2 <= -1 )
replace GL76_A_3 = . if (GL76_A_3 <= -1 )
replace GL76_A_4 = . if (GL76_A_4 <= -1 )
replace GL77 = . if (GL77 <= -1 )
replace GL77_A = . if (GL77_A <= -1 )
replace GL77B_01 = . if (GL77B_01 <= -1 )
replace GL77B_02 = . if (GL77B_02 <= -1 )
replace GL77B_11 = . if (GL77B_11 <= -1 )
replace GL77B_12 = . if (GL77B_12 <= -1 )
replace GL77B_13 = . if (GL77B_13 <= -1 )
replace GL77B_21 = . if (GL77B_21 <= -1 )
replace GL77B_22 = . if (GL77B_22 <= -1 )
replace GL77B_23 = . if (GL77B_23 <= -1 )
replace GL77B_24 = . if (GL77B_24 <= -1 )
replace GL77B_25 = . if (GL77B_25 <= -1 )
replace GL77B_26 = . if (GL77B_26 <= -1 )
replace GL77B_27 = . if (GL77B_27 <= -1 )
replace GL77B_28 = . if (GL77B_28 <= -1 )
replace GL77B_71 = . if (GL77B_71 <= -1 )
replace GL77B_91 = . if (GL77B_91 <= -1 )
replace GL77_C_1 = . if (GL77_C_1 <= -1 )
replace GL77_C_2 = . if (GL77_C_2 <= -1 )
replace GL77_C_3 = . if (GL77_C_3 <= -1 )
replace GL77_C_4 = . if (GL77_C_4 <= -1 )
replace GL77_C_5 = . if (GL77_C_5 <= -1 )
replace GL77_C_6 = . if (GL77_C_6 <= -1 )
replace GL77_C_7 = . if (GL77_C_7 <= -1 )
replace GL77_C_8 = . if (GL77_C_8 <= -1 )
replace GL78 = . if (GL78 <= -1 )
replace GL79 = . if (GL79 <= -1 )
replace GL80_01 = . if (GL80_01 <= -1 )
replace GL80_02 = . if (GL80_02 <= -1 )
replace GL80_11 = . if (GL80_11 <= -1 )
replace GL80_12 = . if (GL80_12 <= -1 )
replace GL80_13 = . if (GL80_13 <= -1 )
replace GL80_21 = . if (GL80_21 <= -1 )
replace GL80_22 = . if (GL80_22 <= -1 )
replace GL80_23 = . if (GL80_23 <= -1 )
replace GL80_28 = . if (GL80_28 <= -1 )
replace GL80_71 = . if (GL80_71 <= -1 )
replace GL80_91 = . if (GL80_91 <= -1 )
replace GL80_A1 = . if (GL80_A1 <= -1 )
replace GL80_A2 = . if (GL80_A2 <= -1 )
replace GL81_01 = . if (GL81_01 <= -1 )
replace GL81_02 = . if (GL81_02 <= -1 )
replace GL81_03 = . if (GL81_03 <= -1 )
replace GL81_A = . if (GL81_A <= -1 )
replace GL81_B = . if (GL81_B <= -1 )
replace GL81_C_1 = . if (GL81_C_1 <= -1 )
replace GL81_C_2 = . if (GL81_C_2 <= -1 )
replace GL81_C_3 = . if (GL81_C_3 <= -1 )
replace GL81_C_4 = . if (GL81_C_4 <= -1 )
replace GL81_C_5 = . if (GL81_C_5 <= -1 )
replace GL81_C_6 = . if (GL81_C_6 <= -1 )
replace GL81_D = . if (GL81_D <= -1 )
replace GL81_E = . if (GL81_E <= -1 )
replace GL81_F = . if (GL81_F <= -1 )
replace GL81_G_1 = . if (GL81_G_1 <= -1 )
replace GL81_G_2 = . if (GL81_G_2 <= -1 )
replace GL81_G_3 = . if (GL81_G_3 <= -1 )
replace GL81_G_4 = . if (GL81_G_4 <= -1 )
replace GL81_G_5 = . if (GL81_G_5 <= -1 )
replace GL81_H_1 = . if (GL81_H_1 <= -1 )
replace GL81_H_2 = . if (GL81_H_2 <= -1 )
replace GL81_H_3 = . if (GL81_H_3 <= -1 )
replace GL81_H_4 = . if (GL81_H_4 <= -1 )
replace GL81_H_5 = . if (GL81_H_5 <= -1 )
replace GL81_H_6 = . if (GL81_H_6 <= -1 )
replace GL81_I = . if (GL81_I <= -1 )
replace GL81_J = . if (GL81_J <= -1 )
replace GL81_K_1 = . if (GL81_K_1 <= -1 )
replace GL81_K_2 = . if (GL81_K_2 <= -1 )
replace GL81_K_3 = . if (GL81_K_3 <= -1 )
replace GL81_K_4 = . if (GL81_K_4 <= -1 )
replace GL81_K_5 = . if (GL81_K_5 <= -1 )
replace GL81_K_6 = . if (GL81_K_6 <= -1 )
replace GL81_K_7 = . if (GL81_K_7 <= -1 )
replace GL81_K_8 = . if (GL81_K_8 <= -1 )
replace GL81_L_1 = . if (GL81_L_1 <= -1 )
replace GL81_L_2 = . if (GL81_L_2 <= -1 )
replace GL81_L_3 = . if (GL81_L_3 <= -1 )
replace GL81_L_4 = . if (GL81_L_4 <= -1 )
replace GL81_L_5 = . if (GL81_L_5 <= -1 )
replace GL81_L_6 = . if (GL81_L_6 <= -1 )
replace GL81_M = . if (GL81_M <= -1 )
replace GL82_01 = . if (GL82_01 <= -1 )
replace GL82_02 = . if (GL82_02 <= -1 )
replace GL82_03 = . if (GL82_03 <= -1 )
replace GL82_A = . if (GL82_A <= -1 )
replace GL82_B = . if (GL82_B <= -1 )
replace GL82_C_1 = . if (GL82_C_1 <= -1 )
replace GL82_C_2 = . if (GL82_C_2 <= -1 )
replace GL82_C_3 = . if (GL82_C_3 <= -1 )
replace GL82_C_4 = . if (GL82_C_4 <= -1 )
replace GL82_C_5 = . if (GL82_C_5 <= -1 )
replace GL82_C_6 = . if (GL82_C_6 <= -1 )
replace GL82_D = . if (GL82_D <= -1 )
replace GL82_E = . if (GL82_E <= -1 )
replace GL82_F = . if (GL82_F <= -1 )
replace GL82_G_1 = . if (GL82_G_1 <= -1 )
replace GL82_G_2 = . if (GL82_G_2 <= -1 )
replace GL82_G_3 = . if (GL82_G_3 <= -1 )
replace GL82_G_4 = . if (GL82_G_4 <= -1 )
replace GL82_G_5 = . if (GL82_G_5 <= -1 )
replace GL82_H_1 = . if (GL82_H_1 <= -1 )
replace GL82_H_2 = . if (GL82_H_2 <= -1 )
replace GL82_H_3 = . if (GL82_H_3 <= -1 )
replace GL82_H_4 = . if (GL82_H_4 <= -1 )
replace GL82_H_5 = . if (GL82_H_5 <= -1 )
replace GL82_H_6 = . if (GL82_H_6 <= -1 )
replace GL82_I = . if (GL82_I <= -1 )
replace GL82_J = . if (GL82_J <= -1 )
replace GL82_K_1 = . if (GL82_K_1 <= -1 )
replace GL82_K_2 = . if (GL82_K_2 <= -1 )
replace GL82_K_3 = . if (GL82_K_3 <= -1 )
replace GL82_K_4 = . if (GL82_K_4 <= -1 )
replace GL82_K_5 = . if (GL82_K_5 <= -1 )
replace GL82_K_6 = . if (GL82_K_6 <= -1 )
replace GL82_K_7 = . if (GL82_K_7 <= -1 )
replace GL82_K_8 = . if (GL82_K_8 <= -1 )
replace GL82_L_1 = . if (GL82_L_1 <= -1 )
replace GL82_L_2 = . if (GL82_L_2 <= -1 )
replace GL82_L_3 = . if (GL82_L_3 <= -1 )
replace GL82_L_4 = . if (GL82_L_4 <= -1 )
replace GL82_L_5 = . if (GL82_L_5 <= -1 )
replace GL82_L_6 = . if (GL82_L_6 <= -1 )
replace GL82_M = . if (GL82_M <= -1 )
replace GL83 = . if (GL83 <= -1 )
replace GL83A_1 = . if (GL83A_1 <= -1 )
replace GL83A_2 = . if (GL83A_2 <= -1 )
replace GL83A_3 = . if (GL83A_3 <= -1 )
replace GL83A_4 = . if (GL83A_4 <= -1 )
replace GL83A_5 = . if (GL83A_5 <= -1 )
replace GL83B_1 = . if (GL83B_1 <= -1 )
replace GL83C_1 = . if (GL83C_1 <= -1 )
replace GL83D_1 = . if (GL83D_1 <= -1 )
replace GL83E_1 = . if (GL83E_1 <= -1 )
replace GL83F1_1 = . if (GL83F1_1 <= -1 )
replace GL83F1_2 = . if (GL83F1_2 <= -1 )
replace GL83F111 = . if (GL83F111 <= -1 )
replace GL83F112 = . if (GL83F112 <= -1 )
replace GL83F113 = . if (GL83F113 <= -1 )
replace GL83F121 = . if (GL83F121 <= -1 )
replace GL83F122 = . if (GL83F122 <= -1 )
replace GL83F123 = . if (GL83F123 <= -1 )
replace GL83F128 = . if (GL83F128 <= -1 )
replace GL83F171 = . if (GL83F171 <= -1 )
replace GL83F191 = . if (GL83F191 <= -1 )
replace GL83G_1 = . if (GL83G_1 <= -1 )
replace GL83B_2 = . if (GL83B_2 <= -1 )
replace GL83C_2 = . if (GL83C_2 <= -1 )
replace GL83D_2 = . if (GL83D_2 <= -1 )
replace GL83E_2 = . if (GL83E_2 <= -1 )
replace GL83F2_1 = . if (GL83F2_1 <= -1 )
replace GL83F2_2 = . if (GL83F2_2 <= -1 )
replace GL83F211 = . if (GL83F211 <= -1 )
replace GL83F212 = . if (GL83F212 <= -1 )
replace GL83F213 = . if (GL83F213 <= -1 )
replace GL83F221 = . if (GL83F221 <= -1 )
replace GL83F222 = . if (GL83F222 <= -1 )
replace GL83F223 = . if (GL83F223 <= -1 )
replace GL83F228 = . if (GL83F228 <= -1 )
replace GL83F271 = . if (GL83F271 <= -1 )
replace GL83F291 = . if (GL83F291 <= -1 )
replace GL83G_2 = . if (GL83G_2 <= -1 )
replace GL84 = . if (GL84 <= -1 )
replace GL85 = . if (GL85 <= -1 )
replace GL86_01 = . if (GL86_01 <= -1 )
replace GL86_02 = . if (GL86_02 <= -1 )
replace GL86_11 = . if (GL86_11 <= -1 )
replace GL86_12 = . if (GL86_12 <= -1 )
replace GL86_13 = . if (GL86_13 <= -1 )
replace GL86_21 = . if (GL86_21 <= -1 )
replace GL86_22 = . if (GL86_22 <= -1 )
replace GL86_23 = . if (GL86_23 <= -1 )
replace GL86_27 = . if (GL86_27 <= -1 )
replace GL86_29 = . if (GL86_29 <= -1 )
replace GL86_71 = . if (GL86_71 <= -1 )
replace GL86_91 = . if (GL86_91 <= -1 )
replace GL86_A1 = . if (GL86_A1 <= -1 )
replace GL86_A2 = . if (GL86_A2 <= -1 )
replace GL87_01 = . if (GL87_01 <= -1 )
replace GL87_02 = . if (GL87_02 <= -1 )
replace GL87_03 = . if (GL87_03 <= -1 )
replace GL87_B = . if (GL87_B <= -1 )
replace GL87_C = . if (GL87_C <= -1 )
replace GL87_D = . if (GL87_D <= -1 )
replace GL87_E = . if (GL87_E <= -1 )
replace GL87_F = . if (GL87_F <= -1 )
replace GL87_G_1 = . if (GL87_G_1 <= -1 )
replace GL87_G_2 = . if (GL87_G_2 <= -1 )
replace GL87_G_3 = . if (GL87_G_3 <= -1 )
replace GL87_G_4 = . if (GL87_G_4 <= -1 )
replace GL87_G_5 = . if (GL87_G_5 <= -1 )
replace GL87_G_6 = . if (GL87_G_6 <= -1 )
replace GL87_G_7 = . if (GL87_G_7 <= -1 )
replace GL87_G_8 = . if (GL87_G_8 <= -1 )
replace GL87_H = . if (GL87_H <= -1 )
replace GL87_I = . if (GL87_I <= -1 )
replace GL87_J = . if (GL87_J <= -1 )
replace GL87_K = . if (GL87_K <= -1 )
replace GL87_L_1 = . if (GL87_L_1 <= -1 )
replace GL87_L_2 = . if (GL87_L_2 <= -1 )
replace GL87_L_3 = . if (GL87_L_3 <= -1 )
replace GL87_L_4 = . if (GL87_L_4 <= -1 )
replace GL87_L_5 = . if (GL87_L_5 <= -1 )
replace GL87_L_6 = . if (GL87_L_6 <= -1 )
replace GL87_M = . if (GL87_M <= -1 )
replace GL87_N = . if (GL87_N <= -1 )
replace GL87_O = . if (GL87_O <= -1 )
replace GL87_P = . if (GL87_P <= -1 )
replace GL88_01 = . if (GL88_01 <= -1 )
replace GL88_02 = . if (GL88_02 <= -1 )
replace GL88_03 = . if (GL88_03 <= -1 )
replace GL88_B = . if (GL88_B <= -1 )
replace GL88_C = . if (GL88_C <= -1 )
replace GL88_D = . if (GL88_D <= -1 )
replace GL88_E = . if (GL88_E <= -1 )
replace GL88_F = . if (GL88_F <= -1 )
replace GL88_G_1 = . if (GL88_G_1 <= -1 )
replace GL88_G_2 = . if (GL88_G_2 <= -1 )
replace GL88_G_3 = . if (GL88_G_3 <= -1 )
replace GL88_G_4 = . if (GL88_G_4 <= -1 )
replace GL88_G_5 = . if (GL88_G_5 <= -1 )
replace GL88_G_6 = . if (GL88_G_6 <= -1 )
replace GL88_G_7 = . if (GL88_G_7 <= -1 )
replace GL88_G_8 = . if (GL88_G_8 <= -1 )
replace GL88_H = . if (GL88_H <= -1 )
replace GL88_I = . if (GL88_I <= -1 )
replace GL88_J = . if (GL88_J <= -1 )
replace GL88_K = . if (GL88_K <= -1 )
replace GL88_L_1 = . if (GL88_L_1 <= -1 )
replace GL88_L_2 = . if (GL88_L_2 <= -1 )
replace GL88_L_3 = . if (GL88_L_3 <= -1 )
replace GL88_L_4 = . if (GL88_L_4 <= -1 )
replace GL88_L_5 = . if (GL88_L_5 <= -1 )
replace GL88_L_6 = . if (GL88_L_6 <= -1 )
replace GL88_M = . if (GL88_M <= -1 )
replace GL88_N = . if (GL88_N <= -1 )
replace GL88_O = . if (GL88_O <= -1 )
replace GL88_P = . if (GL88_P <= -1 )
replace GL89 = . if (GL89 <= -1 )
replace GL89_A_1 = . if (GL89_A_1 <= -1 )
replace GL89_A_2 = . if (GL89_A_2 <= -1 )
replace GL89_A_3 = . if (GL89_A_3 <= -1 )
replace GL89_A_4 = . if (GL89_A_4 <= -1 )
replace GL89_A_5 = . if (GL89_A_5 <= -1 )
replace GL89_A_6 = . if (GL89_A_6 <= -1 )
replace GL89_A_7 = . if (GL89_A_7 <= -1 )
replace GL89_A_8 = . if (GL89_A_8 <= -1 )
replace GL89_A_9 = . if (GL89_A_9 <= -1 )
replace GL89B_1 = . if (GL89B_1 <= -1 )
replace GL89C_1 = . if (GL89C_1 <= -1 )
replace GL89D_1 = . if (GL89D_1 <= -1 )
replace GL89E_1 = . if (GL89E_1 <= -1 )
replace GL89F1_1 = . if (GL89F1_1 <= -1 )
replace GL89F1_2 = . if (GL89F1_2 <= -1 )
replace GL89F111 = . if (GL89F111 <= -1 )
replace GL89F112 = . if (GL89F112 <= -1 )
replace GL89F113 = . if (GL89F113 <= -1 )
replace GL89F121 = . if (GL89F121 <= -1 )
replace GL89F122 = . if (GL89F122 <= -1 )
replace GL89F123 = . if (GL89F123 <= -1 )
replace GL89F127 = . if (GL89F127 <= -1 )
replace GL89F129 = . if (GL89F129 <= -1 )
replace GL89F171 = . if (GL89F171 <= -1 )
replace GL89F191 = . if (GL89F191 <= -1 )
replace GL89G_1 = . if (GL89G_1 <= -1 )
replace GL89B_2 = . if (GL89B_2 <= -1 )
replace GL89C_2 = . if (GL89C_2 <= -1 )
replace GL89D_2 = . if (GL89D_2 <= -1 )
replace GL89E_2 = . if (GL89E_2 <= -1 )
replace GL89F2_1 = . if (GL89F2_1 <= -1 )
replace GL89F2_2 = . if (GL89F2_2 <= -1 )
replace GL89F211 = . if (GL89F211 <= -1 )
replace GL89F212 = . if (GL89F212 <= -1 )
replace GL89F213 = . if (GL89F213 <= -1 )
replace GL89F221 = . if (GL89F221 <= -1 )
replace GL89F222 = . if (GL89F222 <= -1 )
replace GL89F223 = . if (GL89F223 <= -1 )
replace GL89F227 = . if (GL89F227 <= -1 )
replace GL89F229 = . if (GL89F229 <= -1 )
replace GL89F271 = . if (GL89F271 <= -1 )
replace GL89F291 = . if (GL89F291 <= -1 )
replace GL89G_2 = . if (GL89G_2 <= -1 )
replace GL90 = . if (GL90 <= -1 )
replace GL91 = . if (GL91 <= -1 )
replace GL92_01 = . if (GL92_01 <= -1 )
replace GL92_02 = . if (GL92_02 <= -1 )
replace GL92_11 = . if (GL92_11 <= -1 )
replace GL92_12 = . if (GL92_12 <= -1 )
replace GL92_13 = . if (GL92_13 <= -1 )
replace GL92_21 = . if (GL92_21 <= -1 )
replace GL92_22 = . if (GL92_22 <= -1 )
replace GL92_23 = . if (GL92_23 <= -1 )
replace GL92_27 = . if (GL92_27 <= -1 )
replace GL92_29 = . if (GL92_29 <= -1 )
replace GL92_71 = . if (GL92_71 <= -1 )
replace GL92_91 = . if (GL92_91 <= -1 )
replace GL92A_1 = . if (GL92A_1 <= -1 )
replace GL92A_2 = . if (GL92A_2 <= -1 )
replace GL93 = . if (GL93 <= -1 )
replace GL93_A = . if (GL93_A <= -1 )
replace GL93_B_1 = . if (GL93_B_1 <= -1 )
replace GL93_B_2 = . if (GL93_B_2 <= -1 )
replace GL93_B_3 = . if (GL93_B_3 <= -1 )
replace GL93_B_4 = . if (GL93_B_4 <= -1 )
replace GL93_B_5 = . if (GL93_B_5 <= -1 )
replace GL93_B_6 = . if (GL93_B_6 <= -1 )
replace GL93_B_7 = . if (GL93_B_7 <= -1 )
replace GL93_B_8 = . if (GL93_B_8 <= -1 )
replace GL93_C = . if (GL93_C <= -1 )
replace GL94 = . if (GL94 <= -1 )
replace GL94_A = . if (GL94_A <= -1 )
replace GL94_B_1 = . if (GL94_B_1 <= -1 )
replace GL94_B_2 = . if (GL94_B_2 <= -1 )
replace GL94_B_3 = . if (GL94_B_3 <= -1 )
replace GL94_B_4 = . if (GL94_B_4 <= -1 )
replace GL94_B_5 = . if (GL94_B_5 <= -1 )
replace GL94_B_6 = . if (GL94_B_6 <= -1 )
replace GL94_B_7 = . if (GL94_B_7 <= -1 )
replace GL94_B_8 = . if (GL94_B_8 <= -1 )
replace GL94_C = . if (GL94_C <= -1 )
replace GL95 = . if (GL95 <= -1 )
replace GL95_A_1 = . if (GL95_A_1 <= -1 )
replace GL95_A_2 = . if (GL95_A_2 <= -1 )
replace GL95_A_3 = . if (GL95_A_3 <= -1 )
replace GL95_A_4 = . if (GL95_A_4 <= -1 )
replace GL95_A_5 = . if (GL95_A_5 <= -1 )
replace GL95_A_6 = . if (GL95_A_6 <= -1 )
replace GL95B_1 = . if (GL95B_1 <= -1 )
replace GL95C_1 = . if (GL95C_1 <= -1 )
replace GL95D_1 = . if (GL95D_1 <= -1 )
replace GL95E_1 = . if (GL95E_1 <= -1 )
replace GL95F1_1 = . if (GL95F1_1 <= -1 )
replace GL95F1_2 = . if (GL95F1_2 <= -1 )
replace GL95F127 = . if (GL95F127 <= -1 )
replace GL95F129 = . if (GL95F129 <= -1 )
replace GL95F171 = . if (GL95F171 <= -1 )
replace GL95F191 = . if (GL95F191 <= -1 )
replace GL95G_1 = . if (GL95G_1 <= -1 )
replace GL95B_2 = . if (GL95B_2 <= -1 )
replace GL95C_2 = . if (GL95C_2 <= -1 )
replace GL95D_2 = . if (GL95D_2 <= -1 )
replace GL95E_2 = . if (GL95E_2 <= -1 )
replace GL95F2_1 = . if (GL95F2_1 <= -1 )
replace GL95F2_2 = . if (GL95F2_2 <= -1 )
replace GL95F227 = . if (GL95F227 <= -1 )
replace GL95F229 = . if (GL95F229 <= -1 )
replace GL95F271 = . if (GL95F271 <= -1 )
replace GL95F291 = . if (GL95F291 <= -1 )
replace GL95G_2 = . if (GL95G_2 <= -1 )
replace GL96 = . if (GL96 <= -1 )
replace GL97 = . if (GL97 <= -1 )
replace GL98_01 = . if (GL98_01 <= -1 )
replace GL98_02 = . if (GL98_02 <= -1 )
replace GL98_11 = . if (GL98_11 <= -1 )
replace GL98_12 = . if (GL98_12 <= -1 )
replace GL98_13 = . if (GL98_13 <= -1 )
replace GL98_21 = . if (GL98_21 <= -1 )
replace GL98_22 = . if (GL98_22 <= -1 )
replace GL98_23 = . if (GL98_23 <= -1 )
replace GL98_27 = . if (GL98_27 <= -1 )
replace GL98_28 = . if (GL98_28 <= -1 )
replace GL98_29 = . if (GL98_29 <= -1 )
replace GL98_71 = . if (GL98_71 <= -1 )
replace GL98_91 = . if (GL98_91 <= -1 )
replace GL98A_1 = . if (GL98A_1 <= -1 )
replace GL98A_2 = . if (GL98A_2 <= -1 )
replace GL99 = . if (GL99 <= -1 )
replace GL99_A_1 = . if (GL99_A_1 <= -1 )
replace GL99_A_2 = . if (GL99_A_2 <= -1 )
replace GL99_A_3 = . if (GL99_A_3 <= -1 )
replace GL99_A_4 = . if (GL99_A_4 <= -1 )
replace GL99_A_5 = . if (GL99_A_5 <= -1 )
replace GL99_A_6 = . if (GL99_A_6 <= -1 )
replace GL99_B = . if (GL99_B <= -1 )
replace GL100 = . if (GL100 <= -1 )
replace GL100A_1 = . if (GL100A_1 <= -1 )
replace GL100A_2 = . if (GL100A_2 <= -1 )
replace GL100A_3 = . if (GL100A_3 <= -1 )
replace GL100A_4 = . if (GL100A_4 <= -1 )
replace GL100A_5 = . if (GL100A_5 <= -1 )
replace GL100A_6 = . if (GL100A_6 <= -1 )
replace GL100_B = . if (GL100_B <= -1 )
replace GL101 = . if (GL101 <= -1 )
replace GL101A_1 = . if (GL101A_1 <= -1 )
replace GL101A_2 = . if (GL101A_2 <= -1 )
replace GL101A_3 = . if (GL101A_3 <= -1 )
replace GL101A_4 = . if (GL101A_4 <= -1 )
replace GL101A_5 = . if (GL101A_5 <= -1 )
replace GL101A_6 = . if (GL101A_6 <= -1 )
replace GL101B_1 = . if (GL101B_1 <= -1 )
replace GL101C_1 = . if (GL101C_1 <= -1 )
replace GL101D_1 = . if (GL101D_1 <= -1 )
replace GL101E_1 = . if (GL101E_1 <= -1 )
replace GL101B_2 = . if (GL101B_2 <= -1 )
replace GL101C_2 = . if (GL101C_2 <= -1 )
replace GL101D_2 = . if (GL101D_2 <= -1 )
replace GL101E_2 = . if (GL101E_2 <= -1 )
replace GL102 = . if (GL102 <= -1 )
replace GL103 = . if (GL103 <= -1 )
replace GL104_01 = . if (GL104_01 <= -1 )
replace GL104_02 = . if (GL104_02 <= -1 )
replace GL104_11 = . if (GL104_11 <= -1 )
replace GL104_12 = . if (GL104_12 <= -1 )
replace GL104_13 = . if (GL104_13 <= -1 )
replace GL104_21 = . if (GL104_21 <= -1 )
replace GL104_22 = . if (GL104_22 <= -1 )
replace GL104_23 = . if (GL104_23 <= -1 )
replace GL104_27 = . if (GL104_27 <= -1 )
replace GL104_28 = . if (GL104_28 <= -1 )
replace GL104_29 = . if (GL104_29 <= -1 )
replace GL104_71 = . if (GL104_71 <= -1 )
replace GL104_91 = . if (GL104_91 <= -1 )
replace GL104A_1 = . if (GL104A_1 <= -1 )
replace GL104A_2 = . if (GL104A_2 <= -1 )
replace GL105 = . if (GL105 <= -1 )
replace GL105A_1 = . if (GL105A_1 <= -1 )
replace GL105A_2 = . if (GL105A_2 <= -1 )
replace GL105A_3 = . if (GL105A_3 <= -1 )
replace GL105A_4 = . if (GL105A_4 <= -1 )
replace GL105A_5 = . if (GL105A_5 <= -1 )
replace GL105A_6 = . if (GL105A_6 <= -1 )
replace GL105_B = . if (GL105_B <= -1 )
replace GL106 = . if (GL106 <= -1 )
replace GL106A_1 = . if (GL106A_1 <= -1 )
replace GL106A_2 = . if (GL106A_2 <= -1 )
replace GL106A_3 = . if (GL106A_3 <= -1 )
replace GL106A_4 = . if (GL106A_4 <= -1 )
replace GL106A_5 = . if (GL106A_5 <= -1 )
replace GL106A_6 = . if (GL106A_6 <= -1 )
replace GL106_B = . if (GL106_B <= -1 )
replace GL107 = . if (GL107 <= -1 )
replace GL107A51 = . if (GL107A51 <= -1 )
replace GL107A52 = . if (GL107A52 <= -1 )
replace GL107A53 = . if (GL107A53 <= -1 )
replace GL107A54 = . if (GL107A54 <= -1 )
replace GL107A91 = . if (GL107A91 <= -1 )
replace GL107B_1 = . if (GL107B_1 <= -1 )
replace GL107C_1 = . if (GL107C_1 <= -1 )
replace GL107D_1 = . if (GL107D_1 <= -1 )
replace GL107E_1 = . if (GL107E_1 <= -1 )
replace GL107B_2 = . if (GL107B_2 <= -1 )
replace GL107C_2 = . if (GL107C_2 <= -1 )
replace GL107D_2 = . if (GL107D_2 <= -1 )
replace GL107E_2 = . if (GL107E_2 <= -1 )
replace GL108 = . if (GL108 <= -1 )
replace GL108_A = . if (GL108_A <= -1 )
replace GL108_B = . if (GL108_B <= -1 )
replace GL109 = . if (GL109 <= -1 )
replace GL110 = . if (GL110 <= -1 )
replace GL111_A = . if (GL111_A <= -1 )
replace GL111_B = . if (GL111_B <= -1 )
replace GL113_01 = . if (GL113_01 <= -1 )
replace GL113_02 = . if (GL113_02 <= -1 )
replace GL113_11 = . if (GL113_11 <= -1 )
replace GL113_12 = . if (GL113_12 <= -1 )
replace GL113_13 = . if (GL113_13 <= -1 )
replace GL113_21 = . if (GL113_21 <= -1 )
replace GL113_22 = . if (GL113_22 <= -1 )
replace GL113_23 = . if (GL113_23 <= -1 )
replace GL113_24 = . if (GL113_24 <= -1 )
replace GL113_25 = . if (GL113_25 <= -1 )
replace GL113_26 = . if (GL113_26 <= -1 )
replace GL113_27 = . if (GL113_27 <= -1 )
replace GL113_28 = . if (GL113_28 <= -1 )
replace GL113_29 = . if (GL113_29 <= -1 )
replace GL113_71 = . if (GL113_71 <= -1 )
replace GL113_91 = . if (GL113_91 <= -1 )
replace GL114_A = . if (GL114_A <= -1 )
replace GL114_B = . if (GL114_B <= -1 )
replace GL114_C = . if (GL114_C <= -1 )
replace GL114_D = . if (GL114_D <= -1 )
replace GL114_E = . if (GL114_E <= -1 )
replace GL114_F = . if (GL114_F <= -1 )
replace GL114_G = . if (GL114_G <= -1 )
replace GL114_H = . if (GL114_H <= -1 )
replace GL114_I = . if (GL114_I <= -1 )
replace GL114_J = . if (GL114_J <= -1 )
replace GL114_K = . if (GL114_K <= -1 )
replace GL114K_1 = . if (GL114K_1 <= -1 )
replace GL114K_2 = . if (GL114K_2 <= -1 )
replace GL114K_3 = . if (GL114K_3 <= -1 )
replace GL114K_4 = . if (GL114K_4 <= -1 )
replace GL115 = . if (GL115 <= -1 )
replace GL116 = . if (GL116 <= -1 )
replace GL117 = . if (GL117 <= -1 )
replace GL117_B1 = . if (GL117_B1 <= -1 )
replace GL117_B2 = . if (GL117_B2 <= -1 )
replace GL117_B3 = . if (GL117_B3 <= -1 )
replace GL117_B4 = . if (GL117_B4 <= -1 )
replace GL117_B5 = . if (GL117_B5 <= -1 )
replace GL118 = . if (GL118 <= -1 )
replace GL118_A = . if (GL118_A <= -1 )
replace GL119 = . if (GL119 <= -1 )
replace GL120 = . if (GL120 <= -1 )
replace GL121_A = . if (GL121_A <= -1 )
replace GL121_B = . if (GL121_B <= -1 )
replace GL121_C = . if (GL121_C <= -1 )
replace GL121_D = . if (GL121_D <= -1 )
replace GL121_E = . if (GL121_E <= -1 )
replace GL121_F = . if (GL121_F <= -1 )
replace GL122 = . if (GL122 <= -1 )
replace GL123_W = . if (GL123_W <= -1 )
replace GL124 = . if (GL124 <= -1 )
replace GL125 = . if (GL125 <= -1 )
replace GL126 = . if (GL126 <= -1 )
replace GL127 = . if (GL127 <= -1 )
replace GL128 = . if (GL128 <= -1 )
replace GM1 = . if (GM1 <= -1 )
replace GM2 = . if (GM2 <= -1 )
replace GM3 = . if (GM3 <= -1 )
replace GM4 = . if (GM4 <= -1 )
replace GM5 = . if (GM5 <= -1 )
replace GM6 = . if (GM6 <= -1 )
replace GM7 = . if (GM7 <= -1 )
replace GM8 = . if (GM8 <= -1 )
replace GM9 = . if (GM9 <= -1 )
replace GM10A = . if (GM10A <= -1 )
replace GM10B = . if (GM10B <= -1 )
replace GM11A = . if (GM11A <= -1 )
replace GM11B = . if (GM11B <= -1 )
replace GM11C = . if (GM11C <= -1 )
replace GM12A = . if (GM12A <= -1 )
replace GM12B = . if (GM12B <= -1 )
replace GM12C = . if (GM12C <= -1 )
replace GM12D = . if (GM12D <= -1 )
replace GM12E = . if (GM12E <= -1 )
replace GM13 = . if (GM13 <= -1 )
replace GM14A = . if (GM14A <= -1 )
replace GM14B = . if (GM14B <= -1 )
replace GM14C = . if (GM14C <= -1 )
replace GM15A = . if (GM15A <= -1 )
replace GM15B = . if (GM15B <= -1 )
replace GM16 = . if (GM16 <= -1 )
replace GM17 = . if (GM17 <= -1 )
replace GM18A = . if (GM18A <= -1 )
replace GM18B = . if (GM18B <= -1 )
replace GM18C = . if (GM18C <= -1 )
replace GM19 = . if (GM19 <= -1 )
replace GM20 = . if (GM20 <= -1 )
replace GM21 = . if (GM21 <= -1 )
replace GN1 = . if (GN1 <= -1 )
replace GN2 = . if (GN2 <= -1 )
replace GN2A = . if (GN2A <= -1 )
replace GN3_1_1 = . if (GN3_1_1 <= -1 )
replace GN3_1_2 = . if (GN3_1_2 <= -1 )
replace GN3_2_1 = . if (GN3_2_1 <= -1 )
replace GN3_2_2 = . if (GN3_2_2 <= -1 )
replace GN3_3_1 = . if (GN3_3_1 <= -1 )
replace GN3_3_2 = . if (GN3_3_2 <= -1 )
replace GN3_4_1 = . if (GN3_4_1 <= -1 )
replace GN3_4_2 = . if (GN3_4_2 <= -1 )
replace GN4 = . if (GN4 <= -1 )
replace GN4A1 = . if (GN4A1 <= -1 )
replace GN4A2 = . if (GN4A2 <= -1 )
replace GN4A3 = . if (GN4A3 <= -1 )
replace GN4A4 = . if (GN4A4 <= -1 )
replace GN4A5 = . if (GN4A5 <= -1 )
replace GN4A6 = . if (GN4A6 <= -1 )
replace GN5 = . if (GN5 <= -1 )
replace GN6 = . if (GN6 <= -1 )
replace GN6A1 = . if (GN6A1 <= -1 )
replace GN6A2 = . if (GN6A2 <= -1 )
replace AGE = . if (AGE <= -1 )
replace AGEGRP = . if (AGEGRP <= -1 )
replace MSTAT = . if (MSTAT <= -1 )
replace FTWORK = . if (FTWORK <= -1 )
replace EDLEV = . if (EDLEV <= -1 )
replace HLTHINS = . if (HLTHINS <= -1 )
replace MAJSRC = . if (MAJSRC <= -1 )
replace REFER = . if (REFER <= -1 )
replace CJ_STAT = . if (CJ_STAT <= -1 )
replace RESTRICT = . if (RESTRICT <= -1 )
replace SLFEFF3 = . if (SLFEFF3 <= -1.0000 )
replace SLFEST3 = . if (SLFEST3 <= -1 )
replace SCACT3 = . if (SCACT3 <= -1 )
replace SCPRE3 = . if (SCPRE3 <= -1 )
replace SCIDEA3 = . if (SCIDEA3 <= -1 )
replace THALLY3 = . if (THALLY3 <= -1 )
replace TP12ST3 = . if (TP12ST3 <= -1 )
replace TPHELP3 = . if (TPHELP3 <= -1 )
replace TPSELF3 = . if (TPSELF3 <= -1 )
replace PDRUG = . if (PDRUG <= -1 )
replace PDRUGFRQ = . if (PDRUGFRQ <= -1 )
replace FAVDRUG = . if (FAVDRUG <= -1 )
replace HERHX = . if (HERHX <= -1 )
replace COCHX = . if (COCHX <= -1 )
replace DRUGTX = . if (DRUGTX <= -1 )
replace HVY_ALC = . if (HVY_ALC <= -1 )
replace ALCWK = . if (ALCWK <= -1 )
replace MRJWK = . if (MRJWK <= -1 )
replace COCWK = . if (COCWK <= -1 )
replace CRKWK = . if (CRKWK <= -1 )
replace HERWK = . if (HERWK <= -1 )
replace NARWK = . if (NARWK <= -1 )
replace SEDWK = . if (SEDWK <= -1 )
replace AMPWK = . if (AMPWK <= -1 )
replace HALWK = . if (HALWK <= -1 )
replace INHWK = . if (INHWK <= -1 )
replace DRGTXAGE = . if (DRGTXAGE <= -1 )


*/
/********************************************************************

 Section 5: Save Outfile

  This section saves out a Stata system format file.  There is no reason to
  modify it if the macros in Section 1 were specified correctly.

*********************************************************************/

save `outfile', replace

